@@ -28,30 +28,35 @@
 
 namespace nux
 {
-  static const t_s32 HERROR = 0;
-  NUX_IMPLEMENT_OBJECT_TYPE (GridHLayout);
+  NUX_IMPLEMENT_OBJECT_TYPE(GridHLayout);
 
-  GridHLayout::GridHLayout (NUX_FILE_LINE_DECL)
-    :   Layout (NUX_FILE_LINE_PARAM)
+  GridHLayout::GridHLayout(NUX_FILE_LINE_DECL)
+    :   Layout(NUX_FILE_LINE_PARAM)
   {
 #if DEBUG_LAYOUT
     m_h_in_margin = 10;
-    m_h_out_margin = 10;
+    left_padding_ = 10;
+    right_padding_ = 10;
     m_v_in_margin = 10;
-    m_v_out_margin = 10;
+    top_padding_ = 10;
+    bottom_padding_ = 10;
 #endif
 
-    _children_size = Size (64, 64);
+    m_h_in_margin = 10;
+    m_v_in_margin = 10;
+
+    filling_order_ = FILL_HORIZONTAL;
+    _children_size = Size(64, 64);
     _force_children_size = true;
     _partial_visibility = true;
     _num_row = 1;
     _num_column = 1;
     _dynamic_column = true;
-    _height_match_content = true;
+    match_content_size_ = true;
 
     // Start packing the elements from the top. Is the layout has more space than the elements can use,
     // leave that space at the bottom of the GridHLayout.
-    m_ContentStacking = eStackLeft;
+    m_ContentStacking = MAJOR_POSITION_LEFT;
 
     SetMinimumSize(32, 32);
   }
@@ -61,216 +66,105 @@ namespace nux
 
   }
 
-  int GridHLayout::GetChildPos (Area *child)
+  void GridHLayout::SetSpaceBetweenChildren(int horizontal_space, int vertical_space)
+  {
+    m_h_in_margin = horizontal_space;
+    m_v_in_margin = vertical_space;
+  }
+
+  int GridHLayout::GetChildPos(Area *child)
   {
     int position = 0;
     std::list<Area *>::const_iterator it;
-    for (it = GetChildren ().begin(); it != GetChildren ().end(); it++)
+    for (it = GetChildren().begin(); it != GetChildren().end(); it++)
     {
       if ((*it) == child)
         break;
-      
-      if ((*it)->CanFocus ())
-      {
-        position++;
-      }
+      ++position;
     }
 
     return position;
   }
 
-  Area* GridHLayout::GetChildAtPosition (int pos)
+  Area* GridHLayout::GetChildAtPosition(int pos)
   {
     int position = 0;
     std::list<Area *>::const_iterator it;
-    for (it = GetChildren ().begin(); it != GetChildren ().end(); it++)
+    for (it = GetChildren().begin(); it != GetChildren().end(); it++)
     {
       if (position == pos)
         return (*it);
-      
-      if ((*it)->CanFocus ())
-      {
-        position++;
-      }
-    }   
+
+      ++position;
+    }
 
     return NULL;
   }
 
-  long GridHLayout::DoFocusLeft (IEvent &ievent, long TraverseInfo, long ProcessEventInfo)
-  {
-    // if we are left on an edge, then send up
-    Area* focused_child = GetFocusedChild ();
-    int position = GetChildPos (focused_child);
-    Area *parent = GetParentObject ();
-
-    if (parent == NULL || position % GetNumColumn ())
-    {
-      return Layout::DoFocusLeft (ievent, TraverseInfo, ProcessEventInfo);
-    }
-    else
-    {
-      // left edge
-      return SendEventToArea (parent, ievent, TraverseInfo, ProcessEventInfo);
-    }
-  }
-
-  long GridHLayout::DoFocusRight (IEvent &ievent, long TraverseInfo, long ProcessEventInfo)
-  {
-    // if we are left on an edge, then send up
-    Area* focused_child = GetFocusedChild ();
-    int position = GetChildPos (focused_child);
-    Area *parent = GetParentObject ();
-
-    if (parent == NULL || (position + 1) % GetNumColumn ())
-    {
-      return Layout::DoFocusRight (ievent, TraverseInfo, ProcessEventInfo);
-    }
-    else
-    {
-      // Right Edge
-      return SendEventToArea (parent, ievent, TraverseInfo, ProcessEventInfo);
-    }
-  }
-
-  //up and down should pass event to parent
-  long GridHLayout::DoFocusUp (IEvent &ievent, long TraverseInfo, long ProcessEventInfo)
-  {
-    Area* focused_child = GetFocusedChild ();
-    int position = GetChildPos (focused_child);
-    Area *parent = GetParentObject ();
-    
-    if (focused_child == NULL || position < GetNumColumn ())
-    {
-      
-      if (parent != NULL)
-        return SendEventToArea (parent, ievent, TraverseInfo, ProcessEventInfo);
-      else
-        FocusFirstChild ();
-
-    }
-    else
-    {
-      // so hacky, but its cheap!
-      // just focus the child position - numcolumns
-      //focused_child->SetFocused (false);
-      focused_child = GetChildAtPosition (position - GetNumColumn ());
-      if (focused_child)
-      {
-        focused_child->SetFocused (true);
-        ChildFocusChanged.emit (/*this,*/ focused_child);
-      }
-      else
-      {
-        if (parent != NULL)
-          return SendEventToArea (parent, ievent, TraverseInfo, ProcessEventInfo);
-        else
-          FocusFirstChild ();
-      }
-    }
-
-    return TraverseInfo;
-  }
-  long GridHLayout::DoFocusDown (IEvent &ievent, long TraverseInfo, long ProcessEventInfo)
-  {
-    Area* focused_child = GetFocusedChild ();
-    int position = GetChildPos (focused_child);
-    Area *parent = GetParentObject ();
-    
-    if (focused_child == NULL || position > GetNumColumn () * (GetNumRow () - 1))
-    {
-      if (parent != NULL)
-        return SendEventToArea (parent, ievent, TraverseInfo, ProcessEventInfo);
-      else
-        FocusLastChild ();
-    }
-    else
-    {
-      // so hacky, but its cheap!
-      // just focus the child position - numcolumns
-      //focused_child->SetFocused (false);
-      focused_child = GetChildAtPosition (position + GetNumColumn ());
-      if (focused_child)
-      {
-        focused_child->SetFocused (true);
-        ChildFocusChanged.emit (/*this,*/ focused_child);
-      }
-      else
-      {
-        if (parent != NULL)
-          return SendEventToArea (parent, ievent, TraverseInfo, ProcessEventInfo);
-        else
-          FocusLastChild ();
-      }
-    }
-
-    return TraverseInfo;
-  }
-
-  void GridHLayout::EnablePartialVisibility (bool partial_visibility)
+  void GridHLayout::EnablePartialVisibility(bool partial_visibility)
   {
     _partial_visibility = partial_visibility;
   }
 
-  void GridHLayout::SetChildrenSize (int width, int height)
+  void GridHLayout::SetChildrenSize(int width, int height)
   {
-    _children_size = Size (width, height);
+    _children_size = Size(width, height);
   }
 
-  Size GridHLayout::GetChildrenSize () const
+  Size GridHLayout::GetChildrenSize() const
   {
     return _children_size;
   }
 
-  void GridHLayout::ForceChildrenSize (bool force)
+  void GridHLayout::ForceChildrenSize(bool force)
   {
     _force_children_size = force;
   }
 
-  int GridHLayout::GetNumColumn () const
+  int GridHLayout::GetNumColumn() const
   {
     return _num_column;
   }
 
-  int GridHLayout::GetNumRow () const
+  int GridHLayout::GetNumRow() const
   {
     return _num_row;
   }
 
-  void GridHLayout::SetHeightMatchContent (bool match_content)
+  void GridHLayout::MatchContentSize(bool match_content)
   {
-    _height_match_content = match_content;
+    match_content_size_ = match_content;
   }
 
-  bool GridHLayout::GetHeightMatchContent () const
+  bool GridHLayout::IsMatchingContentSize() const
   {
-    return _height_match_content;
+    return match_content_size_;
   }
 
-  void GridHLayout::GetCompositeList (std::list<Area *> *ViewList)
+  void GridHLayout::GetCompositeList(std::list<Area *> *ViewList)
   {
     std::list<Area *>::iterator it;
 
     for (it = _layout_element_list.begin(); it != _layout_element_list.end(); it++)
     {
-      if ( (*it)->IsView() )
+      if ((*it)->IsView())
       {
         View *ic = static_cast<View *>(*it);
-        ViewList->push_back (ic);
+        ViewList->push_back(ic);
       }
-      else if ( (*it)->IsLayout() )
+      else if ((*it)->IsLayout())
       {
         Layout *layout = static_cast<Layout *>(*it);
-        layout->GetCompositeList (ViewList);
+        layout->GetCompositeList(ViewList);
       }
     }
   }
 
-  long GridHLayout::ComputeLayout2()
+  long GridHLayout::ComputeLayoutRowOrder()
   {
     std::list<Area *> elements;
 
-    if (GetStretchFactor() == 0)
+    if (GetScaleFactor() == 0)
     {
       ApplyMinWidth();
     }
@@ -280,21 +174,21 @@ namespace nux
       return eCompliantHeight | eCompliantWidth;
     }
 
-    t_s32 num_elements = 0;
+    int num_elements = 0;
 
     std::list<Area *>::iterator it;
     for (it = _layout_element_list.begin(); it != _layout_element_list.end(); it++)
     {
-      if ((*it)->IsVisible ())
+      if ((*it)->IsVisible())
       {
-        (*it)->SetLayoutDone (false);
-        elements.push_back (*it);
+        (*it)->SetLayoutDone(false);
+        elements.push_back(*it);
         num_elements++;
       }
-      (*it)->SetLayoutDone (false);
+      (*it)->SetLayoutDone(false);
     }
 
-    t_s32 original_height = GetBaseHeight();
+    int original_height = GetBaseHeight();
 
     // The grid layout goes through the child elements and assign them a size and position. Children are filled in the grid like this:
     //  0   1   2   3   4   5
@@ -312,17 +206,17 @@ namespace nux
 
     if (_dynamic_column)
     {
-      int X = base.x + m_h_out_margin;
-      int Y = base.y + m_v_out_margin;
+      int X = base.x + left_padding_;
+      int Y = base.y + top_padding_;
 
       bool first_element_of_row = true;
 
-      for(int i = 0; i < num_elements; i++)
+      for (int i = 0; i < num_elements; i++)
       {
         if (num_row == 1)
           num_column++;
 
-        if(first_element_of_row)
+        if (first_element_of_row)
         {
           first_element_of_row = false;
         }
@@ -332,9 +226,9 @@ namespace nux
           (*it)->SetMinimumSize(_children_size.width, _children_size.height);
         }
 
-        (*it)->SetGeometry(nux::Geometry (X, Y, _children_size.width, _children_size.height));
+        (*it)->SetGeometry(nux::Geometry(X, Y, _children_size.width, _children_size.height));
 
-        (*it)->ComputeLayout2();
+        (*it)->ComputeContentSize();
 
         X += _children_size.width + m_h_in_margin;
 
@@ -342,7 +236,7 @@ namespace nux
 
         if ((!_partial_visibility) && (X + _children_size.width > base.x + base.width))
         {
-          X = base.x + m_h_out_margin;
+          X = base.x + left_padding_;
           Y += _children_size.height + m_v_in_margin;
 
           first_element_of_row = true;
@@ -351,7 +245,7 @@ namespace nux
         }
         else if (X >= base.x + base.width)
         {
-          X = base.x + m_h_out_margin;
+          X = base.x + left_padding_;
           Y += _children_size.height + m_v_in_margin;
 
           first_element_of_row = true;
@@ -364,9 +258,9 @@ namespace nux
     _num_row = num_row;
     _num_column = num_column;
 
-    if ((GetStretchFactor() == 0) || _height_match_content)
+    if ((GetScaleFactor() == 0) || match_content_size_)
     {
-      int h = num_row * _children_size.height + 2 * m_v_out_margin + (num_row - 1) * m_v_in_margin;
+      int h = num_row * _children_size.height + (top_padding_ + bottom_padding_) + (num_row - 1) * m_v_in_margin;
       SetMinimumHeight(h);
       SetBaseHeight(h);
     }
@@ -375,26 +269,26 @@ namespace nux
     {
 #if DEBUG_LAYOUT_COMPUTATION
       // The layout and its content resized together without trouble.
-      std::cout << "ComputeLayout2: GridHLayout Width compliant = " << m_fittingWidth << std::endl;
+      std::cout << "ComputeContentSize: GridHLayout Width compliant = " << m_fittingWidth << std::endl;
 #endif
       size_compliance |= eCompliantWidth;
     }
 
     // The layout has been resized to tightly pack its content
-    if (GetBaseHeight() > original_height + HERROR)
+    if (GetBaseHeight() > original_height)
     {
 #if DEBUG_LAYOUT_COMPUTATION
       // The layout has been resized larger in height to tightly pack its content.
       // Or you can say that the layout refuse to be smaller than total HEIGHT of its elements.
-      std::cout << "ComputeLayout2: GridHLayout Height block at " << GetBaseHeight() << std::endl;
+      std::cout << "ComputeContentSize: GridHLayout Height block at " << GetBaseHeight() << std::endl;
 #endif
       size_compliance |= eLargerHeight; // need scrollbar
     }
-    else if (GetBaseHeight() + HERROR < original_height)
+    else if (GetBaseHeight() < original_height)
     {
 #if DEBUG_LAYOUT_COMPUTATION
       // The layout is smaller.
-      std::cout << "ComputeLayout2: GridHLayout Height is smaller = " << GetBaseHeight() << std::endl;
+      std::cout << "ComputeContentSize: GridHLayout Height is smaller = " << GetBaseHeight() << std::endl;
 #endif
       size_compliance |= eSmallerHeight;
     }
@@ -402,34 +296,185 @@ namespace nux
     {
 #if DEBUG_LAYOUT_COMPUTATION
       // The layout and its content resized together without trouble.
-      std::cout << "ComputeLayout2: GridHLayout Height compliant = " << GetBaseHeight() << std::endl;
+      std::cout << "ComputeContentSize: GridHLayout Height compliant = " << GetBaseHeight() << std::endl;
 #endif
       size_compliance |= eCompliantHeight;
     }
 
-//    if(GetStretchFactor() == 0)
-//    {
-//        return size_compliance | eForceComply;
-//    }
+    //    if (GetScaleFactor() == 0)
+    //    {
+    //        return size_compliance | eForceComply;
+    //    }
 
-    //SetDirty (false);
+    //SetDirty(false);
     return size_compliance;
   }
 
-  void GridHLayout::ProcessDraw (GraphicsEngine &GfxContext, bool force_draw)
+  long GridHLayout::ComputeLayoutColumnOrder()
+  {
+    std::list<Area *> elements;
+
+    if (GetScaleFactor() == 0)
+    {
+      ApplyMinHeight();
+    }
+
+    if (_layout_element_list.size() == 0)
+    {
+      return eCompliantHeight | eCompliantWidth;
+    }
+
+    int num_elements = 0;
+
+    std::list<Area *>::iterator it;
+    for (it = _layout_element_list.begin(); it != _layout_element_list.end(); it++)
+    {
+      if ((*it)->IsVisible())
+      {
+        (*it)->SetLayoutDone(false);
+        elements.push_back(*it);
+        num_elements++;
+      }
+      (*it)->SetLayoutDone(false);
+    }
+
+    int original_width = GetBaseWidth();
+
+    nux::Geometry base = GetGeometry();
+    it = elements.begin();
+    int num_row = 0;
+    int num_column = 0;
+
+    if (num_elements > 0)
+      ++num_column;
+
+    if (_dynamic_column)
+    {
+      int X = base.x + left_padding_;
+      int Y = base.y + top_padding_;
+
+      bool first_element_of_column = true;
+
+      for (int i = 0; i < num_elements; i++)
+      {
+        if (num_column == 1)
+          num_row++;
+
+        if (first_element_of_column)
+        {
+          first_element_of_column = false;
+        }
+
+        if (_force_children_size)
+        {
+          (*it)->SetMinimumSize(_children_size.width, _children_size.height);
+        }
+
+        (*it)->SetGeometry(nux::Geometry(X, Y, _children_size.width, _children_size.height));
+
+        (*it)->ComputeContentSize();
+
+        Y += _children_size.height + m_v_in_margin;
+
+        it++;
+
+        if ((!_partial_visibility) && (Y + _children_size.height > base.y + base.height - top_padding_))
+        {
+          X += _children_size.width + m_h_in_margin;
+          Y = base.y + top_padding_;
+
+          first_element_of_column = true;
+          if (i < num_elements - 1)
+            ++num_column;
+        }
+        else if (Y >= base.y + base.height)
+        {
+          X += _children_size.width + m_h_in_margin;
+          Y = base.y + top_padding_;
+
+          first_element_of_column = true;
+          if (i < num_elements - 1)
+            ++num_column;
+        }
+      }
+    }
+
+    _num_row = num_row;
+    _num_column = num_column;
+
+    if ((GetScaleFactor() == 0) || match_content_size_)
+    {
+      int w = num_column * _children_size.width + (left_padding_ + right_padding_) + (num_column - 1) * m_h_in_margin;
+      SetMinimumWidth(w);
+      SetBaseWidth(w);
+    }
+
+    long size_compliance = 0L;
+
+    if (GetBaseWidth() > original_width)
+    {
+#if DEBUG_LAYOUT_COMPUTATION
+      // The layout has been resized larger in WIDTH to tightly pack its content.
+      // Or you can say that the layout refuse to be smaller than total WIDTH of its elements.
+      std::cout << "ComputeContentSize: VLayout Width block at " << GetWidth() << std::endl;
+#endif
+      size_compliance |= eLargerWidth; // need scrollbar
+    }
+    else if (GetBaseWidth() < original_width)
+    {
+#if DEBUG_LAYOUT_COMPUTATION
+      // The layout is smaller.
+      std::cout << "ComputeContentSize: VLayout Width smaller = " << GetWidth() << std::endl;
+#endif
+      size_compliance |= eSmallerWidth;
+    }
+    else
+    {
+#if DEBUG_LAYOUT_COMPUTATION
+      // The layout and its content resized together without trouble.
+      std::cout << "ComputeContentSize: VLayout Width compliant = " << GetWidth() << std::endl;
+#endif
+      size_compliance |= eCompliantWidth;
+    }
+
+    {
+#if DEBUG_LAYOUT_COMPUTATION
+      // The layout and its content resized together without trouble.
+      std::cout << "ComputeContentSize: VLayout Height compliant = " << m_fittingHeight << std::endl;
+#endif
+      size_compliance |= eCompliantHeight;
+    }
+
+    return size_compliance;
+  }
+
+  long GridHLayout::ComputeContentSize()
+  {
+    if (filling_order_ == FILL_HORIZONTAL)
+    {
+      return ComputeLayoutRowOrder();
+    }
+    else
+    {
+      return ComputeLayoutColumnOrder();
+    }
+  }
+
+  void GridHLayout::ProcessDraw(GraphicsEngine &graphics_engine, bool force_draw)
   {
     if (_layout_element_list.size() == 0)
       return;
 
     std::list<Area *> elements;
-    std::list<Area *>::iterator it = _layout_element_list.begin ();
+    std::list<Area *>::iterator it = _layout_element_list.begin();
 
-    GfxContext.PushModelViewMatrix(Get2DMatrix());
+    graphics_engine.PushModelViewMatrix(Get2DMatrix());
 
     Geometry base = GetGeometry();
     Geometry absolute_geometry = GetAbsoluteGeometry();
     Geometry parent_geometry = absolute_geometry;
     Geometry visibility_geometry = absolute_geometry;
+
     if (GetToplevel())
     {
       parent_geometry = GetToplevel()->GetAbsoluteGeometry();
@@ -437,15 +482,30 @@ namespace nux
 
     visibility_geometry = parent_geometry.Intersect(absolute_geometry);
 
-    GfxContext.PushClippingRectangle(base);
+    graphics_engine.PushClippingRectangle(base);
 
     it = _layout_element_list.begin();
 
     bool first = false;
     bool last = false;
-    for (int j = 0; j < _num_row; j++)
+
+    int JJ = 0;
+    int II = 0;
+
+    if (filling_order_ == FILL_HORIZONTAL)
     {
-      for (int i = 0; i < _num_column; i++)
+      JJ = _num_row;
+      II = _num_column;
+    }
+    else
+    {
+      JJ = _num_column;
+      II = _num_row;
+    }
+
+    for (int j = 0; j < JJ; j++)
+    {
+      for (int i = 0; i < II; i++)
       {
         if (it == _layout_element_list.end())
           break;
@@ -467,23 +527,33 @@ namespace nux
             first = true; // First invisible child.
           }
 
-          int x = base.x + m_h_out_margin + i * (_children_size.width + m_h_in_margin);
-          int y = base.y + m_v_out_margin + j * (_children_size.height + m_v_in_margin);
+          int x = 0;
+          int y = 0;
+          if (filling_order_ == FILL_HORIZONTAL)
+          {
+            x = base.x + left_padding_ + i * (_children_size.width + m_h_in_margin);
+            y = base.y + top_padding_ + j * (_children_size.height + m_v_in_margin);
+          }
+          else
+          {
+            x = base.x + left_padding_ + j * (_children_size.width + m_h_in_margin);
+            y = base.y + top_padding_ + i * (_children_size.height + m_v_in_margin);
+          }
 
-          GfxContext.PushClippingRectangle(Geometry (x, y, _children_size.width, _children_size.height));
+          graphics_engine.PushClippingRectangle(Geometry(x, y, _children_size.width, _children_size.height));
 
           if ((*it)->IsView())
           {
             View *ic = static_cast<View *>(*it);
-            ic->ProcessDraw(GfxContext, force_draw);
+            ic->ProcessDraw(graphics_engine, force_draw);
           }
           else if ((*it)->IsLayout())
           {
             Layout *layout = static_cast<Layout *>(*it);
-            layout->ProcessDraw(GfxContext, force_draw);
+            layout->ProcessDraw(graphics_engine, force_draw);
           }
 
-          GfxContext.PopClippingRectangle();
+          graphics_engine.PopClippingRectangle();
         }
         else
         {
@@ -506,13 +576,13 @@ namespace nux
         break;
     }
 
-    GfxContext.PopClippingRectangle ();
-    GfxContext.PopModelViewMatrix ();
+    graphics_engine.PopClippingRectangle();
+    graphics_engine.PopModelViewMatrix();
 
     _queued_draw = false;
   }
 
-  Area* GridHLayout::KeyNavIteration(KeyNavDirection direction)
+  Area* GridHLayout::KeyNavIterationRowOrder(KeyNavDirection direction)
   {
     if (_layout_element_list.size() == 0)
       return NULL;
@@ -524,18 +594,18 @@ namespace nux
     {
       std::list<Area*>::iterator it;
       std::list<Area*>::iterator it_next;
-      it = std::find (_layout_element_list.begin(), _layout_element_list.end(), next_object_to_key_focus_area_);
+      it = std::find(_layout_element_list.begin(), _layout_element_list.end(), next_object_to_key_focus_area_);
       it_next = it;
       ++it_next;
 
       if (it == _layout_element_list.end())
       {
         // Should never happen
-        nuxAssert (0);
+        nuxAssert(0);
         return NULL;
       }
 
-      int position = GetChildPos(*it); // note that (*it) == next_object_to_key_focus_area_
+      int position = GetChildPos(*it); // note that(*it) == next_object_to_key_focus_area_
       int nun_column = GetNumColumn();
       int nun_row = GetNumRow();
 
@@ -545,21 +615,20 @@ namespace nux
         return NULL;
       }
 
+      if ((direction == KEY_NAV_LEFT) && position % nun_column == 0)
+      {
+        return NULL;
+      }
+
       if ((direction == KEY_NAV_RIGHT) && (it_next == _layout_element_list.end()))
       {
         // last item
         return NULL;
       }
 
-      if ((direction == KEY_NAV_LEFT) && ((position % nun_column) == 0))
+      if ((direction == KEY_NAV_RIGHT) && position % nun_column == nun_column - 1)
       {
-        // Left edge
-        return NULL;
-      }
-      
-      if ((direction == KEY_NAV_RIGHT) && (position == (position / nun_column) * nun_column + (nun_column -1)))
-      {
-        // right edge
+        // last item
         return NULL;
       }
 
@@ -569,7 +638,7 @@ namespace nux
         return NULL;
       }
 
-      if ((direction == KEY_NAV_DOWN) && ((position / nun_column) == nun_row))
+      if ((direction == KEY_NAV_DOWN) && ((position / nun_column) == (nun_row - 1)))
       {
         // bottom edge
         return NULL;
@@ -601,12 +670,12 @@ namespace nux
 
         while (key_nav_focus == NULL)
         {
-          ++it;
           int pos = GetChildPos(*it);
 
           if ((it == _layout_element_list.end()) || (pos == (pos / nun_column) * nun_column + (nun_column -1)))
             break;
 
+          ++it;
           key_nav_focus = (*it)->KeyNavIteration(direction);
         }
 
@@ -619,12 +688,145 @@ namespace nux
         {
           --it;
         }
-        return (*it)->KeyNavIteration(direction);
+
+        if (it != _layout_element_list.end())
+          return (*it)->KeyNavIteration(direction);
       }
 
       if (direction == KEY_NAV_DOWN)
       {
         for (int i = 0; i < nun_column; ++i)
+        {
+          ++it;
+        }
+
+        if (it != _layout_element_list.end())
+          return (*it)->KeyNavIteration(direction);
+      }
+    }
+    else
+    {
+      std::list<Area*>::iterator it;
+      it = _layout_element_list.begin();
+      return (*it)->KeyNavIteration(direction);
+    }
+
+    return NULL;
+  }
+
+  Area* GridHLayout::KeyNavIterationColumnOrder(KeyNavDirection direction)
+  {
+    if (_layout_element_list.size() == 0)
+      return NULL;
+
+    if (IsVisible() == false)
+      return NULL;
+
+    if (next_object_to_key_focus_area_)
+    {
+      std::list<Area*>::iterator it;
+      std::list<Area*>::iterator it_next;
+      it = std::find(_layout_element_list.begin(), _layout_element_list.end(), next_object_to_key_focus_area_);
+      it_next = it;
+      ++it_next;
+
+      if (it == _layout_element_list.end())
+      {
+        // Should never happen
+        nuxAssert(0);
+        return NULL;
+      }
+
+      int position = GetChildPos(*it); // note that(*it) == next_object_to_key_focus_area_
+      int nun_column = GetNumColumn();
+      int nun_row = GetNumRow();
+
+      if ((direction == KEY_NAV_UP) && (it == _layout_element_list.begin()))
+      {
+        // first item
+        return NULL;
+      }
+
+      if ((direction == KEY_NAV_DOWN) && (it_next == _layout_element_list.end()))
+      {
+        // last item
+        return NULL;
+      }
+
+      if ((direction == KEY_NAV_UP) && ((position % nun_row) == 0))
+      {
+        // Left edge
+        return NULL;
+      }
+
+      if ((direction == KEY_NAV_DOWN) && (position == (position / nun_row) * nun_row + (nun_row -1)))
+      {
+        // right edge
+        return NULL;
+      }
+
+      if ((direction == KEY_NAV_LEFT) && ((position / nun_row) == 0))
+      {
+        // top edge
+        return NULL;
+      }
+
+      if ((direction == KEY_NAV_RIGHT) && ((position / nun_row) == nun_column))
+      {
+        // bottom edge
+        return NULL;
+      }
+
+      //////
+      if (direction == KEY_NAV_UP)
+      {
+        --it;
+        Area* key_nav_focus = (*it)->KeyNavIteration(direction);
+
+        while (key_nav_focus == NULL)
+        {
+          int pos = GetChildPos(*it);
+          if (it == _layout_element_list.begin() || ((pos % nun_row) == 0))
+            break;
+
+          --it;
+          key_nav_focus = (*it)->KeyNavIteration(direction);
+        }
+
+        return key_nav_focus;
+      }
+
+      if (direction == KEY_NAV_DOWN)
+      {
+        ++it;
+        Area* key_nav_focus = (*it)->KeyNavIteration(direction);
+
+        while (key_nav_focus == NULL)
+        {
+          ++it;
+          int pos = GetChildPos(*it);
+
+          if ((it == _layout_element_list.end()) || (pos == (pos / nun_row) * nun_row + (nun_row -1)))
+            break;
+
+          key_nav_focus = (*it)->KeyNavIteration(direction);
+        }
+
+        return key_nav_focus;
+      }
+
+      if (direction == KEY_NAV_LEFT)
+      {
+        for (int i = 0; i < nun_row; ++i)
+        {
+          --it;
+        }
+        return (*it)->KeyNavIteration(direction);
+      }
+
+      if (direction == KEY_NAV_RIGHT)
+      {
+        for (int i = 0; i < nun_row; ++i)
         {
           ++it;
           if (it == _layout_element_list.end())
@@ -641,5 +843,28 @@ namespace nux
     }
 
     return NULL;
+
+  }
+
+  Area* GridHLayout::KeyNavIteration(KeyNavDirection direction)
+  {
+    if (filling_order_ == FILL_HORIZONTAL)
+    {
+      return KeyNavIterationRowOrder(direction);
+    }
+    else
+    {
+      return KeyNavIterationColumnOrder(direction);
+    }
+  }
+
+  void GridHLayout::SetFillingOrder(FillingOrder filling_order)
+  {
+    filling_order_ = filling_order;
+  }
+
+  GridHLayout::FillingOrder GridHLayout::GetFillingOrder() const
+  {
+    return filling_order_;
   }
 }
