@@ -54,23 +54,23 @@ namespace nux
     virtual ~BaseKeyboardHandler();
 
 
-    virtual long ProcessKey (
+    virtual long ProcessKey(
       unsigned long    eventType    /*event type*/,
       unsigned long    keysym       /*event keysym*/,
       unsigned long    state        /*event state*/,
-      TCHAR      character    /*character*/,
+      char      character    /*character*/,
       const Geometry &g);
 
     NString GetTextLine() const
     {
       return m_textline;
     }
-    t_u32 GetLength() const
+    unsigned int GetLength() const
     {
-      return (t_u32) m_textline.Length();
+      return (unsigned int) m_textline.Length();
     }
 
-    t_u32 GetCursorPosition() const
+    unsigned int GetCursorPosition() const
     {
       return m_caret;
     }
@@ -78,72 +78,72 @@ namespace nux
     {
       return m_need_redraw;
     }
-    t_s32 GetPositionX() const
+    int GetPositionX() const
     {
       return m_text_positionx;
     }
-    t_s32 GetPositionY() const
+    int GetPositionY() const
     {
       return m_text_positiony;
     }
 
-    void SetText (const TCHAR *str);
-    void SetText (const tstring &s);
-    void SetText (const NString &s);
+    void SetText(const char *str);
+    void SetText(const tstring &s);
+    void SetText(const NString &s);
 
     void ClearText();
-    void PlaceCaret (t_u32 cp);
+    void PlaceCaret(unsigned int cp);
 
     void MoveCursorAtStart();
     void MoveCursorAtEnd();
 
-    void SetKeyEntryType (eKeyEntryType keytype);
+    void SetKeyEntryType(eKeyEntryType keytype);
     eKeyEntryType GetKeyEntryType();
 
-    void SetClipRegion (const Geometry &g);
-    void GetTextSelection (t_s32 *start, t_s32 *end) const;
-    t_s32 GetTextSelectionStart() const;
-    t_s32 GetTextSelectionEnd() const;
+    void SetClipRegion(const Geometry &g);
+    void GetTextSelection(int *start, int *end) const;
+    int GetTextSelectionStart() const;
+    int GetTextSelectionEnd() const;
     NString GetSelectedText() const;
     void SelectAllText();
     void UnselectAllText();
     bool IsTextSelected();
 
-    void SetPrefix (NString); // 0x865, 25 rad, 25 degree...
-    void SetPostfix (NString);
+    void SetPrefix(NString); // 0x865, 25 rad, 25 degree...
+    void SetPostfix(NString);
 
     void EnterFocus();
 
-    t_u32 NextWordPosition (t_u32 cp);
-    t_u32 PrevWordPosition (t_u32 cp);
-    void ResolveCaretPosition (t_s32 x, t_s32 y);
-    void CaretAutoScroll (t_s32 x, t_s32 y, Geometry geo);
-    void MouseDown (t_s32 x, t_s32 y);
-    void MouseUp (t_s32 x, t_s32 y);
-    void MouseDrag (t_s32 x, t_s32 y);
+    unsigned int NextWordPosition(unsigned int cp);
+    unsigned int PrevWordPosition(unsigned int cp);
+    void ResolveCaretPosition(int x, int y);
+    void CaretAutoScroll(int x, int y, Geometry geo);
+    void MouseDown(int x, int y);
+    void MouseUp(int x, int y);
+    void MouseDrag(int x, int y);
     //bool IsMouseDrag();
 
-    void SetFont (ObjectPtr<FontTexture> Font);
-    ObjectPtr<FontTexture> GetFont () const;
+    void SetFont(ObjectPtr<FontTexture> Font);
+    ObjectPtr<FontTexture> GetFont() const;
 
   protected:
     ObjectPtr<FontTexture> m_Font;
     NString m_textline;
-    t_s32 m_previous_cursor_position;
+    int m_previous_cursor_position;
     bool m_need_redraw;
-    t_s32 m_text_positionx;
-    t_s32 m_text_positiony;
+    int m_text_positionx;
+    int m_text_positiony;
     Geometry m_clip_region;
 
     eKeyEntryType m_KeyType;
 
-    t_s32   m_caret;           //!< Caret position, in characters
+    int   m_caret;           //!< Caret position, in characters
     bool    m_insert_mode;     //!< If true, control is in insert mode. Else, overwrite mode.
-    t_s32   m_selection_start; //!< Starting position of the selection. The caret marks the end.
-    t_s32   m_first_visible_char;   //!< First visible character in the edit control
+    int   m_selection_start; //!< Starting position of the selection. The caret marks the end.
+    int   m_first_visible_char;   //!< First visible character in the edit control
 
     void DeleteSelectionText();
-    void InsertChar (t_u32 character);
+    void InsertChar(unsigned int character);
     void AdjustCursorAndTextPosition();
 
 
@@ -156,8 +156,8 @@ namespace nux
         When the caret reaches the left or right border of the control and there are more characters to reveals,
         the caret jumps back in the opposite direction by a number of pixel at the same moment when new characters are revealed.
     */
-    static t_s32 s_jump_offset_at_borders;
-    static t_s32 s_cursor_width;
+    static int s_jump_offset_at_borders;
+    static int s_cursor_width;
   };
 
 }
