@@ -29,25 +29,25 @@
 
 namespace nux
 {
-  NUX_IMPLEMENT_OBJECT_TYPE (StaticTextBox);
+  NUX_IMPLEMENT_OBJECT_TYPE(StaticTextBox);
 
-  StaticTextBox::StaticTextBox (const TCHAR *Caption, NUX_FILE_LINE_DECL)
-    :   View (NUX_FILE_LINE_PARAM)
-    ,   m_TextAlignment (eAlignTextLeft)
-    ,   m_bMinimumWidthMatchText (true)
-    ,   m_bDrawBackground (false)
-    ,   m_WriteAlpha (true)
+  StaticTextBox::StaticTextBox(const char *Caption, NUX_FILE_LINE_DECL)
+    :   View(NUX_FILE_LINE_PARAM)
+    ,   m_TextAlignment(eAlignTextLeft)
+    ,   m_bMinimumWidthMatchText(true)
+    ,   m_bDrawBackground(false)
+    ,   m_WriteAlpha(true)
   {
-    m_BackgroundColor = Color (0xFF343434);
-    m_TextColor = Color (1.0f, 1.0f, 1.0f, 1.0f);
+    m_BackgroundColor = Color(0xFF343434);
+    m_TextColor = Color(1.0f, 1.0f, 1.0f, 1.0f);
     // First, set the default minimum size.
-    SetMinimumSize (DEFAULT_WIDGET_WIDTH, PRACTICAL_WIDGET_HEIGHT);
+    SetMinimumSize(DEFAULT_WIDGET_WIDTH, PRACTICAL_WIDGET_HEIGHT);
 
     // The width size of the text is computed in SetText and set as the minimum for the widget.
     // If the text is null or empty, then the default minimum widtth set above remains.
-    SetText (Caption);
+    SetText(Caption);
 
-    SetGeometry (Geometry (0, 0, 3 * DEFAULT_WIDGET_WIDTH, DEFAULT_WIDGET_HEIGHT) );
+    SetGeometry(Geometry(0, 0, 3 * DEFAULT_WIDGET_WIDTH, DEFAULT_WIDGET_HEIGHT));
 
     // This widget does not use a layout!
     m_Background = 0;
@@ -58,75 +58,67 @@ namespace nux
     delete m_Background;
   }
 
-  long StaticTextBox::ProcessEvent (IEvent &ievent, long TraverseInfo, long ProcessEventInfo)
-  {
-    long ret = TraverseInfo;
-
-    ret = PostProcessEvent2 (ievent, ret, ProcessEventInfo);
-    return ret;
-  }
-
-  void StaticTextBox::Draw (GraphicsEngine &GfxContext, bool force_draw)
+  void StaticTextBox::Draw(GraphicsEngine &graphics_engine, bool force_draw)
   {
     Geometry base = GetGeometry();
     {
-      GfxContext.PushClippingRectangle (base);
+      graphics_engine.PushClippingRectangle(base);
 
       if (m_bDrawBackground)
       {
-        GetPainter().PushDrawLayer (GfxContext, base, m_Background);
-        GetPainter().PaintTextLineStatic (GfxContext, GetFont (), GetGeometry(), m_Text.GetTCharPtr(), m_TextColor, m_WriteAlpha, m_TextAlignment);
+        GetPainter().PushDrawLayer(graphics_engine, base, m_Background);
+        GetPainter().PaintTextLineStatic(graphics_engine, GetFont(), GetGeometry(), m_Text.GetTCharPtr(), m_TextColor, m_WriteAlpha, m_TextAlignment);
         GetPainter().PopBackground();
       }
       else
       {
-        //GetPainter().PaintBackground(GfxContext, base);
-        GetPainter().PaintTextLineStatic (GfxContext, GetFont (), GetGeometry(), m_Text.GetTCharPtr(), m_TextColor, m_WriteAlpha, m_TextAlignment);
+        //GetPainter().PaintBackground(graphics_engine, base);
+        GetPainter().PaintTextLineStatic(graphics_engine, GetFont(), GetGeometry(), m_Text.GetTCharPtr(), m_TextColor, m_WriteAlpha, m_TextAlignment);
       }
 
-      GfxContext.PopClippingRectangle();
+      graphics_engine.PopClippingRectangle();
     }
   }
 
-  void StaticTextBox::DrawContent (GraphicsEngine &GfxContext, bool force_draw)
+  void StaticTextBox::DrawContent(GraphicsEngine &graphics_engine, bool force_draw)
   {
 
   }
 
-  void StaticTextBox::PostDraw (GraphicsEngine &GfxContext, bool force_draw)
+  void StaticTextBox::PostDraw(GraphicsEngine &graphics_engine, bool force_draw)
   {
 
   }
 
-  void StaticTextBox::SetText (const TCHAR &Caption)
+  void StaticTextBox::SetText(const char &Caption)
   {
-    NString s (Caption);
-    SetText (s);
+    NString s(Caption);
+    SetText(s);
   }
 
-  void StaticTextBox::SetText (const TCHAR *Caption)
+  void StaticTextBox::SetText(const char *Caption)
   {
-    NString s (Caption);
-    SetText (s);
+    NString s(Caption);
+    SetText(s);
   }
 
-  void StaticTextBox::SetText (const tstring &Caption)
+  void StaticTextBox::SetText(const tstring &Caption)
   {
-    NString s (Caption);
-    SetText (s);
+    NString s(Caption);
+    SetText(s);
   }
 
-  void StaticTextBox::SetText (const NString &Caption)
+  void StaticTextBox::SetText(const NString &Caption)
   {
     m_Text = Caption;
 
-    if (GetMinWidthMatchText() )
+    if (GetMinWidthMatchText())
       AdjustMinWidthToMatchText();
 
     QueueDraw();
   }
 
-  void StaticTextBox::SetMinWidthMatchText (bool b)
+  void StaticTextBox::SetMinWidthMatchText(bool b)
   {
     m_bMinimumWidthMatchText = b;
 
@@ -144,18 +136,18 @@ namespace nux
     if (m_Text.Size() == 0)
       return;
 
-    SetMinimumWidth (/*4 + */GetFont ()->GetStringWidth (m_Text.GetTStringRef() ) );
+    SetMinimumWidth(/*4 + */GetFont()->GetStringWidth(m_Text.GetTStringRef()));
   }
 
-  void StaticTextBox::SetFont (ObjectPtr<FontTexture> Font)
+  void StaticTextBox::SetFont(ObjectPtr<FontTexture> Font)
   {
-    View::SetFont (Font);
+    View::SetFont(Font);
 
-    if (GetMinWidthMatchText() )
+    if (GetMinWidthMatchText())
       AdjustMinWidthToMatchText();
   }
 
-  void StaticTextBox::SetBackground (AbstractPaintLayer *layer)
+  void StaticTextBox::SetBackground(AbstractPaintLayer *layer)
   {
     delete m_Background;
     m_Background = layer->Clone();
