@@ -7,7 +7,7 @@
 /*
   Copyright 2008 Google Inc.
 
-  Licensed under the Apache License, Version 2.0 (the "License");
+  Licensed under the Apache License, Version 2.0(the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at
 
@@ -29,6 +29,7 @@
 namespace nux
 {
   class CairoGraphics;
+  class IBusIMEContext;
 
   class CairoFont
   {
@@ -75,31 +76,32 @@ namespace nux
 
   class TextEntry: public View
   {
-    NUX_DECLARE_OBJECT_TYPE (TextEntry, View);
+    NUX_DECLARE_OBJECT_TYPE(TextEntry, View);
   public:
-    TextEntry (const TCHAR* text, NUX_FILE_LINE_PROTO);
-    ~TextEntry ();
+    TextEntry(const char* text, NUX_FILE_LINE_PROTO);
+    ~TextEntry();
 
     Area* FindAreaUnderMouse(const Point& mouse_position, NuxEventType event_type);
-    virtual long ProcessEvent (IEvent &ievent, long TraverseInfo, long ProcessEventInfo);
-    virtual void Draw (GraphicsEngine &GfxContext, bool force_draw);
-    virtual void DrawContent (GraphicsEngine &GfxContext, bool force_draw);
-    virtual void PostDraw (GraphicsEngine &GfxContext, bool force_draw);
+    virtual void Draw(GraphicsEngine& graphics_engine, bool force_draw);
+    virtual void DrawContent(GraphicsEngine& graphics_engine, bool force_draw);
+    virtual void PostDraw(GraphicsEngine& graphics_engine, bool force_draw);
 
-    void PreLayoutManagement ();
-    long PostLayoutManagement (long layoutResult);
+    void PreLayoutManagement();
+    long PostLayoutManagement(long layoutResult);
 
     //  Receivers
 
-    void RecvMouseDoubleClick (int x, int y, unsigned long button_flags, unsigned long key_flags);
-    void RecvMouseUp (int x, int y, unsigned long button_flags, unsigned long key_flags);
-    void RecvMouseDown (int x, int y, unsigned long button_flags, unsigned long key_flags);
-    void RecvMouseDrag (int x, int y, int dx, int dy, unsigned long button_flags, unsigned long key_flags);
-    void RecvKeyEvent (
+    void RecvMouseDoubleClick(int x, int y, unsigned long button_flags, unsigned long key_flags);
+    void RecvMouseUp(int x, int y, unsigned long button_flags, unsigned long key_flags);
+    void RecvMouseDown(int x, int y, unsigned long button_flags, unsigned long key_flags);
+    void RecvMouseDrag(int x, int y, int dx, int dy, unsigned long button_flags, unsigned long key_flags);
+    void RecvMouseEnter(int x, int y, unsigned long button_flags, unsigned long key_flags);
+    void RecvMouseLeave(int x, int y, unsigned long button_flags, unsigned long key_flags);
+    void RecvKeyEvent(
       unsigned long    eventType  ,   /*event type*/
       unsigned long    keysym     ,   /*event keysym*/
       unsigned long    state      ,   /*event state*/
-      const TCHAR*     character  ,   /*character*/
+      const char*     character  ,   /*character*/
       unsigned short   keyCount       /*key repeat count*/);
 
     void RecvStartKeyFocus();
@@ -108,34 +110,41 @@ namespace nux
     bool _size_match_text;
     BaseTexture *_texture2D;
 
-    void MainDraw ();
-    void ProcessMouseEvent (int event_type, int x, int y, int dx, int dy, unsigned long button_flags, unsigned long key_flags);
+    void MainDraw();
+    void ProcessMouseEvent(int event_type, int x, int y, int dx, int dy, unsigned long button_flags, unsigned long key_flags);
     void ProcessKeyEvent   (
       unsigned long    eventType  ,   /*event type*/
       unsigned long    keysym     ,   /*event keysym*/
       unsigned long    state      ,   /*event state*/
-      const TCHAR*     character  ,   /*character*/
+      const char*     character  ,   /*character*/
       unsigned short   keyCount       /*key repeat count*/);
 
-    void FocusInx ();
-    void FocusOutx ();
+    void FocusInx();
+    void FocusOutx();
 
     //! Text changed signal
     /*!
         This signal is emitted when the text has changed.
     */
-    sigc::signal <void, TextEntry*> sigTextChanged;
+    sigc::signal <void, TextEntry*> text_changed;
     sigc::signal <void> activated;
     sigc::signal <void, int> cursor_moved;
 
-    void SetText(const char *text);
+    void SetText(const char* text);
     std::string const& GetText() const;
+    std::string GetTextSelection() const;
 
-    void SetTextColor(const Color &color);
+    void SetCompletion(const char* text); // Should use std::string, does not for consistancy
+    std::string const& GetCompletion() const;
+
+    void SetCompletionColor(const Color& color);
+    Color const& GetCompletionColor() const;
+
+    void SetTextColor(const Color& color);
     Color const& GetTextColor() const;
-    void SetFontFamily (const char *font);
-    void SetFontSize (double font_size);
-    void SetFontOptions (const cairo_font_options_t *options);
+    void SetFontFamily(const char* font);
+    void SetFontSize(double font_size);
+    void SetFontOptions(const cairo_font_options_t* options);
 
     /** Select text between start and end. */
     void Select(int start, int end);
@@ -145,11 +154,63 @@ namespace nux
     CairoGraphics::Alignment GetAlign() const;
     void SetAlign(CairoGraphics::Alignment align);
 
+    bool im_active();
+
+    void MoveCursorToLineStart();
+    void MoveCursorToLineEnd();
+
+
+    /*!
+        When the text entry is in single line mode, the keyboard arrow up/down may be used 
+        to navigate to another view. If the parameter of this function is set to true then 
+        the text entry returns false on NUX_VK_UP in InspectKeyEvent(). This allows the parent of the
+        text entry to look for another view that can receive the keyboard focus. The default value is true.\n
+        In multi-line mode, keyboard arrow up/down are used to navigate in the text.
+
+        @param b True to allow the key navigation to move away from the text entry on NUX_VK_UP.
+    */
+    void SetLoseKeyFocusOnKeyNavDirectionUp(bool b);
+
+    bool GetLoseKeyFocusOnKeyNavDirectionUp() const;
+
+    /*!
+        When the text entry is in single line mode, the keyboard arrow up/down may be used 
+        to navigate to another view. If the parameter of this function is set to true then 
+        the text entry returns false on NUX_VK_DOWN in InspectKeyEvent(). This allows the parent of the
+        text entry to look for another view that can receive the keyboard focus.  The default value is true.\n
+        In multi-line mode, keyboard arrow up/down are used to navigate in the text.
+
+        @param b True to allow the key navigation to move away from the text entry on NUX_VK_DOWN.
+    */    
+    void SetLoseKeyFocusOnKeyNavDirectionDown(bool b);
+
+    bool GetLoseKeyFocusOnKeyNavDirectionDown() const;
+    
+    /*!
+        Return True if the text has been modified after the text entry has received the keyboard focus.\n
+        If the text entry already has characters typed in and it gets the keyboard focus, this function return false
+        while the text has not been modified. The text can be modified either by typing new characters or addind text
+        through TextEntry::SetText, TextEntry::EnterText, TextEntry::DeleteText.
+        If this text entry does not have the keyboard focus, this function returns false.
+
+        @return True after the text entry has received the keyboard focus and text has been typed in.
+    */
+    bool IsInTextInputMode() const;
+
+    /*!
+        Insert text at current caret position.
+    */
+    void EnterText(const char* str);
+    
+    /*!
+        Delete text in a specified range, in number of characters.
+    */
+    void DeleteText(int start, int end);
+
   protected:
-    virtual void DoSetFocused (bool focused);
     bool _block_focus; // used to selectively ignore focus keyevents
 
-    virtual void GeometryChanged ();
+    virtual void GeometryChanged();
 
     /**
      * Enum used to specify different motion types.
@@ -163,7 +224,22 @@ namespace nux
       BUFFER
     };
 
-    void QueueTextDraw ();
+    /**
+     * Enum used for the search state of the compose list
+     */
+    enum SearchState {
+      NO_MATCH,
+      PARTIAL,
+      MATCH
+    };
+
+    /** Checks for possible dead key sequences */
+    bool HandledDeadKeys(int keysym, int state, const char* character);
+
+    /** Checks for possible composition sequences */
+    bool HandledComposition(int keysym, const char* character);
+    
+    void QueueTextDraw();
     /** Remove the cached layout. */
     void ResetLayout();
     /**
@@ -189,17 +265,17 @@ namespace nux
     void ResetPreedit();
     /** Send out a request to blink the cursor if necessary */
     void QueueCursorBlink();
-    static bool CursorBlinkCallback(TextEntry *data);
+    static bool CursorBlinkCallback(TextEntry* data);
 
     void ShowCursor();
     void HideCursor();
 
     /** Draw the Cursor to the canvas */
-    void DrawCursor(CairoGraphics *canvas);
+    void DrawCursor(CairoGraphics* canvas);
     /** Draw the text to the canvas */
-    void DrawText(CairoGraphics *canvas);
+    void DrawText(CairoGraphics* canvas);
 
-    void GetCursorRects(Rect *strong, Rect *weak);
+    void GetCursorRects(Rect* strong, Rect* weak);
 
     void UpdateCursorRegion();
 
@@ -224,7 +300,7 @@ namespace nux
      * coordinate in the layout */
     int XYToTextIndex(int x, int y);
     /** Get the offset range that is currently selected,in number of characters.*/
-    bool GetSelectionBounds(int *start, int *end);
+    bool GetSelectionBounds(int* start, int* end) const;
     /** Set the offest range that should be selected, in number of characters. */
     void SetSelectionBounds(int selection_bound, int cursor);
 
@@ -240,11 +316,6 @@ namespace nux
     /** Get previous char length before index, in number of bytes. */
     int GetPrevCharLength(int index);
 
-    /** Insert text at current caret position */
-    void EnterText(const char *str);
-    /** Delete text in a specified range, in number of characters. */
-    void DeleteText(int start, int end);
-
     /** Select the current word under cursor */
     void SelectWord();
     /** Select the current display line under cursor */
@@ -273,8 +344,10 @@ namespace nux
     /**
      * Gets the cursor location in pango layout. The unit is pixel.
      */
-    void GetCursorLocationInLayout(int *strong_x, int *strong_y, int *strong_height,
-                                   int *weak_x, int *weak_y, int *weak_height);
+    void GetCursorLocationInLayout(int* strong_x, int* strong_y, int* strong_height,
+                                   int* weak_x, int* weak_y, int* weak_height);
+
+    int LookForMatch(std::string& str);
 
     /** The CairoCanvas which hold cairo_t inside */
     CairoGraphics* canvas_;
@@ -283,19 +356,25 @@ namespace nux
     PangoLayout* cached_layout_;
 
     /** The text content of the edit control */
-    std::string _text;
+    std::string text_;
     /** The preedit text of the edit control */
-    std::string _preedit;
+    std::string preedit_;
     /** Attribute list of the preedit text */
-    PangoAttrList *preedit_attrs_;
+    PangoAttrList* preedit_attrs_;
     /**
      *  The character that should be displayed in invisible mode.
      *  If this is empty, then the edit control is visible
      */
     std::string password_char_;
 
+    /** The completion string */
+    std::string completion_;
+
+    /** The completion colour */
+    Color completion_color_;
+
     /** Last time of mouse double click event. */
-    t_u64 last_dblclick_time_;
+    unsigned long long last_dblclick_time_;
 
     /** The current cursor position in number of bytes. */
     int cursor_;
@@ -375,23 +454,42 @@ namespace nux
     /** The font size of the text */
     double font_size_;
 
-    cairo_font_options_t *font_options_;
+    cairo_font_options_t* font_options_;
     double font_dpi_;
 
     /** The text color of the edit control */
     Color _text_color;
 
     CairoGraphics::Alignment align_;
+    
+#if defined(NUX_OS_LINUX)
+    Cursor caret_cursor_;
+#endif
 
     std::list<Rect> last_selection_region_;
     std::list<Rect> selection_region_;
     std::list<Rect> last_cursor_region_;
     std::list<Rect> cursor_region_;
 
-  protected:
-    bool text_input_mode_;
+#if defined(NUX_OS_LINUX)
+    IBusIMEContext* ime_;
+    friend class IBusIMEContext;
+#endif
+
+    bool ime_active_;
+
+    bool text_input_mode_;    //!< Transient state of the TextEntry. \sa IsInTextInputMode.
     bool key_nav_mode_;
 
+    bool lose_key_focus_on_key_nav_direction_up_;
+    bool lose_key_focus_on_key_nav_direction_down_;
+
+    bool dead_key_mode_;
+    std::string dead_key_string_;
+
+    bool composition_mode_;
+    std::string composition_string_;
+
     virtual bool InspectKeyEvent(unsigned int eventType,
       unsigned int keysym,
       const char* character);
