@@ -32,12 +32,12 @@
 namespace nux
 {
 
-  NUX_IMPLEMENT_OBJECT_TYPE (VSplitter);
-  static const t_s32 VSPLITTERWIDTH = 5;
-  static const t_s32 VSTICK_SIZE = 5;
+  NUX_IMPLEMENT_OBJECT_TYPE(VSplitter);
+  static const int VSPLITTERWIDTH = 5;
+  static const int VSTICK_SIZE = 5;
 
-  VSplitter::VSplitter (NUX_FILE_LINE_DECL)
-    :   View (NUX_FILE_LINE_PARAM)
+  VSplitter::VSplitter(NUX_FILE_LINE_DECL)
+    :   View(NUX_FILE_LINE_PARAM)
   {
     new_addition = false;
     m_initial_config = true;
@@ -52,7 +52,7 @@ namespace nux
     m_current_height = 100;
 
     //SetMinimumSize(m_current_width, m_current_height);
-    SetGeometry (Geometry (m_current_x, m_current_y, m_current_width, m_current_height) );
+    SetGeometry(Geometry(m_current_x, m_current_y, m_current_width, m_current_height));
   }
 
   VSplitter::~VSplitter()
@@ -76,46 +76,46 @@ namespace nux
     m_SplitConfig.clear();
   }
 
-  void VSplitter::Draw (GraphicsEngine &GfxContext, bool force_draw)
+  void VSplitter::Draw(GraphicsEngine &graphics_engine, bool force_draw)
   {
     Geometry base = GetGeometry();
-    GfxContext.PushClippingRectangle (base);
+    graphics_engine.PushClippingRectangle(base);
     std::vector<Area *>::iterator it;
 
-    GetPainter().PaintBackground (GfxContext, base);
+    GetPainter().PaintBackground(graphics_engine, base);
     std::vector<MySplitter *>::iterator it_splitter;
 
     for (it_splitter = m_SplitterObject.begin(); it_splitter != m_SplitterObject.end(); it_splitter++)
     {
       Geometry geo = (*it_splitter)->GetGeometry();
       Geometry grip_geo;
-      t_s32 h = 20;
+      int h = 20;
 
       if (geo.GetHeight() > h)
       {
-        grip_geo.SetX (geo.x);
-        grip_geo.SetY (geo.y + (geo.GetHeight() - h) / 2);
-        grip_geo.SetWidth (geo.GetWidth() );
-        grip_geo.SetHeight (h);
+        grip_geo.SetX(geo.x);
+        grip_geo.SetY(geo.y + (geo.GetHeight() - h) / 2);
+        grip_geo.SetWidth(geo.GetWidth());
+        grip_geo.SetHeight(h);
       }
       else
       {
-        grip_geo.SetX (geo.x);
-        grip_geo.SetY (geo.y + (h - geo.GetHeight() ) / 2);
-        grip_geo.SetWidth (geo.GetWidth() );
-        grip_geo.SetHeight (h);
+        grip_geo.SetX(geo.x);
+        grip_geo.SetY(geo.y + (h - geo.GetHeight()) / 2);
+        grip_geo.SetWidth(geo.GetWidth());
+        grip_geo.SetHeight(h);
       }
 
-      GetPainter().Draw2DLine (GfxContext, grip_geo.x + 1, grip_geo.y, grip_geo.x + 1, grip_geo.y + grip_geo.GetHeight(), Color (0xFF111111) );
-      GetPainter().Draw2DLine (GfxContext, grip_geo.x + 3, grip_geo.y, grip_geo.x + 3, grip_geo.y + grip_geo.GetHeight(), Color (0xFF111111) );
+      GetPainter().Draw2DLine(graphics_engine, grip_geo.x + 1, grip_geo.y, grip_geo.x + 1, grip_geo.y + grip_geo.GetHeight(), Color(0xFF111111));
+      GetPainter().Draw2DLine(graphics_engine, grip_geo.x + 3, grip_geo.y, grip_geo.x + 3, grip_geo.y + grip_geo.GetHeight(), Color(0xFF111111));
     }
 
-    GfxContext.PopClippingRectangle();
+    graphics_engine.PopClippingRectangle();
   }
 
-  void VSplitter::DrawContent (GraphicsEngine &GfxContext, bool force_draw)
+  void VSplitter::DrawContent(GraphicsEngine &graphics_engine, bool force_draw)
   {
-    GfxContext.PushClippingRectangle (GetGeometry() );
+    graphics_engine.PushClippingRectangle(GetGeometry());
     Geometry base = GetGeometry();
     bool need_redraw = IsRedrawNeeded();
 
@@ -127,115 +127,115 @@ namespace nux
          it++, it_splitter++)
     {
       Geometry sgeo = (*it_splitter)->GetGeometry();
-      GfxContext.PushClippingRectangle (Rect (
-                                          base.x, base.y, sgeo.x - base.x, base.GetHeight() ) );
+      graphics_engine.PushClippingRectangle(Rect(
+                                          base.x, base.y, sgeo.x - base.x, base.GetHeight()));
 
-      base.SetX (sgeo.x + sgeo.GetWidth() );
+      base.SetX(sgeo.x + sgeo.GetWidth());
 
       if (force_draw || need_redraw)
       {
-        if ( (*it)->Type().IsDerivedFromType (View::StaticObjectType) )
+        if ((*it)->Type().IsDerivedFromType(View::StaticObjectType))
         {
-          View *ic = NUX_STATIC_CAST (View *, (*it) );
-          ic->ProcessDraw (GfxContext, true);
+          View *ic = NUX_STATIC_CAST(View *, (*it));
+          ic->ProcessDraw(graphics_engine, true);
         }
-        else if ( (*it)->Type().IsObjectType (InputArea::StaticObjectType) )
+        else if ((*it)->Type().IsObjectType(InputArea::StaticObjectType))
         {
-          InputArea *base_area = NUX_STATIC_CAST (InputArea *, (*it) );
-          base_area->OnDraw (GfxContext, true);
+          InputArea *base_area = NUX_STATIC_CAST(InputArea *, (*it));
+          base_area->OnDraw(graphics_engine, true);
         }
-        else if ( (*it)->Type().IsObjectType (HLayout::StaticObjectType) )
+        else if ((*it)->Type().IsObjectType(HLayout::StaticObjectType))
         {
-          HLayout *layout = NUX_STATIC_CAST (HLayout *, (*it) );
-          layout->ProcessDraw (GfxContext, true);
+          HLayout *layout = NUX_STATIC_CAST(HLayout *, (*it));
+          layout->ProcessDraw(graphics_engine, true);
         }
-        else if ( (*it)->Type().IsObjectType (VLayout::StaticObjectType) )
+        else if ((*it)->Type().IsObjectType(VLayout::StaticObjectType))
         {
-          VLayout *layout = NUX_STATIC_CAST (VLayout *, (*it) );
-          layout->ProcessDraw (GfxContext, true);
+          VLayout *layout = NUX_STATIC_CAST(VLayout *, (*it));
+          layout->ProcessDraw(graphics_engine, true);
         }
       }
       else
       {
-        if ( (*it)->Type().IsDerivedFromType (View::StaticObjectType) )
+        if ((*it)->Type().IsDerivedFromType(View::StaticObjectType))
         {
-          View *ic = NUX_STATIC_CAST (View *, (*it) );
-          ic->ProcessDraw (GfxContext, false);
+          View *ic = NUX_STATIC_CAST(View *, (*it));
+          ic->ProcessDraw(graphics_engine, false);
         }
-        else if ( (*it)->Type().IsObjectType (InputArea::StaticObjectType) )
+        else if ((*it)->Type().IsObjectType(InputArea::StaticObjectType))
         {
-          InputArea *base_area = NUX_STATIC_CAST (InputArea *, (*it) );
-          base_area->OnDraw (GfxContext, false);
+          InputArea *base_area = NUX_STATIC_CAST(InputArea *, (*it));
+          base_area->OnDraw(graphics_engine, false);
         }
-        else if ( (*it)->Type().IsObjectType (HLayout::StaticObjectType) )
+        else if ((*it)->Type().IsObjectType(HLayout::StaticObjectType))
         {
-          HLayout *layout = NUX_STATIC_CAST (HLayout *, (*it) );
-          layout->ProcessDraw (GfxContext, false);
+          HLayout *layout = NUX_STATIC_CAST(HLayout *, (*it));
+          layout->ProcessDraw(graphics_engine, false);
         }
-        else if ( (*it)->Type().IsObjectType (VLayout::StaticObjectType) )
+        else if ((*it)->Type().IsObjectType(VLayout::StaticObjectType))
         {
-          VLayout *layout = NUX_STATIC_CAST (VLayout *, (*it) );
-          layout->ProcessDraw (GfxContext, false);
+          VLayout *layout = NUX_STATIC_CAST(VLayout *, (*it));
+          layout->ProcessDraw(graphics_engine, false);
         }
       }
 
-      GfxContext.PopClippingRectangle();
+      graphics_engine.PopClippingRectangle();
     }
 
-    GfxContext.PopClippingRectangle();
+    graphics_engine.PopClippingRectangle();
   }
 
-  void VSplitter::PostDraw (GraphicsEngine &GfxContext, bool force_draw)
+  void VSplitter::PostDraw(GraphicsEngine &graphics_engine, bool force_draw)
   {
 
   }
 
-  void VSplitter::OverlayDrawing (GraphicsEngine &GfxContext)
+  void VSplitter::OverlayDrawing(GraphicsEngine &graphics_engine)
   {
-    t_u32 num_element = (t_u32) m_SplitterObject.size();
+    unsigned int num_element = (unsigned int) m_SplitterObject.size();
 
     Geometry base = GetGeometry();
 
     if (m_focus_splitter_index >= 0)
     {
       Geometry geo = m_SplitterObject[m_focus_splitter_index]->GetGeometry();
-      geo.OffsetPosition (mvt_dx, mvt_dy);
+      geo.OffsetPosition(mvt_dx, mvt_dy);
 
       if (m_focus_splitter_index == 0 && num_element > 1)
       {
         if (geo.x < base.x)
         {
-          geo.SetX (base.x);
+          geo.SetX(base.x);
         }
 
         if (geo.x  + VSPLITTERWIDTH > m_SplitterObject[m_focus_splitter_index + 1]->GetGeometry().x)
         {
-          geo.SetX (m_SplitterObject[m_focus_splitter_index+1]->GetGeometry().x - VSPLITTERWIDTH);
+          geo.SetX(m_SplitterObject[m_focus_splitter_index+1]->GetGeometry().x - VSPLITTERWIDTH);
         }
       }
 
-      if ( (m_focus_splitter_index > 0) && m_focus_splitter_index < (t_s32) num_element - 1)
+      if ((m_focus_splitter_index > 0) && m_focus_splitter_index < (int) num_element - 1)
       {
         if (geo.x < m_SplitterObject[m_focus_splitter_index - 1]->GetGeometry().x + VSPLITTERWIDTH)
         {
-          geo.SetX (m_SplitterObject[m_focus_splitter_index - 1]->GetGeometry().x + VSPLITTERWIDTH);
+          geo.SetX(m_SplitterObject[m_focus_splitter_index - 1]->GetGeometry().x + VSPLITTERWIDTH);
         }
 
         if (geo.x + VSPLITTERWIDTH > m_SplitterObject[m_focus_splitter_index + 1]->GetGeometry().x)
         {
-          geo.SetX (m_SplitterObject[m_focus_splitter_index + 1]->GetGeometry().x - VSPLITTERWIDTH);
+          geo.SetX(m_SplitterObject[m_focus_splitter_index + 1]->GetGeometry().x - VSPLITTERWIDTH);
         }
       }
 
-      GfxContext.GetRenderStates().SetBlend (true, GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+      graphics_engine.GetRenderStates().SetBlend(true, GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
       {
-        GetPainter().Paint2DQuadColor (GfxContext, geo, Color (0xBB868686) );
+        GetPainter().Paint2DQuadColor(graphics_engine, geo, Color(0xBB868686));
       }
-      GfxContext.GetRenderStates().SetBlend (false);
+      graphics_engine.GetRenderStates().SetBlend(false);
     }
   }
 
-  void VSplitter::AddWidget (Area *ic, float stretchfactor)
+  void VSplitter::AddWidget(Area *ic, float stretchfactor)
   {
     if (ic)
     {
@@ -243,18 +243,18 @@ namespace nux
       splitter->SetParentObject(this);
       //splitter->SinkReference();
 
-      t_u32 no = (t_u32) m_InterfaceObject.size();
-      splitter->mouse_down.connect (sigc::bind ( sigc::mem_fun (this, &VSplitter::OnSplitterMouseDown), no) );
-      splitter->mouse_up.connect (sigc::bind ( sigc::mem_fun (this, &VSplitter::OnSplitterMouseUp), no) );
-      splitter->mouse_drag.connect (sigc::bind ( sigc::mem_fun (this, &VSplitter::OnSplitterMouseDrag), no) );
+      unsigned int no = (unsigned int) m_InterfaceObject.size();
+      splitter->mouse_down.connect(sigc::bind(sigc::mem_fun(this, &VSplitter::OnSplitterMouseDown), no));
+      splitter->mouse_up.connect(sigc::bind(sigc::mem_fun(this, &VSplitter::OnSplitterMouseUp), no));
+      splitter->mouse_drag.connect(sigc::bind(sigc::mem_fun(this, &VSplitter::OnSplitterMouseDrag), no));
 
-      ic->SetParentObject (this);
-      m_InterfaceObject.push_back (ic);
-      m_SplitterObject.push_back (splitter);
-      m_SplitConfig.push_back (stretchfactor);
+      ic->SetParentObject(this);
+      m_InterfaceObject.push_back(ic);
+      m_SplitterObject.push_back(splitter);
+      m_SplitConfig.push_back(stretchfactor);
 
       new_addition = true;
-      ComputeChildLayout();
+      ComputeContentSize();
     }
   }
 
@@ -263,15 +263,15 @@ namespace nux
     m_InterfaceObject.clear();
   }
 
-  long VSplitter::ComputeChildLayout()
+  long VSplitter::ComputeContentSize()
   {
-    t_u32 num_element = (t_u32) m_InterfaceObject.size();
-    t_s32 x = GetBaseX();
-    t_s32 y = GetBaseY();
-    t_s32 w = GetBaseWidth();
-    t_s32 h = GetBaseHeight();
+    unsigned int num_element = (unsigned int) m_InterfaceObject.size();
+    int x = GetBaseX();
+    int y = GetBaseY();
+    int w = GetBaseWidth();
+    int h = GetBaseHeight();
 
-    if ( (w == 0) || (h == 0) )
+    if ((w == 0) || (h == 0))
     {
       return eCompliantHeight | eCompliantWidth;
     }
@@ -298,75 +298,75 @@ namespace nux
 
     if (m_current_height != h)
     {
-      for (t_u32 i = 0; i < num_element; i++)
+      for (unsigned int i = 0; i < num_element; i++)
       {
         Geometry splitter_geo = m_SplitterObject[i]->GetGeometry();
-        splitter_geo.SetHeight (h);
-        splitter_geo.SetY (y);
+        splitter_geo.SetHeight(h);
+        splitter_geo.SetY(y);
 
-        m_SplitterObject[i]->SetGeometry (splitter_geo);
+        m_SplitterObject[i]->SetGeometry(splitter_geo);
       }
     }
 
     if (m_current_width != w)
     {
-      t_s32 size_to_distribute = w - num_element * VSPLITTERWIDTH;
-      t_s32 previous_spliter_end = m_current_x;
-      t_s32 new_spliter_end = x;
+      int size_to_distribute = w - num_element * VSPLITTERWIDTH;
+      int previous_spliter_end = m_current_x;
+      int new_spliter_end = x;
 
-      for (t_u32 i = 0; i < num_element; i++)
+      for (unsigned int i = 0; i < num_element; i++)
       {
         Geometry splitter_geo = m_SplitterObject[i]->GetGeometry();
         // compute percentage of space occupied by the element i;
         // width of element i = m_SplitterObject[i]->GetX() - previous_splliter_end
-        t_s32 splitter_start = m_SplitterObject[i]->GetBaseX();
-        float percent = float (splitter_start - previous_spliter_end) / float (m_current_width - num_element * VSPLITTERWIDTH);
+        int splitter_start = m_SplitterObject[i]->GetBaseX();
+        float percent = float(splitter_start - previous_spliter_end) / float(m_current_width - num_element * VSPLITTERWIDTH);
 
         if (percent > 1.0f)
           percent = 1.0f;
 
-        splitter_geo.SetX (new_spliter_end + size_to_distribute * percent);
+        splitter_geo.SetX(new_spliter_end + size_to_distribute * percent);
         previous_spliter_end = splitter_start + VSPLITTERWIDTH;
         new_spliter_end = new_spliter_end + size_to_distribute * percent + VSPLITTERWIDTH;
-        m_SplitterObject[i]->SetGeometry (splitter_geo);
+        m_SplitterObject[i]->SetGeometry(splitter_geo);
       }
 
       if (m_SplitterObject[0]->GetBaseX() < x)
       {
-        m_SplitterObject[0]->SetBaseX (x);
+        m_SplitterObject[0]->SetBaseX(x);
       }
 
-      m_SplitterObject[num_element-1]->SetBaseX (x + w - VSPLITTERWIDTH);
+      m_SplitterObject[num_element-1]->SetBaseX(x + w - VSPLITTERWIDTH);
     }
 
-    t_s32 accwidth = x;
+    int accwidth = x;
 
-    for (t_u32 i = 0; i < num_element; i++)
+    for (unsigned int i = 0; i < num_element; i++)
     {
       Geometry splitter_geo = m_SplitterObject[i]->GetGeometry();
 
       //m_InterfaceObject[i]->SetGeometry(Geometry(accwidth, y, splitter_geo.x - accwidth, h));
 
-      if (m_InterfaceObject[i]->Type().IsDerivedFromType (View::StaticObjectType) )
+      if (m_InterfaceObject[i]->Type().IsDerivedFromType(View::StaticObjectType))
       {
-        View *ic = NUX_STATIC_CAST (View *, m_InterfaceObject[i]);
-        ic->SetGeometry (Geometry (accwidth, y, splitter_geo.x - accwidth, h) );
+        View *ic = NUX_STATIC_CAST(View *, m_InterfaceObject[i]);
+        ic->SetGeometry(Geometry(accwidth, y, splitter_geo.x - accwidth, h));
         // if we are already computing the layout from the main window down, we need to call
         // ComputeElementLayout to force the computing of this element layout.
-        GetWindowThread ()->ComputeElementLayout (ic);
+        GetWindowThread()->ComputeElementLayout(ic);
       }
-      else if (m_InterfaceObject[i]->Type().IsObjectType (InputArea::StaticObjectType) )
+      else if (m_InterfaceObject[i]->Type().IsObjectType(InputArea::StaticObjectType))
       {
-        InputArea *base_area = NUX_STATIC_CAST (InputArea *, m_InterfaceObject[i]);
-        base_area->SetGeometry (Geometry (accwidth, y, splitter_geo.x - accwidth, h) );
+        InputArea *base_area = NUX_STATIC_CAST(InputArea *, m_InterfaceObject[i]);
+        base_area->SetGeometry(Geometry(accwidth, y, splitter_geo.x - accwidth, h));
       }
-      else if (m_InterfaceObject[i]->Type().IsDerivedFromType (Layout::StaticObjectType) )
+      else if (m_InterfaceObject[i]->Type().IsDerivedFromType(Layout::StaticObjectType))
       {
-        Layout *layout = NUX_STATIC_CAST (Layout *, m_InterfaceObject[i]);
-        layout->SetGeometry (Geometry (accwidth, y, splitter_geo.x - accwidth, h) );
+        Layout *layout = NUX_STATIC_CAST(Layout *, m_InterfaceObject[i]);
+        layout->SetGeometry(Geometry(accwidth, y, splitter_geo.x - accwidth, h));
         // if we are already computing the layout from the main window down, we need to call
         // ComputeElementLayout to force the computing of this element layout.
-        GetWindowThread ()->ComputeElementLayout (layout);
+        GetWindowThread()->ComputeElementLayout(layout);
       }
 
       accwidth += splitter_geo.x - accwidth + VSPLITTERWIDTH;
@@ -382,11 +382,11 @@ namespace nux
 
   void VSplitter::ResetSplitConfig()
   {
-    t_s32 x = GetBaseX();
-    t_s32 y = GetBaseY();
-    t_s32 w = GetBaseWidth();
-    t_s32 h = GetBaseHeight();
-    t_u32 num_element = (t_u32) m_InterfaceObject.size();
+    int x = GetBaseX();
+    int y = GetBaseY();
+    int w = GetBaseWidth();
+    int h = GetBaseHeight();
+    unsigned int num_element = (unsigned int) m_InterfaceObject.size();
 
     if (num_element < 1)
     {
@@ -396,7 +396,7 @@ namespace nux
     float max_stretch = 0.0f;
     float stretchfactor;
 
-    for (t_u32 i = 0; i < (t_u32) m_SplitConfig.size(); i++)
+    for (unsigned int i = 0; i < (unsigned int) m_SplitConfig.size(); i++)
     {
       stretchfactor = m_SplitConfig[i];
 
@@ -408,57 +408,57 @@ namespace nux
 
     float total = 0;
 
-    for (t_u32 i = 0; i < (t_u32) m_SplitConfig.size(); i++)
+    for (unsigned int i = 0; i < (unsigned int) m_SplitConfig.size(); i++)
     {
       stretchfactor = m_SplitConfig[i];
       total += stretchfactor / max_stretch;
     }
 
-    t_s32 availableheight = (w - num_element * VSPLITTERWIDTH);
-    float max_size = float (availableheight) / total;
+    int availableheight = (w - num_element * VSPLITTERWIDTH);
+    float max_size = float(availableheight) / total;
 
-    for (t_u32 i = 0; i < (t_u32) m_SplitConfig.size(); i++)
+    for (unsigned int i = 0; i < (unsigned int) m_SplitConfig.size(); i++)
     {
       stretchfactor = m_SplitConfig[i];
       x += stretchfactor * max_size / max_stretch;
-      Geometry geo (x, y, VSPLITTERWIDTH, h);
-      m_SplitterObject[i]->SetGeometry (geo);
+      Geometry geo(x, y, VSPLITTERWIDTH, h);
+      m_SplitterObject[i]->SetGeometry(geo);
     }
 
-    m_SplitterObject[num_element-1]->SetBaseX (x + w - VSPLITTERWIDTH);
+    m_SplitterObject[num_element-1]->SetBaseX(x + w - VSPLITTERWIDTH);
 
     m_initial_config = true;
   }
 
-  void VSplitter::OnSplitterMouseDown (t_s32 x, t_s32 y, unsigned long button_flags, unsigned long key_flags, t_s32 header_pos)
+  void VSplitter::OnSplitterMouseDown(int x, int y, unsigned long button_flags, unsigned long key_flags, int header_pos)
   {
     m_point = Point(x, y);
 
     m_focus_splitter_index = header_pos;
-    GetWindowCompositor().SetWidgetDrawingOverlay (this, GetWindowCompositor().GetProcessingTopView() );
+    GetWindowThread()->GetWindowCompositor().SetWidgetDrawingOverlay(this, GetWindowThread()->GetWindowCompositor().GetProcessingTopView());
 
     // Hint for the window to initiate a redraw
-    GetWindowThread ()->RequestRedraw();
+    GetWindowThread()->RequestRedraw();
   }
 
-  void VSplitter::OnSplitterMouseUp (t_s32 x, t_s32 y, unsigned long button_flags, unsigned long key_flags, t_s32 header_pos)
+  void VSplitter::OnSplitterMouseUp(int x, int y, unsigned long button_flags, unsigned long key_flags, int header_pos)
   {
     if (mvt_dx)
     {
       Geometry geo = m_SplitterObject[header_pos]->GetGeometry();
-      geo.OffsetPosition (mvt_dx, 0);
+      geo.OffsetPosition(mvt_dx, 0);
 
-      t_u32 num_element = (t_u32) m_SplitterObject.size();
+      unsigned int num_element = (unsigned int) m_SplitterObject.size();
 
-      if (header_pos < (t_s32) num_element - 1)
+      if (header_pos < (int) num_element - 1)
       {
         // Make the splitter bar stick to the next one if the distance between them is less than VSTICK_SIZE
         if (m_SplitterObject[header_pos + 1]->GetGeometry().x - geo.x - VSPLITTERWIDTH < VSTICK_SIZE)
-          geo.SetX ( m_SplitterObject[header_pos + 1]->GetGeometry().x - VSPLITTERWIDTH );
+          geo.SetX( m_SplitterObject[header_pos + 1]->GetGeometry().x - VSPLITTERWIDTH );
       }
 
-      m_SplitterObject[header_pos]->SetGeometry (geo);
-      ResizeSplitter (header_pos);
+      m_SplitterObject[header_pos]->SetGeometry(geo);
+      ResizeSplitter(header_pos);
     }
 
     m_focus_splitter_index = -1;
@@ -466,15 +466,15 @@ namespace nux
     mvt_dy = 0;
 
     // End overlay drawing;
-    GetWindowCompositor().SetWidgetDrawingOverlay (0, GetWindowCompositor().GetProcessingTopView() );
+    GetWindowThread()->GetWindowCompositor().SetWidgetDrawingOverlay(0, GetWindowThread()->GetWindowCompositor().GetProcessingTopView());
     // Hint for the window to initiate a redraw
-    GetWindowThread ()->RequestRedraw();
+    GetWindowThread()->RequestRedraw();
   }
 
-  void VSplitter::OnSplitterMouseDrag (t_s32 x, t_s32 y, t_s32 dx, t_s32 dy, unsigned long button_flags, unsigned long key_flags, t_s32 header_pos)
+  void VSplitter::OnSplitterMouseDrag(int x, int y, int dx, int dy, unsigned long button_flags, unsigned long key_flags, int header_pos)
   {
     Geometry geo = m_SplitterObject[header_pos]->GetGeometry();
-    t_s32 num_element = (t_s32) m_SplitterObject.size();
+    int num_element = (int) m_SplitterObject.size();
 
     if (header_pos == num_element - 1)
     {
@@ -489,61 +489,61 @@ namespace nux
     {
       // Continuously redraw resize and redraw the 2 parts of the widget.
       // This is slow.
-      geo.OffsetPosition (mvt_dx, mvt_dy);
-      m_SplitterObject[header_pos]->SetGeometry (geo);
-      ResizeSplitter (header_pos);
+      geo.OffsetPosition(mvt_dx, mvt_dy);
+      m_SplitterObject[header_pos]->SetGeometry(geo);
+      ResizeSplitter(header_pos);
 
       mvt_dx = 0;
       mvt_dy = 0;
     }
 
     // Hint for the window to initiate a redraw
-    GetWindowThread ()->RequestRedraw();
+    GetWindowThread()->RequestRedraw();
   }
 
-  void VSplitter::ResizeSplitter (t_s32 header_pos)
+  void VSplitter::ResizeSplitter(int header_pos)
   {
     Geometry geo = m_SplitterObject[header_pos]->GetGeometry();
-    t_s32 num_element = (t_s32) m_SplitterObject.size();
+    int num_element = (int) m_SplitterObject.size();
 
-    if ( (header_pos == 0) && (m_SplitterObject[header_pos]->GetBaseX() < GetBaseX() ) )
+    if ((header_pos == 0) && (m_SplitterObject[header_pos]->GetBaseX() < GetBaseX()))
     {
-      m_SplitterObject[header_pos]->SetBaseX (GetBaseX() );
+      m_SplitterObject[header_pos]->SetBaseX(GetBaseX());
     }
 
-    if ( (header_pos == num_element - 1) && (m_SplitterObject[header_pos]->GetBaseX() > GetBaseX() + GetBaseWidth() - VSPLITTERWIDTH) )
+    if ((header_pos == num_element - 1) && (m_SplitterObject[header_pos]->GetBaseX() > GetBaseX() + GetBaseWidth() - VSPLITTERWIDTH))
     {
-      m_SplitterObject[header_pos]->SetBaseX (GetBaseX() + GetBaseWidth() - VSPLITTERWIDTH);
+      m_SplitterObject[header_pos]->SetBaseX(GetBaseX() + GetBaseWidth() - VSPLITTERWIDTH);
     }
 
-    if (header_pos < (t_s32) num_element - 1)
+    if (header_pos < (int) num_element - 1)
     {
-      t_s32 posx0, posx1;
+      int posx0, posx1;
       posx0 = m_SplitterObject[header_pos]->GetBaseX();
       posx1 = m_SplitterObject[header_pos + 1]->GetBaseX();
 
       if (posx0 > posx1 - VSPLITTERWIDTH)
       {
         posx0 = posx1 - VSPLITTERWIDTH;
-        m_SplitterObject[header_pos]->SetBaseX (posx0);
+        m_SplitterObject[header_pos]->SetBaseX(posx0);
       }
     }
 
     if (0 < header_pos)
     {
-      t_s32 posx0, posx1;
+      int posx0, posx1;
       posx0 = m_SplitterObject[header_pos]->GetBaseX();
       posx1 = m_SplitterObject[header_pos - 1]->GetBaseX();
 
       if (posx0 < posx1 + VSPLITTERWIDTH)
       {
         posx0 = posx1 + VSPLITTERWIDTH;
-        m_SplitterObject[header_pos]->SetBaseX (posx0);
+        m_SplitterObject[header_pos]->SetBaseX(posx0);
       }
     }
 
     m_initial_config = false;
-    ComputeChildLayout();
+    ComputeContentSize();
 
     QueueDraw();
   }
@@ -557,12 +557,12 @@ namespace nux
     for (it = m_InterfaceObject.begin(); it != m_InterfaceObject.end(); it++)
     {
       //(*it)->DoneRedraw();
-      if((*it)->Type().IsDerivedFromType (View::StaticObjectType))
+      if ((*it)->Type().IsDerivedFromType(View::StaticObjectType))
       {
         View *ic = NUX_STATIC_CAST(View *, (*it));
         ic->DoneRedraw();
       }
-      else if((*it)->Type().IsObjectType (InputArea::StaticObjectType))
+      else if ((*it)->Type().IsObjectType(InputArea::StaticObjectType))
       {
         //InputArea* base_area = NUX_STATIC_CAST(InputArea*, (*it));
       }
@@ -573,27 +573,27 @@ namespace nux
   {
     bool mouse_inside = TestMousePointerInclusionFilterMouseWheel(mouse_position, event_type);
 
-    if(mouse_inside == false)
+    if (mouse_inside == false)
       return NULL;
 
     std::vector<MySplitter*>::iterator splitter_it;
     for (splitter_it = m_SplitterObject.begin(); splitter_it != m_SplitterObject.end(); splitter_it++)
     {
       Area* found_area = (*splitter_it)->FindAreaUnderMouse(mouse_position, event_type);
-      if(found_area)
+      if (found_area)
         return found_area;
     }
 
     std::vector<Area *>::iterator it;
-    for(it = m_InterfaceObject.begin(); it != m_InterfaceObject.end(); it++)
+    for (it = m_InterfaceObject.begin(); it != m_InterfaceObject.end(); it++)
     {
       Area* found_area = (*it)->FindAreaUnderMouse(mouse_position, event_type);
 
-      if(found_area)
+      if (found_area)
         return found_area;
     }
 
-    if((event_type == NUX_MOUSE_WHEEL) && (!AcceptMouseWheelEvent()))
+    if ((event_type == NUX_MOUSE_WHEEL) && (!AcceptMouseWheelEvent()))
       return NULL;
     return this;
   }
@@ -617,12 +617,12 @@ namespace nux
       }
       std::vector<Area*>::iterator it;
       std::vector<Area*>::iterator it_next;
-      it = std::find (m_InterfaceObject.begin(), m_InterfaceObject.end(), next_object_to_key_focus_area_);
+      it = std::find(m_InterfaceObject.begin(), m_InterfaceObject.end(), next_object_to_key_focus_area_);
 
       if (it == m_InterfaceObject.end())
       {
         // Should never happen
-        nuxAssert (0);
+        nuxAssert(0);
         return NULL;
       }
 
