@@ -28,25 +28,25 @@ namespace nux
 
   class VSplitter: public View
   {
-    NUX_DECLARE_OBJECT_TYPE (VSplitter, View);
+    NUX_DECLARE_OBJECT_TYPE(VSplitter, View);
   public:
-    VSplitter (NUX_FILE_LINE_PROTO);
+    VSplitter(NUX_FILE_LINE_PROTO);
     ~VSplitter();
 
-    virtual void Draw (GraphicsEngine &GfxContext, bool force_draw);
-    virtual void DrawContent (GraphicsEngine &GfxContext, bool force_draw);
-    virtual void PostDraw (GraphicsEngine &GfxContext, bool force_draw);
+    virtual void Draw(GraphicsEngine &graphics_engine, bool force_draw);
+    virtual void DrawContent(GraphicsEngine &graphics_engine, bool force_draw);
+    virtual void PostDraw(GraphicsEngine &graphics_engine, bool force_draw);
 
-    void AddWidget (Area *ic, float stretchfactor);
+    void AddWidget(Area *ic, float stretchfactor);
     void ResetSplitConfig();
 
     void clearContent();
 
-    void OnSplitterMouseDown (t_s32 x, t_s32 y, unsigned long button_flags, unsigned long key_flags, t_s32 header_pos);
-    void OnSplitterMouseUp (t_s32 x, t_s32 y, unsigned long button_flags, unsigned long key_flags, t_s32 header_pos);
-    void OnSplitterMouseDrag (t_s32 x, t_s32 y, t_s32 dx, t_s32 dy, unsigned long button_flags, unsigned long key_flags, t_s32 header_pos);
+    void OnSplitterMouseDown(int x, int y, unsigned long button_flags, unsigned long key_flags, int header_pos);
+    void OnSplitterMouseUp(int x, int y, unsigned long button_flags, unsigned long key_flags, int header_pos);
+    void OnSplitterMouseDrag(int x, int y, int dx, int dy, unsigned long button_flags, unsigned long key_flags, int header_pos);
 
-    virtual void OverlayDrawing (GraphicsEngine &GfxContext);
+    virtual void OverlayDrawing(GraphicsEngine &graphics_engine);
 
     //! Return true if this object can break the layout.
     /*
@@ -62,11 +62,11 @@ namespace nux
     virtual Area* FindAreaUnderMouse(const Point& mouse_position, NuxEventType event_type);
 
   protected:
-    virtual long ComputeChildLayout();
+    virtual long ComputeContentSize();
     virtual void DoneRedraw();
-    void ResizeSplitter (t_s32 header_pos);
+    void ResizeSplitter(int header_pos);
     //void ContinuousSplitterAdjustment();
-    void setResizeOnSplitterRelease (bool b)
+    void setResizeOnSplitterRelease(bool b)
     {
       m_ResizeOnSplitterRelease = b;
     }
@@ -89,16 +89,16 @@ namespace nux
     bool new_addition;
 
     bool m_ResizeOnSplitterRelease;
-    t_s32 m_current_width;
-    t_s32 m_current_height;
-    t_s32 m_current_x;
-    t_s32 m_current_y;
+    int m_current_width;
+    int m_current_height;
+    int m_current_x;
+    int m_current_y;
 
     bool m_initial_config;
 
     // splitter bar differential position;
-    t_s32 mvt_dx, mvt_dy;
-    t_s32 m_focus_splitter_index;
+    int mvt_dx, mvt_dy;
+    int m_focus_splitter_index;
   };
 
 }
