@@ -216,6 +216,9 @@ namespace nux
 
   void View::QueueDraw()
   {
+    if (draw_cmd_queued_)
+      return;
+
     //GetWindowCompositor()..AddToDrawList(this);
     WindowThread* application = GetWindowThread();
     if (application)
@@ -409,12 +412,14 @@ namespace nux
 
   void View::GeometryChangePending()
   {
-    QueueDraw();
+    if (IsLayoutDone())
+      QueueDraw();
   }
 
   void View::GeometryChanged()
   {
-    QueueDraw();
+    if (IsLayoutDone())
+      QueueDraw();
   }
 
   Area* View::FindAreaUnderMouse(const Point& mouse_position, NuxEventType event_type)
