@@ -42,7 +42,7 @@ namespace nux
   public:
     //! Constructor
     ObjectPtr()
-      : ptr_(nullptr)
+      : ptr_(NULL)
     {
     }
 
@@ -66,7 +66,7 @@ namespace nux
     */
     template <typename O>
     ObjectPtr(ObjectPtr<O> const& other)
-      : ptr_(nullptr)
+      : ptr_(NULL)
     {
       if (other.ptr_ &&
           other.ptr_->Type().IsDerivedFromType(T::StaticObjectType))
@@ -87,7 +87,7 @@ namespace nux
         longer have a reference on ptr.
     */
     explicit ObjectPtr(T *ptr, bool WarnMissuse = false)
-      : ptr_(nullptr)
+      : ptr_(NULL)
     {
       if (ptr)
       {
@@ -113,7 +113,7 @@ namespace nux
     */
     template <typename O>
     explicit ObjectPtr(O *ptr, bool WarnMissuse = false)
-      : ptr_(nullptr)
+      : ptr_(NULL)
     {
       if (ptr &&
           ptr->Type().IsDerivedFromType(T::StaticObjectType))
@@ -198,18 +198,7 @@ namespace nux
         keep it.
         @param Return the stored pointer.
     */
-    const T* GetPointer () const
-    {
-      return ptr_;
-    }
-
-    //! Return the stored pointer.
-    /*!
-        Caller of this function should Reference the pointer if they intend to
-        keep it.
-        @param Return the stored pointer.
-    */
-    T* GetPointer()
+    T* GetPointer () const
     {
       return ptr_;
     }
@@ -252,7 +241,7 @@ namespace nux
     */
     bool IsValid() const
     {
-        return bool(ptr_);
+      return (ptr_ != NULL) ? true : false;
     }
 
     bool operator < (T *ptr) const
@@ -339,7 +328,7 @@ namespace nux
       // Decrease the number of strong reference on the hosted pointer.
       ptr_->objectptr_count_->Decrement();
       bool destroyed = ptr_->UnReference();
-      ptr_ = nullptr;
+      ptr_ = NULL;
       return destroyed;
     }
 
@@ -367,7 +356,7 @@ namespace nux
   public:
     //! Constructor
     ObjectWeakPtr()
-      : ptr_(nullptr)
+      : ptr_(NULL)
     {
     }
 
@@ -397,7 +386,7 @@ namespace nux
     */
     template <typename O>
     explicit ObjectWeakPtr(O* ptr, bool WarnMissuse = false)
-      : ptr_(nullptr)
+      : ptr_(NULL)
     {
       if (ptr &&
           (ptr->Type().IsDerivedFromType(T::StaticObjectType)))
@@ -423,7 +412,7 @@ namespace nux
     */
     template <typename O>
     ObjectWeakPtr(const ObjectWeakPtr<O>& other)
-      : ptr_(nullptr)
+      : ptr_(NULL)
     {
       if (other.ptr_ &&
           (other.ptr_->Type().IsDerivedFromType(T::StaticObjectType)))
@@ -439,7 +428,7 @@ namespace nux
     */
     template <typename O>
     ObjectWeakPtr(const ObjectPtr<O> &other)
-      : ptr_(nullptr)
+      : ptr_(NULL)
     {
       if (other.ptr_ &&
           (other.ptr_->Type().IsDerivedFromType(T::StaticObjectType)))
@@ -622,7 +611,7 @@ namespace nux
     */
     bool IsValid() const
     {
-      return bool(ptr_);
+      return (ptr_!= NULL) ? true : false;
     }
 
     //! Return true is the hosted pointer is null or has been destroyed.
@@ -647,7 +636,7 @@ namespace nux
     bool Release()
     {
         Disconnect();
-        ptr_ = nullptr;
+        ptr_ = NULL;
         return false;
     }
 
@@ -656,17 +645,7 @@ namespace nux
         Caller of this function should Reference the pointer if they intend to keep it.
         @param Return the stored pointer.
     */
-    const T* GetPointer () const
-    {
-      return ptr_;
-    }
-
-    //! Return the stored pointer.
-    /*!
-        Caller of this function should Reference the pointer if they intend to keep it.
-        @param Return the stored pointer.
-    */
-    T* GetPointer()
+    T* GetPointer () const
     {
       return ptr_;
     }
@@ -682,14 +661,14 @@ namespace nux
     {
       if (ptr_)
       {
-        auto slot = sigc::mem_fun(this, &ObjectWeakPtr<T>::TargetDestroyed);
+        sigc::slot<void, Object*> slot = sigc::mem_fun(this, &ObjectWeakPtr<T>::TargetDestroyed);
         destroy_listener_ = ptr_->object_destroyed.connect(slot);
       }
     }
 
     void TargetDestroyed(Object* ptr)
     {
-        ptr_ = nullptr;
+        ptr_ = NULL;
         // rese the connetion too
         destroy_listener_ = sigc::connection();
     }
