@@ -41,7 +41,7 @@ namespace nux
   //  - declare the vertex attribute name before any other attribute.
   //  - Give the vertex attribute a name that comes before any other attribute name. For instance prefix the vertex attribute name with "_".
 
-  NString gFontVtxShader = TEXT ("#version 110      \n\
+  NString gFontVtxShader = "                  \n\
   attribute vec4 _Position;                         \n\
   attribute vec4 iOffset;                           \n\
   attribute vec4 iScale;                            \n\
@@ -53,20 +53,35 @@ namespace nux
   oTexCoord0   = iTexUV;                            \n\
   vec4 myvertex = _Position * iScale + iOffset;     \n\
   gl_Position  = ViewProjectionMatrix * myvertex;   \n\
-  }");
+  }";
 
-  NString gFontFragShader = TEXT ("#version 110                             \n\
+  NString gFontFragShader = "                                         \n\
   #extension GL_ARB_texture_rectangle : enable                              \n\
-  uniform sampler2DRect FontTexture;                                        \n\
+  #ifdef GL_ES                                                              \n\
+  precision mediump float;                                                  \n\
+  #endif                                                                    \n\
   uniform vec4 TextColor;                                                   \n\
   varying vec4 oTexCoord0;                                                  \n\
+  #ifdef SAMPLERTEX2D                                                       \n\
+  uniform sampler2D FontTexture;                                            \n\
+  vec4 SampleTexture(sampler2D TexObject, vec4 TexCoord)                    \n\
+  {                                                                         \n\
+    return texture2D(TexObject, TexCoord.st);                               \n\
+  }                                                                         \n\
+  #elif defined SAMPLERTEX2DRECT                                            \n\
+  uniform sampler2DRect FontTexture;                                        \n\
+  vec4 SampleTexture(sampler2DRect TexObject, vec4 TexCoord)                \n\
+  {                                                                         \n\
+    return texture2DRect(TexObject, TexCoord.st);                           \n\
+  }                                                                         \n\
+  #endif                                                                    \n\
   void main()                                                               \n\
   {                                                                         \n\
-    vec4 diffuse = texture2DRect(FontTexture, oTexCoord0.st);               \n\
+    vec4 diffuse = SampleTexture(FontTexture, oTexCoord0);                  \n\
     gl_FragColor = vec4(TextColor.x, TextColor.y, TextColor.z, diffuse.w);  \n\
-  }");
+  }";
 
-  NString FontAsmVtx = TEXT ("!!ARBvp1.0          \n\
+  NString FontAsmVtx = "!!ARBvp1.0          \n\
   ATTRIB iScale       = vertex.attrib[9];         \n\
   ATTRIB iOffset      = vertex.attrib[10];        \n\
   OUTPUT oPos         = result.position;          \n\
@@ -79,9 +94,9 @@ namespace nux
   DP4   oPos.z, state.matrix.mvp.row[2], temp;    \n\
   DP4   oPos.w, state.matrix.mvp.row[3], temp;    \n\
   MOV   oTexCoord0, vertex.attrib[8];             \n\
-  END");
+  END";
 
-  NString FontAsmFrg = TEXT ("!!ARBfp1.0            \n\
+  NString FontAsmFrg = "!!ARBfp1.0            \n\
   PARAM color = program.local[0];                   \n\
   TEMP temp;                                        \n\
   TEMP tex0;                                        \n\
@@ -89,9 +104,9 @@ namespace nux
   MOV temp, color;                                  \n\
   MUL temp.w, color, tex0;                          \n\
   MOV result.color, temp;                           \n\
-  END");
+  END";
 
-  NString FontAsmFrgRect = TEXT ("!!ARBfp1.0        \n\
+  NString FontAsmFrgRect = "!!ARBfp1.0        \n\
   PARAM color = program.local[0];                   \n\
   TEMP temp;                                        \n\
   TEMP tex0;                                        \n\
@@ -99,38 +114,42 @@ namespace nux
   MOV temp, color;                                  \n\
   MUL temp.w, color, tex0;                          \n\
   MOV result.color, temp;                           \n\
-  END");
+  END";
 
 
-  FontRenderer::FontRenderer (GraphicsEngine &graphics_engine)
-    :   _graphics_engine (graphics_engine)
+  FontRenderer::FontRenderer(GraphicsEngine &graphics_engine)
+    :   _graphics_engine(graphics_engine)
   {
-    if(_graphics_engine.UsingGLSLCodePath())
+    if (_graphics_engine.UsingGLSLCodePath())
     {
       _pixel_shader_prog = GetGraphicsDisplay()->GetGpuDevice()->CreatePixelShader();
       _vertex_shader_prog = GetGraphicsDisplay()->GetGpuDevice()->CreateVertexShader();
       _shader_prog = GetGraphicsDisplay()->GetGpuDevice()->CreateShaderProgram();
 
-      _vertex_shader_prog->SetShaderCode (TCHAR_TO_ANSI (*gFontVtxShader) );
-      _pixel_shader_prog->SetShaderCode (TCHAR_TO_ANSI (*gFontFragShader) );
+      _vertex_shader_prog->SetShaderCode(TCHAR_TO_ANSI(*gFontVtxShader));
+#ifndef NUX_OPENGLES_20
+      _pixel_shader_prog->SetShaderCode(TCHAR_TO_ANSI(*gFontFragShader), "#define SAMPLERTEX2DRECT");
+#else
+      _pixel_shader_prog->SetShaderCode(TCHAR_TO_ANSI(*gFontFragShader), "#define SAMPLERTEX2D");
+#endif
 
       _shader_prog->ClearShaderObjects();
-      _shader_prog->AddShaderObject (_vertex_shader_prog);
-      _shader_prog->AddShaderObject (_pixel_shader_prog);
-      //CHECKGL (glBindAttribLocation(_shader_prog->GetOpenGLID(), 0, "_Position"));
+      _shader_prog->AddShaderObject(_vertex_shader_prog);
+      _shader_prog->AddShaderObject(_pixel_shader_prog);
+      //CHECKGL(glBindAttribLocation(_shader_prog->GetOpenGLID(), 0, "_Position"));
       _shader_prog->Link();
     }
     else
     {
       _asm_shader_prog = GetGraphicsDisplay()->GetGpuDevice()->CreateAsmShaderProgram();
 
-      _asm_shader_prog->LoadVertexShader (TCHAR_TO_ANSI (*FontAsmVtx) );
-      _asm_shader_prog->LoadPixelShader (TCHAR_TO_ANSI (*FontAsmFrg) );
+      _asm_shader_prog->LoadVertexShader(TCHAR_TO_ANSI(*FontAsmVtx));
+      _asm_shader_prog->LoadPixelShader(TCHAR_TO_ANSI(*FontAsmFrg));
       _asm_shader_prog->Link();
 
       _asm_font_texture_rect_prog = GetGraphicsDisplay()->GetGpuDevice()->CreateAsmShaderProgram();
-      _asm_font_texture_rect_prog->LoadVertexShader (TCHAR_TO_ANSI (*FontAsmVtx) );
-      _asm_font_texture_rect_prog->LoadPixelShader (TCHAR_TO_ANSI (*FontAsmFrgRect) );
+      _asm_font_texture_rect_prog->LoadVertexShader(TCHAR_TO_ANSI(*FontAsmVtx));
+      _asm_font_texture_rect_prog->LoadPixelShader(TCHAR_TO_ANSI(*FontAsmFrgRect));
       _asm_font_texture_rect_prog->Link();
     }
   }
@@ -139,12 +158,12 @@ namespace nux
   {
   }
 
-  int FontRenderer::DrawColorString (ObjectPtr<FontTexture> Font, int x, int y, const NString &str, const Color &color, bool WriteAlphaChannel, int SkipFirstNCharacters, int NumCharacter)
+  int FontRenderer::DrawColorString(ObjectPtr<FontTexture> Font, int x, int y, const NString &str, const Color &color, bool WriteAlphaChannel, int SkipFirstNCharacters, int NumCharacter)
   {
-    return RenderText (Font, x, y, str, color, WriteAlphaChannel, SkipFirstNCharacters, NumCharacter);
+    return RenderText(Font, x, y, str, color, WriteAlphaChannel, SkipFirstNCharacters, NumCharacter);
   }
 
-  void FontRenderer::PositionString (ObjectPtr<FontTexture> Font, const NString &str, const PageBBox &pageBBox, StringBBox &strBBox, TextAlignment alignment, int NumCharacter)
+  void FontRenderer::PositionString(ObjectPtr<FontTexture> Font, const NString &str, const PageBBox &pageBBox, StringBBox &strBBox, TextAlignment alignment, int NumCharacter)
   {
     int x, y;
     int xmin, ymin, xmax, ymax;
@@ -158,32 +177,32 @@ namespace nux
     if (NumCharacter == 0)
       NumChar = str.Size();
     else
-      NumChar = Min ((int) str.Size(), NumCharacter);
+      NumChar = Min((int) str.Size(), NumCharacter);
 
     strBBox.width = Font->GetStringWidth(str, NumChar);
     strBBox.height = Font->GetLineHeight();
 
-    switch (alignment)
+    switch(alignment)
     {
       case eAlignTextCenter:
 
         if (strBBox.width > xmax - xmin)
           x = xmin; // the text is larger than the box: default to eAlignTextLeft for x.
         else
-          x = xmin + ( (float) (xmax - xmin) - (float) (strBBox.width) ) / 2.0f;
+          x = xmin + ((float) (xmax - xmin) - (float) (strBBox.width)) / 2.0f;
 
-        y = ymin + ( (float) (ymax - ymin) - (float) (strBBox.height) ) / 2.0f;
+        y = ymin + ((float) (ymax - ymin) - (float) (strBBox.height)) / 2.0f;
         break;
 
       case eAlignTextRight:
-        x = xmin + ( (float) (xmax - xmin) - (float) (strBBox.width) );
-        y = ymin + ( (float) (ymax - ymin) - (float) (strBBox.height) ) / 2.0f;
+        x = xmin + ((float) (xmax - xmin) - (float) (strBBox.width));
+        y = ymin + ((float) (ymax - ymin) - (float) (strBBox.height)) / 2.0f;
         break;
 
       case eAlignTextLeft:
       default:
         x = xmin;
-        y = ymin + ( (float) (ymax - ymin) - (float) (strBBox.height) ) / 2.0f;
+        y = ymin + ((float) (ymax - ymin) - (float) (strBBox.height)) / 2.0f;
         break;
     }
 
@@ -191,27 +210,27 @@ namespace nux
     strBBox.y = y;
   }
 
-  int FontRenderer::RenderColorText (ObjectPtr<FontTexture> Font, int x, int y, const NString &Str, const Color &color,
+  int FontRenderer::RenderColorText(ObjectPtr<FontTexture> Font, int x, int y, const NString &Str, const Color &color,
                                      bool WriteAlphaChannel, int NumCharacter)
   {
-    int off = DrawColorString (Font, x, y, Str, color, WriteAlphaChannel, 0, NumCharacter);
+    int off = DrawColorString(Font, x, y, Str, color, WriteAlphaChannel, 0, NumCharacter);
     return off;
   }
 
-  int FontRenderer::RenderColorTextLineStatic (ObjectPtr<FontTexture> Font, const PageBBox &pageSize, const NString &Str, const Color &color,
+  int FontRenderer::RenderColorTextLineStatic(ObjectPtr<FontTexture> Font, const PageBBox &pageSize, const NString &Str, const Color &color,
       bool WriteAlphaChannel, TextAlignment alignment)
   {
     StringBBox stringBBox;
 
-    _graphics_engine.PushClippingRectangle (Rect (pageSize.xmin, pageSize.ymin, pageSize.xmax - pageSize.xmin, pageSize.ymax - pageSize.ymin) );
-    PositionString (Font, Str, pageSize, stringBBox, alignment);
-    int off = DrawColorString (Font, stringBBox.x, stringBBox.y, Str, color, WriteAlphaChannel, 0, Str.Size() );
+    _graphics_engine.PushClippingRectangle(Rect(pageSize.xmin, pageSize.ymin, pageSize.xmax - pageSize.xmin, pageSize.ymax - pageSize.ymin));
+    PositionString(Font, Str, pageSize, stringBBox, alignment);
+    int off = DrawColorString(Font, stringBBox.x, stringBBox.y, Str, color, WriteAlphaChannel, 0, Str.Size());
 
     _graphics_engine.PopClippingRectangle();
     return off;
   }
 
-  int FontRenderer::RenderColorTextLineEdit (ObjectPtr<FontTexture> Font, const PageBBox &pageSize, const NString &Str,
+  int FontRenderer::RenderColorTextLineEdit(ObjectPtr<FontTexture> Font, const PageBBox &pageSize, const NString &Str,
       const Color &TextColor,
       bool WriteAlphaChannel,
       const Color &SelectedTextColor,
@@ -221,54 +240,54 @@ namespace nux
       bool ShowCursor, unsigned int CursorPosition, int offset, int selection_start, int selection_end)
   {
     StringBBox stringBBox;
-    Color selection_color (0xFF888888);
+    Color selection_color(0xFF888888);
 
-    NString substring = Str.GetSubString (selection_start, selection_end - selection_start);
-    unsigned int substring_width = Font->GetStringWidth (substring);
-    int substring_pos = Font->GetStringWidth (Str, selection_start);
+    NString substring = Str.GetSubString(selection_start, selection_end - selection_start);
+    unsigned int substring_width = Font->GetStringWidth(substring);
+    int substring_pos = Font->GetStringWidth(Str, selection_start);
 
-    _graphics_engine.PushClippingRectangle (Rect (pageSize.xmin, pageSize.ymin, pageSize.xmax - pageSize.xmin, pageSize.ymax - pageSize.ymin) );
+    _graphics_engine.PushClippingRectangle(Rect(pageSize.xmin, pageSize.ymin, pageSize.xmax - pageSize.xmin, pageSize.ymax - pageSize.ymin));
 
     if (substring_width > 0)
-      _graphics_engine.QRP_Color (pageSize.xmin + offset + substring_pos, pageSize.ymin, substring_width, pageSize.ymax - pageSize.ymin, SelectedTextBackgroundColor);
+      _graphics_engine.QRP_Color(pageSize.xmin + offset + substring_pos, pageSize.ymin, substring_width, pageSize.ymax - pageSize.ymin, SelectedTextBackgroundColor);
 
     _graphics_engine.PopClippingRectangle();
 
-    _graphics_engine.PushClippingRectangle (Rect (pageSize.xmin, pageSize.ymin, pageSize.xmax - pageSize.xmin, pageSize.ymax - pageSize.ymin) );
+    _graphics_engine.PushClippingRectangle(Rect(pageSize.xmin, pageSize.ymin, pageSize.xmax - pageSize.xmin, pageSize.ymax - pageSize.ymin));
 
-    PositionString (Font, Str, pageSize, stringBBox, eAlignTextLeft);
+    PositionString(Font, Str, pageSize, stringBBox, eAlignTextLeft);
     //ComputeGlyphString(stringBBox.x + offset, stringBBox.y, Str.c_str());
 
     // Part before selected text
-    int off = DrawColorString (Font, stringBBox.x + offset, stringBBox.y, Str, TextColor, WriteAlphaChannel, 0, selection_start);
+    int off = DrawColorString(Font, stringBBox.x + offset, stringBBox.y, Str, TextColor, WriteAlphaChannel, 0, selection_start);
     // Selection part
-    off = DrawColorString (Font, stringBBox.x + offset, stringBBox.y, Str, SelectedTextColor, WriteAlphaChannel, selection_start, selection_end - selection_start);
+    off = DrawColorString(Font, stringBBox.x + offset, stringBBox.y, Str, SelectedTextColor, WriteAlphaChannel, selection_start, selection_end - selection_start);
     // Part after selected text
-    off = DrawColorString (Font, stringBBox.x + offset, stringBBox.y, Str, TextColor, WriteAlphaChannel, selection_end, Str.Size() - selection_end);
+    off = DrawColorString(Font, stringBBox.x + offset, stringBBox.y, Str, TextColor, WriteAlphaChannel, selection_end, Str.Size() - selection_end);
 
     _graphics_engine.PopClippingRectangle();
 
     // Render Cursor
-    NString temp = Str.GetSubString (0, CursorPosition);
-    int w = Font->GetStringWidth (temp.GetTCharPtr() );
+    NString temp = Str.GetSubString(0, CursorPosition);
+    int w = Font->GetStringWidth(temp.GetTCharPtr());
 
 
     if (ShowCursor)
     {
       int x = pageSize.xmin + w + offset + CURSOR_OFFSET;
       x = (x >= pageSize.xmax) ? pageSize.xmax - 1 : x;
-      _graphics_engine.PushClippingRectangle (Rect (x, pageSize.ymin, CURSOR_SIZE, pageSize.ymax - pageSize.ymin) );
+      _graphics_engine.PushClippingRectangle(Rect(x, pageSize.ymin, CURSOR_SIZE, pageSize.ymax - pageSize.ymin));
 
-      _graphics_engine.QRP_Color (x, pageSize.ymin, CURSOR_SIZE, pageSize.ymax - pageSize.ymin, CursorColor);
+      _graphics_engine.QRP_Color(x, pageSize.ymin, CURSOR_SIZE, pageSize.ymax - pageSize.ymin, CursorColor);
       
-      DrawColorString (Font, stringBBox.x + offset, stringBBox.y, Str, TextBlinkColor, WriteAlphaChannel, CursorPosition, 1);
+      DrawColorString(Font, stringBBox.x + offset, stringBBox.y, Str, TextBlinkColor, WriteAlphaChannel, CursorPosition, 1);
       _graphics_engine.PopClippingRectangle();
     }
 
     return off;
   }
 
-  int FontRenderer::RenderText (ObjectPtr<FontTexture> Font, int x, int y, const NString &str, const Color &color, bool WriteAlphaChannel, int StartCharacter, int NumCharacter)
+  int FontRenderer::RenderText(ObjectPtr<FontTexture> Font, int x, int y, const NString &str, const Color &color, bool WriteAlphaChannel, int StartCharacter, int NumCharacter)
   {
     // !WARNING This call works if all the glyph of the font are in a single texture.
 
@@ -277,31 +296,32 @@ namespace nux
     if (StrLength <= 0)
       return 0;
 
-    nuxAssertMsg (NumCharacter >= 0, TEXT ("[FontRenderer::RenderText] Incorrect value for NumCharacter.") );
-    nuxAssertMsg (StartCharacter >= 0, TEXT ("[FontRenderer::RenderText] Incorrect value for StartCharacter.") );
-    nuxAssertMsg (StartCharacter <= StrLength, TEXT ("[FontRenderer::RenderText] Incorrect value for StartCharacter.") );
+    nuxAssertMsg(NumCharacter >= 0, "[FontRenderer::RenderText] Incorrect value for NumCharacter.");
+    nuxAssertMsg(StartCharacter >= 0, "[FontRenderer::RenderText] Incorrect value for StartCharacter.");
+    nuxAssertMsg(StartCharacter <= StrLength, "[FontRenderer::RenderText] Incorrect value for StartCharacter.");
 
-    //     if(NumCharacter == 0)
+    //     if (NumCharacter == 0)
     //         NumCharacter = str.Size();
 
     int NumCharToDraw = Min<int> (StrLength - StartCharacter, NumCharacter);
 
-    //nuxAssertMsg(NumCharToDraw > 0, TEXT("[FontRenderer::RenderText] Incorrect value for NumCharToDraw."));
+    //nuxAssertMsg(NumCharToDraw > 0, "[FontRenderer::RenderText] Incorrect value for NumCharToDraw.");
     if (NumCharToDraw <= 0)
       return 0;
 
-    CHECKGL ( glDisable (GL_CULL_FACE) );
+    CHECKGL(glDisable(GL_CULL_FACE));
     int CurX = x;
     int CurY = y;
-    _graphics_engine.GetRenderStates().SetBlend (TRUE, GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-    _graphics_engine.GetRenderStates().SetColorMask (TRUE, TRUE, TRUE, WriteAlphaChannel); // Do not write the alpha of characters
+    _graphics_engine.GetRenderStates().SetBlend(TRUE, GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+    _graphics_engine.GetRenderStates().SetColorMask(TRUE, TRUE, TRUE, WriteAlphaChannel); // Do not write the alpha of characters
 
+    GLshort *Index = new GLshort[StrLength*6];
     Vector4 *Position = new Vector4[StrLength*4];
     Vector4 *UV = new Vector4[StrLength*4];
     Vector4 *Offset = new Vector4[StrLength*4];
     Vector4 *Scale = new Vector4[StrLength*4];
 
-    ObjectPtr<CachedBaseTexture> glTexture = _graphics_engine.ResourceCache.GetCachedResource (Font->TextureArray[0]);
+    ObjectPtr<CachedBaseTexture> glTexture = _graphics_engine.ResourceCache.GetCachedResource(Font->TextureArray[0]);
 
     float tex_width = (float) glTexture->m_Texture->GetWidth();
     float tex_height = (float) glTexture->m_Texture->GetHeight();
@@ -320,7 +340,7 @@ namespace nux
       int abcC = Font->m_Charset.Chars[c /*Str[i]*/].abcC;
       //int page = Font->m_Charset.Chars[c /*Str[i]*/].page;
 
-      if ( (i >= StartCharacter) && (i < StartCharacter + NumCharToDraw) )
+      if ((i >= StartCharacter) && (i < StartCharacter + NumCharToDraw))
       {
         int II = i - StartCharacter;
         Position[II*4 + 0].x = 0;      // x
@@ -356,7 +376,7 @@ namespace nux
           Scale[II*4 + j].w = 1.0f;
         }
 
-        if(glTexture->m_Texture->Type().IsDerivedFromType(IOpenGLRectangleTexture::StaticObjectType))
+        if (glTexture->m_Texture->Type().IsDerivedFromType(IOpenGLRectangleTexture::StaticObjectType))
         {
           //upper left
           UV[II*4 + 0].x = CharX;
@@ -410,11 +430,20 @@ namespace nux
         }
       }
 
+      // Set up element array indices
+      Index[i*6 + 0] = i*4;
+      Index[i*6 + 1] = i*4 + 2;
+      Index[i*6 + 2] = i*4 + 3;
+
+      Index[i*6 + 3] = i*4;
+      Index[i*6 + 4] = i*4 + 1;
+      Index[i*6 + 5] = i*4 + 2;
+
       CurX += abcA + abcB + abcC;
     }
 
-    CHECKGL (glBindBufferARB (GL_ARRAY_BUFFER_ARB, 0) );
-    CHECKGL (glBindBufferARB (GL_ELEMENT_ARRAY_BUFFER_ARB, 0) );
+    CHECKGL(glBindBufferARB(GL_ARRAY_BUFFER_ARB, 0));
+    CHECKGL(glBindBufferARB(GL_ELEMENT_ARRAY_BUFFER_ARB, 0));
 
     int in_attrib_position = 0;
     int in_attrib_tex_uv = 0;
@@ -422,13 +451,13 @@ namespace nux
     int in_attrib_offset = 0;
 
     ObjectPtr<IOpenGLAsmShaderProgram> shader_program;
-    if(_graphics_engine.UsingGLSLCodePath())
+    if (_graphics_engine.UsingGLSLCodePath())
     {
       _shader_prog->Begin();
-      int ViewProjectionMatrix = _shader_prog->GetUniformLocationARB ("ViewProjectionMatrix");
+      int ViewProjectionMatrix = _shader_prog->GetUniformLocationARB("ViewProjectionMatrix");
       Matrix4 mat = _graphics_engine.GetOpenGLModelViewProjectionMatrix();
 
-      _shader_prog->SetUniformLocMatrix4fv (ViewProjectionMatrix, 1, false, (float *) &mat);
+      _shader_prog->SetUniformLocMatrix4fv(ViewProjectionMatrix, 1, false, (float *) &mat);
 
       in_attrib_position = _shader_prog->GetAttributeLocation("_Position");
       in_attrib_tex_uv   = _shader_prog->GetAttributeLocation("iTexUV");
@@ -440,87 +469,89 @@ namespace nux
 
       _graphics_engine.SetTexture(GL_TEXTURE0, glTexture->m_Texture);
 
-      if(FontTexture != -1)
+      if (FontTexture != -1)
       {
         CHECKGL(glUniform1iARB(FontTexture, 0));
       }
 
-      if(TextColor != -1)
+      if (TextColor != -1)
       {
         CHECKGL(glUniform4fARB(TextColor, color.red, color.green, color.blue, color.alpha));
       }
     }
+#ifndef NUX_OPENGLES_20
     else
     {
       shader_program = _asm_shader_prog;
-      if(glTexture->m_Texture->Type().IsDerivedFromType(IOpenGLRectangleTexture::StaticObjectType))
+      if (glTexture->m_Texture->Type().IsDerivedFromType(IOpenGLRectangleTexture::StaticObjectType))
       {
         shader_program = _asm_font_texture_rect_prog;
       }
       shader_program->Begin();
 
-      CHECKGL (glMatrixMode(GL_MODELVIEW));
-      CHECKGL (glLoadIdentity());
-      Matrix4 model_view_matrix = _graphics_engine.GetModelViewMatrix ();
+      CHECKGL(glMatrixMode(GL_MODELVIEW));
+      CHECKGL(glLoadIdentity());
+      Matrix4 model_view_matrix = _graphics_engine.GetModelViewMatrix();
       model_view_matrix.Transpose();
-      CHECKGL (glLoadMatrixf((float *) model_view_matrix.m));
+      CHECKGL(glLoadMatrixf((float *) model_view_matrix.m));
 
-      CHECKGL (glMatrixMode(GL_PROJECTION));
-      CHECKGL (glLoadIdentity());
-      Matrix4 projection_matrix = GetGraphicsDisplay()->GetGraphicsEngine()->GetProjectionMatrix ();
-      projection_matrix.Transpose ();
-      CHECKGL (glLoadMatrixf ((float *) projection_matrix.m));
+      CHECKGL(glMatrixMode(GL_PROJECTION));
+      CHECKGL(glLoadIdentity());
+      Matrix4 projection_matrix = GetGraphicsDisplay()->GetGraphicsEngine()->GetProjectionMatrix();
+      projection_matrix.Transpose();
+      CHECKGL(glLoadMatrixf((float *) projection_matrix.m));
 
       in_attrib_position   = VTXATTRIB_POSITION;
       in_attrib_tex_uv      = VTXATTRIB_TEXCOORD0;
       in_attrib_scale      = VTXATTRIB_TEXCOORD1;
       in_attrib_offset     = VTXATTRIB_TEXCOORD2;
 
-      CHECKGL ( glProgramLocalParameter4fARB (GL_FRAGMENT_PROGRAM_ARB, 0, color.red, color.green, color.blue, color.alpha ) );
+      CHECKGL(glProgramLocalParameter4fARB(GL_FRAGMENT_PROGRAM_ARB, 0, color.red, color.green, color.blue, color.alpha ));
 
-      _graphics_engine.SetTexture (GL_TEXTURE0, glTexture->m_Texture);
+      _graphics_engine.SetTexture(GL_TEXTURE0, glTexture->m_Texture);
     }
+#endif
 
     if (in_attrib_offset != -1)
     {
-      CHECKGL ( glEnableVertexAttribArrayARB (in_attrib_offset) );
-      CHECKGL ( glVertexAttribPointerARB (in_attrib_offset, 4, GL_FLOAT, GL_FALSE, 16, Offset) );
+      CHECKGL(glEnableVertexAttribArrayARB(in_attrib_offset));
+      CHECKGL(glVertexAttribPointerARB(in_attrib_offset, 4, GL_FLOAT, GL_FALSE, 16, Offset));
     }
 
     if (in_attrib_position != -1)
     {
-      CHECKGL ( glEnableVertexAttribArrayARB (in_attrib_position) );
-      CHECKGL ( glVertexAttribPointerARB (in_attrib_position, 4, GL_FLOAT, GL_FALSE, 16, Position) );
+      CHECKGL(glEnableVertexAttribArrayARB(in_attrib_position));
+      CHECKGL(glVertexAttribPointerARB(in_attrib_position, 4, GL_FLOAT, GL_FALSE, 16, Position));
     }
 
     if (in_attrib_scale != -1)
     {
-      CHECKGL ( glEnableVertexAttribArrayARB (in_attrib_scale) );
-      CHECKGL ( glVertexAttribPointerARB (in_attrib_scale, 4, GL_FLOAT, GL_FALSE, 16, Scale) );
+      CHECKGL(glEnableVertexAttribArrayARB(in_attrib_scale));
+      CHECKGL(glVertexAttribPointerARB(in_attrib_scale, 4, GL_FLOAT, GL_FALSE, 16, Scale));
     }
 
     if (in_attrib_tex_uv != -1)
     {
-      CHECKGL ( glEnableVertexAttribArrayARB (in_attrib_tex_uv) );
-      CHECKGL ( glVertexAttribPointerARB (in_attrib_tex_uv, 4, GL_FLOAT, GL_FALSE, 16, UV) );
+      CHECKGL(glEnableVertexAttribArrayARB(in_attrib_tex_uv));
+      CHECKGL(glVertexAttribPointerARB(in_attrib_tex_uv, 4, GL_FLOAT, GL_FALSE, 16, UV));
     }
 
     if (NumCharToDraw > 0)
-      CHECKGL ( glDrawArrays ( GL_QUADS, 0, NumCharToDraw * 4 ) );
+      CHECKGL(glDrawElements( GL_TRIANGLES, NumCharToDraw * 6, GL_UNSIGNED_SHORT, Index ));
 
     if (in_attrib_position != -1)
-      CHECKGL ( glDisableVertexAttribArrayARB (in_attrib_position) );
+      CHECKGL(glDisableVertexAttribArrayARB(in_attrib_position));
 
     if (in_attrib_offset != -1)
-      CHECKGL ( glDisableVertexAttribArrayARB (in_attrib_offset) );
+      CHECKGL(glDisableVertexAttribArrayARB(in_attrib_offset));
 
     if (in_attrib_scale != -1)
-      CHECKGL ( glDisableVertexAttribArrayARB (in_attrib_scale) );
+      CHECKGL(glDisableVertexAttribArrayARB(in_attrib_scale));
 
     if (in_attrib_tex_uv != -1)
-      CHECKGL ( glDisableVertexAttribArrayARB (in_attrib_tex_uv) );
+      CHECKGL(glDisableVertexAttribArrayARB(in_attrib_tex_uv));
 
-    if(_graphics_engine.UsingGLSLCodePath())
+    if (_graphics_engine.UsingGLSLCodePath())
     {
       _shader_prog->End();
     }
@@ -529,11 +560,12 @@ namespace nux
       shader_program->End();
     }
 
-    _graphics_engine.GetRenderStates().SetColorMask (TRUE, TRUE, TRUE, TRUE);
-    _graphics_engine.GetRenderStates().SetBlend (FALSE);
+    _graphics_engine.GetRenderStates().SetColorMask(TRUE, TRUE, TRUE, TRUE);
+    _graphics_engine.GetRenderStates().SetBlend(FALSE);
 
     CurX -= x + CURSOR_OFFSET;
 
+    delete [] Index;
     delete [] Position;
     delete [] UV;
     delete [] Scale;
@@ -542,18 +574,18 @@ namespace nux
     return CurX; // number of pixel to offset before writing the next string.
   }
 
-  int FontRenderer::RenderTextToBuffer (float *VertexBuffer, int VBSize,
+  int FontRenderer::RenderTextToBuffer(float *VertexBuffer, int VBSize,
                                         ObjectPtr<FontTexture> Font, Rect geo, const NString &str, const Color &color, TextAlignment alignment, int NumCharacter)
   {
-    nuxAssertMsg (NumCharacter >= 0, TEXT ("[FontRenderer::RenderTextToBuffer] Number of char to draw must be positive.") );
+    nuxAssertMsg(NumCharacter >= 0, "[FontRenderer::RenderTextToBuffer] Number of char to draw must be positive.");
     int NumCharToDraw = 0;
 
     if (NumCharacter == 0)
       NumCharToDraw = str.Size();
     else
-      NumCharToDraw = Min ( (int) str.Size(), NumCharacter);
+      NumCharToDraw = Min((int) str.Size(), NumCharacter);
 
-    nuxAssertMsg (3 * NumCharToDraw * 16 <= VBSize, TEXT ("[FontRenderer::RenderTextToBuffer] VertexBuffer not large enough.") );
+    nuxAssertMsg(3 * NumCharToDraw * 16 <= VBSize, "[FontRenderer::RenderTextToBuffer] VertexBuffer not large enough.");
 
     if (3 * NumCharToDraw * 16 > VBSize)
       return 0;
@@ -567,7 +599,7 @@ namespace nux
     pageBox.x_margin = 0;
     pageBox.y_margin = 0;
 
-    PositionString (Font, str, pageBox, stringBBox, alignment);
+    PositionString(Font, str, pageBox, stringBBox, alignment);
 
     int CurX = stringBBox.x;
     int CurY = stringBBox.y;
