@@ -40,16 +40,19 @@ namespace nux
 // Use assembly shaders for Intel GPUs: ARB_fragment_program does not have the required
 // instruction to implement the HSV to RGB color conversion.
 
-  static NString VtxShader = TEXT ("#version 110   \n\
+  static NString VtxShader = "            \n\
         uniform mat4 ViewProjectionMatrix;      \n\
         attribute vec4 AVertex;                 \n\
         attribute vec4 VertexColor;             \n\
         void main()                             \n\
         {                                       \n\
             gl_Position = ViewProjectionMatrix * AVertex;   \n\
-        }");
+        }";
 
-  static NString RedFrgShader = TEXT ("#version 110                            \n\
+  static NString RedFrgShader = "         \n\
+        #ifdef GL_ES                            \n\
+        precision mediump float;                \n\
+        #endif                                  \n\
         uniform vec4 RectPosition;              \n\
         uniform vec4 RectDimension;             \n\
         uniform vec4 Color;                     \n\
@@ -58,9 +61,12 @@ namespace nux
             float x = (gl_FragCoord.x - RectPosition.x) / RectDimension.x;  \n\
             float y = (gl_FragCoord.y - RectPosition.y) / RectDimension.y;  \n\
             gl_FragColor = vec4(Color.r, y, x, 1.0);                        \n\
-        }");
+        }";
 
-  static NString GreenFrgShader = TEXT ("#version 110                            \n\
+  static NString GreenFrgShader = "       \n\
+        #ifdef GL_ES                            \n\
+        precision mediump float;                \n\
+        #endif                                  \n\
         uniform vec4 RectPosition;              \n\
         uniform vec4 RectDimension;             \n\
         uniform vec4 Color;                     \n\
@@ -69,9 +75,12 @@ namespace nux
             float x = (gl_FragCoord.x - RectPosition.x) / RectDimension.x;  \n\
             float y = (gl_FragCoord.y - RectPosition.y) / RectDimension.y;  \n\
             gl_FragColor = vec4(y, Color.g, x, 1.0);                        \n\
-        }");
+        }";
 
-  static NString BlueFrgShader = TEXT ("#version 110                            \n\
+  static NString BlueFrgShader = "        \n\
+        #ifdef GL_ES                            \n\
+        precision mediump float;                \n\
+        #endif                                  \n\
         uniform vec4 RectPosition;              \n\
         uniform vec4 RectDimension;             \n\
         uniform vec4 Color;                     \n\
@@ -80,9 +89,12 @@ namespace nux
             float x = (gl_FragCoord.x - RectPosition.x) / RectDimension.x;  \n\
             float y = (gl_FragCoord.y - RectPosition.y) / RectDimension.y;  \n\
             gl_FragColor = vec4(x, y, Color.b, 1.0);                        \n\
-        }");
+        }";
 
-  static NString HueFrgShader = TEXT ("#version 110        \n\
+  static NString HueFrgShader = "                 \n\
+        #ifdef GL_ES                                    \n\
+        precision mediump float;                        \n\
+        #endif                                          \n\
         vec3 HSV_To_RGB(vec3 HSV);                      \n\
         uniform vec4 RectPosition;                      \n\
         uniform vec4 RectDimension;                     \n\
@@ -93,9 +105,12 @@ namespace nux
             float y = (gl_FragCoord.y - RectPosition.y) / RectDimension.y;  \n\
             vec3 rgb = HSV_To_RGB(vec3(Color.x, x, y));         \n\
             gl_FragColor = vec4(rgb, 1.0);                      \n\
-        }");
+        }";
 
-  static NString SaturationFrgShader = TEXT ("#version 110     \n\
+  static NString SaturationFrgShader = "              \n\
+        #ifdef GL_ES                                        \n\
+        precision mediump float;                            \n\
+        #endif                                              \n\
         vec3 HSV_To_RGB(vec3 HSV);                          \n\
         uniform vec4 RectPosition;                          \n\
         uniform vec4 RectDimension;                         \n\
@@ -106,9 +121,12 @@ namespace nux
             float y = (gl_FragCoord.y - RectPosition.y) / RectDimension.y;  \n\
             vec3 rgb = HSV_To_RGB(vec3(x, Color.y, y));         \n\
             gl_FragColor = vec4(rgb, 1.0);                      \n\
-        }");
+        }";
 
-  static NString ValueFrgShader = TEXT ("#version 110  \n\
+  static NString ValueFrgShader = "           \n\
+        #ifdef GL_ES                                \n\
+        precision mediump float;                    \n\
+        #endif                                      \n\
         vec3 HSV_To_RGB(vec3 HSV);                  \n\
         uniform vec4 RectPosition;                  \n\
         uniform vec4 RectDimension;                 \n\
@@ -119,9 +137,12 @@ namespace nux
             float y = (gl_FragCoord.y - RectPosition.y) / RectDimension.y;  \n\
             vec3 rgb = HSV_To_RGB(vec3(x, y, Color.z));                     \n\
             gl_FragColor = vec4(rgb, 1.0);                                  \n\
-        }");
+        }";
 
-  static NString HSV_To_RGBFrgShader = TEXT ("#version 110  \n\
+  static NString HSV_To_RGBFrgShader = "                                  \n\
+        #ifdef GL_ES                                                            \n\
+        precision mediump float;                                                \n\
+        #endif                                                                  \n\
         vec3 HSV_To_RGB(vec3 HSV)                                               \n\
         {                                                                       \n\
             vec3 RGB = vec3(HSV.z);                                             \n\
@@ -139,12 +160,12 @@ namespace nux
                 else if (var_i == 4.0) { RGB = vec3(var_3, var_1, HSV.z); }     \n\
                 else                 { RGB = vec3(HSV.z, var_1, var_2); }       \n\
             }                                                                   \n\
-            return (RGB);                                                       \n\
-        }");
+            return(RGB);                                                       \n\
+        }";
 
 //////////////////////////////////////////////////////////////////////////////
 
-  static NString AsmVtxShader = TEXT ("!!ARBvp1.0                                 \n\
+  static NString AsmVtxShader = "!!ARBvp1.0                                 \n\
         ATTRIB iPos         = vertex.position;      \n\
         PARAM  mvp[4]       = {state.matrix.mvp};   \n\
         OUTPUT oPos         = result.position;      \n\
@@ -153,9 +174,9 @@ namespace nux
         DP4   oPos.y, mvp[1], iPos;      \n\
         DP4   oPos.z, mvp[2], iPos;      \n\
         DP4   oPos.w, mvp[3], iPos;      \n\
-        END");
+        END";
 
-  NString AsmRedFrgShader = TEXT ("!!ARBfp1.0                  \n\
+  NString AsmRedFrgShader = "!!ARBfp1.0                  \n\
         PARAM RectPosition = program.local[0];              \n\
         PARAM RectDimension = program.local[1];             \n\
         PARAM Color = program.local[2];                     \n\
@@ -170,9 +191,9 @@ namespace nux
         MOV temp1.yz, temp0.yyxx;                           \n\
         MOV temp1.w, {1, 1, 1, 1};                          \n\
         MOV result.color, temp1;                            \n\
-        END");
+        END";
 
-  NString AsmGreenFrgShader = TEXT ("!!ARBfp1.0                  \n\
+  NString AsmGreenFrgShader = "!!ARBfp1.0                  \n\
        PARAM RectPosition = program.local[0];              \n\
        PARAM RectDimension = program.local[1];             \n\
        PARAM Color = program.local[2];                     \n\
@@ -187,9 +208,9 @@ namespace nux
        MOV temp1.xz, temp0.yyxx;                           \n\
        MOV temp1.w, {1, 1, 1, 1};                          \n\
        MOV result.color, temp1;                            \n\
-       END");
+       END";
 
-  NString AsmBlueFrgShader = TEXT ("!!ARBfp1.0                \n\
+  NString AsmBlueFrgShader = "!!ARBfp1.0                \n\
        PARAM RectPosition = program.local[0];              \n\
        PARAM RectDimension = program.local[1];             \n\
        PARAM Color = program.local[2];                     \n\
@@ -204,36 +225,36 @@ namespace nux
        MOV temp1.xy, temp0.xyxx;                           \n\
        MOV temp1.w, {1, 1, 1, 1};                          \n\
        MOV result.color, temp1;                            \n\
-       END");
+       END";
 
 
-  NString AsmHueFrgShader = TEXT ("!!ARBfp1.0                  \n\
+  NString AsmHueFrgShader = "!!ARBfp1.0                  \n\
         MOV result.color, {0, 0, 0, 0};                     \n\
-        END");
+        END";
 
-  NString AsmSaturationFrgShader = TEXT ("!!ARBfp1.0                  \n\
+  NString AsmSaturationFrgShader = "!!ARBfp1.0                  \n\
        MOV result.color, {0, 0, 0, 0};                      \n\
-       END");
+       END";
 
-  NString AsmValueFrgShader = TEXT ("!!ARBfp1.0                  \n\
+  NString AsmValueFrgShader = "!!ARBfp1.0                  \n\
        MOV result.color, {0, 0, 0, 0};                      \n\
-       END");
+       END";
 
 
 
-GLSh_ColorPicker::GLSh_ColorPicker (color::Channel color_channel)
-    :   _R (1.0)
-    ,   _G (0.0)
-    ,   _B (0.0)
-    ,   _A (1.0)
-    ,   _ScreenOffsetX (0)
-    ,   _ScreenOffsetY (0)
+GLSh_ColorPicker::GLSh_ColorPicker(color::Channel color_channel)
+    :   _R(1.0)
+    ,   _G(0.0)
+    ,   _B(0.0)
+    ,   _A(1.0)
+    ,   _ScreenOffsetX(0)
+    ,   _ScreenOffsetY(0)
   {
     NString FrgShaderCode;
 
-    if (GetGraphicsDisplay()->GetGraphicsEngine()->UsingGLSLCodePath() && (GetGraphicsDisplay()->GetGpuDevice()->GetGPUBrand() != GPU_BRAND_INTEL) )
+    if (GetGraphicsDisplay()->GetGraphicsEngine()->UsingGLSLCodePath() && (GetGraphicsDisplay()->GetGpuDevice()->GetGPUBrand() != GPU_BRAND_INTEL))
     {
-      switch (color_channel)
+      switch(color_channel)
       {
         case color::RED:
         {
@@ -267,7 +288,7 @@ GLSh_ColorPicker::GLSh_ColorPicker (color::Channel color_channel)
         }
         default:
         {
-          nuxDebugMsg (TEXT ("[GLSh_ColorPicker::GLSh_ColorPicker] Unknown color channel") );
+          nuxDebugMsg("[GLSh_ColorPicker::GLSh_ColorPicker] Unknown color channel");
           FrgShaderCode = RedFrgShader;
           break;
         }
@@ -276,16 +297,16 @@ GLSh_ColorPicker::GLSh_ColorPicker (color::Channel color_channel)
       GlobalPixelShader = GetGraphicsDisplay()->GetGpuDevice()->CreatePixelShader();
       sprog = GetGraphicsDisplay()->GetGpuDevice()->CreateShaderProgram();
 
-      GlobalPixelShader->SetShaderCode (HSV_To_RGBFrgShader.GetTCharPtr() );
+      GlobalPixelShader->SetShaderCode(HSV_To_RGBFrgShader.GetTCharPtr());
 
-      sprog->AddShaderObject (GlobalPixelShader);
-      sprog->LoadVertexShader (VtxShader.GetTCharPtr(), NULL);
-      sprog->LoadPixelShader (FrgShaderCode.GetTCharPtr(), NULL);
+      sprog->AddShaderObject(GlobalPixelShader);
+      sprog->LoadVertexShader(VtxShader.GetTCharPtr(), NULL);
+      sprog->LoadPixelShader(FrgShaderCode.GetTCharPtr(), NULL);
       sprog->Link();
     }
     else
     {
-      switch (color_channel)
+      switch(color_channel)
       {
         case color::RED:
         {
@@ -319,15 +340,15 @@ GLSh_ColorPicker::GLSh_ColorPicker (color::Channel color_channel)
         }
         default:
         {
-          nuxDebugMsg (TEXT ("[GLSh_ColorPicker::GLSh_ColorPicker] Unknown color channel") );
+          nuxDebugMsg("[GLSh_ColorPicker::GLSh_ColorPicker] Unknown color channel");
           FrgShaderCode = RedFrgShader;
           break;
         }
       }
 
       m_AsmProg = GetGraphicsDisplay()->GetGpuDevice()->CreateAsmShaderProgram();
-      m_AsmProg->LoadVertexShader (AsmVtxShader.GetTCharPtr() );
-      m_AsmProg->LoadPixelShader (FrgShaderCode.GetTCharPtr() );
+      m_AsmProg->LoadVertexShader(AsmVtxShader.GetTCharPtr());
+      m_AsmProg->LoadPixelShader(FrgShaderCode.GetTCharPtr());
       m_AsmProg->Link();
     }
   }
@@ -339,7 +360,7 @@ GLSh_ColorPicker::GLSh_ColorPicker (color::Channel color_channel)
     m_AsmProg.Release();
   }
 
-  void GLSh_ColorPicker::SetColor (float R, float G, float B, float A)
+  void GLSh_ColorPicker::SetColor(float R, float G, float B, float A)
   {
     _R = R;
     _G = G;
@@ -347,13 +368,13 @@ GLSh_ColorPicker::GLSh_ColorPicker (color::Channel color_channel)
     _A = A;
   }
 
-  void GLSh_ColorPicker::SetScreenPositionOffset (float x, float y)
+  void GLSh_ColorPicker::SetScreenPositionOffset(float x, float y)
   {
     _ScreenOffsetX = x;
     _ScreenOffsetY = y;
   }
 
-  void GLSh_ColorPicker::Render (int x, int y, int z, int width, int height, int WindowWidth, int WindowHeight)
+  void GLSh_ColorPicker::Render(int x, int y, int z, int width, int height, int WindowWidth, int WindowHeight)
   {
     float fx = x, fy = y;
     float VtxBuffer[] =
@@ -364,67 +385,67 @@ GLSh_ColorPicker::GLSh_ColorPicker (color::Channel color_channel)
       fx + width,  fy,          0.0f, 1.0f,
     };
 
-    if (GetGraphicsDisplay()->GetGraphicsEngine()->UsingGLSLCodePath() && (GetGraphicsDisplay()->GetGpuDevice()->GetGPUBrand() != GPU_BRAND_INTEL) )
+    if (GetGraphicsDisplay()->GetGraphicsEngine()->UsingGLSLCodePath() && (GetGraphicsDisplay()->GetGpuDevice()->GetGPUBrand() != GPU_BRAND_INTEL))
     {
-      CHECKGL (glBindBufferARB (GL_ARRAY_BUFFER_ARB, 0) );
-      CHECKGL (glBindBufferARB (GL_ELEMENT_ARRAY_BUFFER_ARB, 0) );
+      CHECKGL(glBindBufferARB(GL_ARRAY_BUFFER_ARB, 0));
+      CHECKGL(glBindBufferARB(GL_ELEMENT_ARRAY_BUFFER_ARB, 0));
       sprog->Begin();
 
-      int VertexLocation = sprog->GetAttributeLocation ("AVertex");
+      int VertexLocation = sprog->GetAttributeLocation("AVertex");
 
-      int VPMatrixLocation = sprog->GetUniformLocationARB ("ViewProjectionMatrix");
-      Matrix4 MVPMatrix = GetGraphicsDisplay()->GetGraphicsEngine ()->GetOpenGLModelViewProjectionMatrix ();
+      int VPMatrixLocation = sprog->GetUniformLocationARB("ViewProjectionMatrix");
+      Matrix4 MVPMatrix = GetGraphicsDisplay()->GetGraphicsEngine()->GetOpenGLModelViewProjectionMatrix();
 
-      sprog->SetUniformLocMatrix4fv ( (GLint) VPMatrixLocation, 1, false, (GLfloat *) & (MVPMatrix.m) );
+      sprog->SetUniformLocMatrix4fv((GLint) VPMatrixLocation, 1, false, (GLfloat *) & (MVPMatrix.m));
 
-      int ColorBase    = sprog->GetUniformLocationARB ("Color");
-      int RectPosition    = sprog->GetUniformLocationARB ("RectPosition");
-      int RectDimension   = sprog->GetUniformLocationARB ("RectDimension");
+      int ColorBase    = sprog->GetUniformLocationARB("Color");
+      int RectPosition    = sprog->GetUniformLocationARB("RectPosition");
+      int RectDimension   = sprog->GetUniformLocationARB("RectDimension");
 
       if (ColorBase != -1)
-        CHECKGL ( glUniform4fARB (ColorBase, _R, _G, _B, _A) );
+        CHECKGL(glUniform4fARB(ColorBase, _R, _G, _B, _A));
 
       if (RectPosition != -1)
-        CHECKGL ( glUniform4fARB (RectPosition, x + _ScreenOffsetX, WindowHeight - y - height - _ScreenOffsetY, z, 0.0f) );
+        CHECKGL(glUniform4fARB(RectPosition, x + _ScreenOffsetX, WindowHeight - y - height - _ScreenOffsetY, z, 0.0f));
 
       if (RectDimension != -1)
-        CHECKGL ( glUniform4fARB (RectDimension, width, height, 0.0f, 0.0f) );
+        CHECKGL(glUniform4fARB(RectDimension, width, height, 0.0f, 0.0f));
 
-      CHECKGL ( glEnableVertexAttribArrayARB (VertexLocation) );
-      CHECKGL ( glVertexAttribPointerARB ( (GLuint) VertexLocation, 4, GL_FLOAT, GL_FALSE, 16, VtxBuffer) );
+      CHECKGL(glEnableVertexAttribArrayARB(VertexLocation));
+      CHECKGL(glVertexAttribPointerARB((GLuint) VertexLocation, 4, GL_FLOAT, GL_FALSE, 16, VtxBuffer));
 
-      CHECKGL ( glDrawArrays (GL_TRIANGLE_FAN, 0, 4) );
+      CHECKGL(glDrawArrays(GL_TRIANGLE_FAN, 0, 4));
 
-      CHECKGL ( glDisableVertexAttribArrayARB (VertexLocation) );
+      CHECKGL(glDisableVertexAttribArrayARB(VertexLocation));
 
       sprog->End();
     }
 #ifndef NUX_OPENGLES_20
     else
     {
-      CHECKGL (glBindBufferARB (GL_ARRAY_BUFFER_ARB, 0) );
-      CHECKGL (glBindBufferARB (GL_ELEMENT_ARRAY_BUFFER_ARB, 0) );
+      CHECKGL(glBindBufferARB(GL_ARRAY_BUFFER_ARB, 0));
+      CHECKGL(glBindBufferARB(GL_ELEMENT_ARRAY_BUFFER_ARB, 0));
       m_AsmProg->Begin();
 
-      CHECKGL ( glMatrixMode (GL_MODELVIEW) );
-      CHECKGL ( glLoadIdentity() );
-      CHECKGL ( glLoadMatrixf ( (FLOAT *) GetGraphicsDisplay()->GetGraphicsEngine()->GetOpenGLModelViewMatrix().m) );
-      CHECKGL ( glMatrixMode (GL_PROJECTION) );
-      CHECKGL ( glLoadIdentity() );
-      CHECKGL ( glLoadMatrixf ( (FLOAT *) GetGraphicsDisplay()->GetGraphicsEngine()->GetOpenGLProjectionMatrix().m) );
+      CHECKGL(glMatrixMode(GL_MODELVIEW));
+      CHECKGL(glLoadIdentity());
+      CHECKGL(glLoadMatrixf((FLOAT *) GetGraphicsDisplay()->GetGraphicsEngine()->GetOpenGLModelViewMatrix().m));
+      CHECKGL(glMatrixMode(GL_PROJECTION));
+      CHECKGL(glLoadIdentity());
+      CHECKGL(glLoadMatrixf((FLOAT *) GetGraphicsDisplay()->GetGraphicsEngine()->GetOpenGLProjectionMatrix().m));
 
       int VertexLocation          = VTXATTRIB_POSITION;
 
-      CHECKGL ( glProgramLocalParameter4fARB (GL_FRAGMENT_PROGRAM_ARB, 0, x + _ScreenOffsetX, WindowHeight - y - height - _ScreenOffsetY, z, 0.0f) );
-      CHECKGL ( glProgramLocalParameter4fARB (GL_FRAGMENT_PROGRAM_ARB, 1, width, height, 0.0f, 0.0f) );
-      CHECKGL ( glProgramLocalParameter4fARB (GL_FRAGMENT_PROGRAM_ARB, 2, _R, _G, _B, _A) );
+      CHECKGL(glProgramLocalParameter4fARB(GL_FRAGMENT_PROGRAM_ARB, 0, x + _ScreenOffsetX, WindowHeight - y - height - _ScreenOffsetY, z, 0.0f));
+      CHECKGL(glProgramLocalParameter4fARB(GL_FRAGMENT_PROGRAM_ARB, 1, width, height, 0.0f, 0.0f));
+      CHECKGL(glProgramLocalParameter4fARB(GL_FRAGMENT_PROGRAM_ARB, 2, _R, _G, _B, _A));
 
-      CHECKGL ( glEnableVertexAttribArrayARB (VertexLocation) );
-      CHECKGL ( glVertexAttribPointerARB ( (GLuint) VertexLocation, 4, GL_FLOAT, GL_FALSE, 16, VtxBuffer) );
+      CHECKGL(glEnableVertexAttribArrayARB(VertexLocation));
+      CHECKGL(glVertexAttribPointerARB((GLuint) VertexLocation, 4, GL_FLOAT, GL_FALSE, 16, VtxBuffer));
 
-      CHECKGL ( glDrawArrays (GL_TRIANGLE_FAN, 0, 4) );
+      CHECKGL(glDrawArrays(GL_TRIANGLE_FAN, 0, 4));
 
-      CHECKGL ( glDisableVertexAttribArrayARB (VertexLocation) );
+      CHECKGL(glDisableVertexAttribArrayARB(VertexLocation));
 
       m_AsmProg->End();
     }
