@@ -50,7 +50,7 @@ namespace nux
    * Note that if there's no alpha channel, the argument is ignored.
    * @return The resulting texture.
    */
-  BaseTexture *CreateTexture2DFromFile (const char *filename, int max_size,
+  BaseTexture* CreateTexture2DFromFile(const char* filename, int max_size,
                                         bool premultiply);
 
   /*!
@@ -62,57 +62,59 @@ namespace nux
    * Note that if there's no alpha channel, the argument is ignored.
    * @return The resulting texture.
    */
-  BaseTexture *CreateTexture2DFromPixbuf (GdkPixbuf *pixbuf, bool premultiply);
+  BaseTexture* CreateTexture2DFromPixbuf(GdkPixbuf* pixbuf, bool premultiply);
 
   // FIXME(loicm) Should be deprecated.
-  BaseTexture *CreateTextureFromPixbuf (GdkPixbuf *pixbuf);
+  BaseTexture* CreateTextureFromPixbuf(GdkPixbuf* pixbuf);
 
-  BaseTexture *CreateTextureFromFile (const TCHAR *TextureFilename);
-  BaseTexture *CreateTextureFromBitmapData (const NBitmapData *BitmapData);
+  BaseTexture* CreateTextureFromFile(const char* TextureFilename);
+  BaseTexture* CreateTextureFromBitmapData(const NBitmapData* BitmapData);
+
+  BaseTexture* LoadTextureFromFile(const std::string& filename);
 
   //! Abstract base class for textures.
   class BaseTexture: public ResourceData
   {
-    NUX_DECLARE_OBJECT_TYPE (BaseTexture, ResourceData);
+    NUX_DECLARE_OBJECT_TYPE(BaseTexture, ResourceData);
 
     BaseTexture(NUX_FILE_LINE_PROTO);
     virtual ~BaseTexture();
 
     /*!
       Update the texture with the provided Bitmap data. In doing so, if the texture as been cached in the resource manager, then
-      the the DeviceTexture inside the CachedTexture will no longer be returned by GetDeviceTexture (). Instead a new device texture will
+      the the DeviceTexture inside the CachedTexture will no longer be returned by GetDeviceTexture(). Instead a new device texture will
       be returned.
 
       @BitmapData Pointer to the bitmap data.
       @UpdateAndCacheResource If true, then the texture is cached immediately. If false, the texture will be cached the first time
-      GetDeviceTexture () or GetCachedTexture () is called.
+      GetDeviceTexture() or GetCachedTexture() is called.
       @return True if there was no error during the update.
     */
-    virtual bool Update (const NBitmapData *BitmapData, bool UpdateAndCacheResource = true) = 0;
+    virtual bool Update(const NBitmapData* BitmapData, bool UpdateAndCacheResource = true) = 0;
 
     /*!
       Update the texture with the provided filename. In doing so, if the texture as been cached in the resource manager, then
-      the the DeviceTexture inside the CachedTexture will no longer be returned by GetDeviceTexture (). Instead a new device texture will
+      the the DeviceTexture inside the CachedTexture will no longer be returned by GetDeviceTexture(). Instead a new device texture will
       be returned.
 
       @BitmapData Pointer to the bitmap data.
       @UpdateAndCacheResource If true, then the texture is cached immediately. If false, the texture will be cached the first time
-      GetDeviceTexture () or GetCachedTexture () is called.
+      GetDeviceTexture() or GetCachedTexture() is called.
       @return True if there was no error during the update.
     */
-    virtual bool Update (const TCHAR *filename, bool UpdateAndCacheResource = true) = 0;
+    virtual bool Update(const char* filename, bool UpdateAndCacheResource = true) = 0;
 
-    virtual void GetData (void *Buffer, int MipIndex, int StrideY, int face = 0) = 0;
+    virtual void GetData(void* Buffer, int MipIndex, int StrideY, int face = 0) = 0;
 
     /*!
       @return The texture width.
     */
-    virtual int GetWidth () const = 0;
+    virtual int GetWidth() const = 0;
 
     /*!
       @return The texture height.
     */
-    virtual int GetHeight () const = 0;
+    virtual int GetHeight() const = 0;
 
     /*!
       @return The texture depth. Return 1 for Texture2D, TextureCube, TextureRenctangle. TextureVolume and TextureFrameAnimation have a depth equal or greater than 1.
@@ -126,7 +128,7 @@ namespace nux
     /*!
       @return True if the width and height of the texture are powers of two.
     */
-    virtual bool IsPowerOfTwo () const = 0;
+    virtual bool IsPowerOfTwo() const = 0;
 
     /*!
       @return The texture data format.
@@ -136,32 +138,34 @@ namespace nux
     /*!
       @return The number of mip maps in the texture.
     */
-    virtual int GetNumMipLevel () const = 0;
+    virtual int GetNumMipLevel() const = 0;
 
     /*!
       @return True if the texture storage contains valid bitmap data.
     */
-    virtual bool IsNull () const = 0;
+    virtual bool IsNull() const = 0;
 
     /*!
       Clone the texture.
       @return A cloned version of this texture.
     */
-    virtual BaseTexture* Clone () const = 0;
+    virtual BaseTexture* Clone() const = 0;
 
     /*!
-      Cache the texture if it hasn't been been already and return the device texture.
+        Cache the texture if it hasn't been been already and return the device texture.
+        \sa IOpenGLBaseTexture;
 
-      @return The device texture.
+        @return The device texture.
     */
-    ObjectPtr < IOpenGLBaseTexture > GetDeviceTexture ();
+    ObjectPtr<IOpenGLBaseTexture> GetDeviceTexture();
 
     /*!
-      Cache the texture if it hasn't been been already and return the cached texture.
+        Cache the texture if it hasn't been been already and return the cached texture.
+        \sa CachedBaseTexture;
 
-      @return The cached texture.
+        @return The cached texture.
     */
-    ObjectPtr < CachedBaseTexture > GetCachedTexture ();
+    ObjectPtr<CachedBaseTexture> GetCachedTexture();
   };
 
   //! General Texture
@@ -170,14 +174,14 @@ namespace nux
   */
   class Texture2D: public BaseTexture
   {
-    NUX_DECLARE_OBJECT_TYPE (Texture2D, BaseTexture);
+    NUX_DECLARE_OBJECT_TYPE(Texture2D, BaseTexture);
 
   public:
-    Texture2D (NUX_FILE_LINE_PROTO);
-    Texture2D (const Texture2D &texture, NUX_FILE_LINE_PROTO);
-    Texture2D (const NTextureData &BaseTexture, NUX_FILE_LINE_PROTO);
-    Texture2D &operator = (const Texture2D &texture);
-    ~Texture2D ();
+    Texture2D(NUX_FILE_LINE_PROTO);
+    Texture2D(const Texture2D& texture, NUX_FILE_LINE_PROTO);
+    Texture2D(const NTextureData& BaseTexture, NUX_FILE_LINE_PROTO);
+    Texture2D& operator = (const Texture2D& texture);
+    ~Texture2D();
 
     /*!
         Update the hardware resources associated to this with the provided texture data.
@@ -187,7 +191,7 @@ namespace nux
         GetGraphicsDisplay()->GetGraphicsEngine()->CacheResource(this);
         @return True is there was not error.
     */
-    virtual bool Update (const NBitmapData *BitmapData, bool UpdateAndCacheResource = true);
+    virtual bool Update(const NBitmapData* BitmapData, bool UpdateAndCacheResource = true);
 
     /*!
         Update the hardware resources associated to this object with the data associated to the file name.
@@ -197,105 +201,31 @@ namespace nux
         GetGraphicsDisplay()->GetGraphicsEngine()->CacheResource(this);
         @return True is there was not error.
     */
-    virtual bool Update (const TCHAR *Filename, bool UpdateAndCacheResource = true);
+    virtual bool Update(const char* Filename, bool UpdateAndCacheResource = true);
 
     /*!
       @return True if the texture storage contains valid bitmap data.
     */
-    virtual bool IsNull () const
+    virtual bool IsNull() const
     {
       return _image.IsNull();
     }
 
-    void GetData (void *Buffer, int MipIndex, int StrideY, int face = 0);
+    void GetData(void* Buffer, int MipIndex, int StrideY, int face = 0);
 
     /*!
       @return The number of mip maps in the texture.
     */
-    int GetNumMipLevel () const
+    int GetNumMipLevel() const
     {
-      return _image.GetNumMipmap ();
+      return _image.GetNumMipmap();
     }
     /*!
       @return The texture width.
     */
-    int GetWidth () const
+    int GetWidth() const
     {
-      return _image.GetWidth ();
-    }
-
-    /*!
-      @return The texture height.
-    */
-    int GetHeight () const
-    {
-      return _image.GetHeight ();
-    }
-
-    /*!
-      @return The texture data format.
-    */
-    BitmapFormat GetFormat () const
-    {
-      return _image.GetFormat ();
-    }
-
-    /*!
-      @return True if the width and height of the texture are powers of two.
-    */
-    bool IsPowerOfTwo () const
-    {
-      return IsPowerOf2 (_image.GetWidth () ) && IsPowerOf2 (_image.GetHeight () );
-    }
-
-    /*!
-      Clone the texture.
-      @return A cloned version of this texture.
-    */
-    virtual BaseTexture* Clone() const;
-
-  private:
-    NTextureData _image; //!< Storage for the texture data
-  };
-
-  class TextureRectangle: public BaseTexture
-  {
-    NUX_DECLARE_OBJECT_TYPE (TextureRectangle, BaseTexture);
-
-  public:
-    TextureRectangle (NUX_FILE_LINE_PROTO);
-    TextureRectangle (const TextureRectangle &texture);
-    TextureRectangle (const NTextureData& Image);
-    TextureRectangle &operator = (const TextureRectangle &texture);
-    ~TextureRectangle ();
-
-    virtual bool Update (const NBitmapData *BitmapData, bool UpdateAndCacheResource = true);
-    virtual bool Update (const TCHAR *filename, bool UpdateAndCacheResource = true);
-
-    /*!
-      @return True if the texture storage contains valid bitmap data.
-    */
-    virtual bool IsNull () const
-    {
-      return _image.IsNull ();
-    }
-
-    void GetData (void *Buffer, int MipIndex, int StrideY, int face = 0);
-
-    /*!
-      @return The number of mip maps in the texture.
-    */
-    int GetNumMipLevel () const
-    {
-      return _image.GetNumMipmap ();
-    }
-
-    /*!
-      @return The texture width.
-    */
-    int GetWidth () const
-    {
-      return _image.GetWidth ();
+      return _image.GetWidth();
     }
 
     /*!
@@ -319,7 +249,81 @@ namespace nux
     */
     bool IsPowerOfTwo() const
     {
-      return IsPowerOf2 (_image.GetWidth() ) && IsPowerOf2 (_image.GetHeight() );
+      return IsPowerOf2(_image.GetWidth()) && IsPowerOf2(_image.GetHeight());
+    }
+
+    /*!
+      Clone the texture.
+      @return A cloned version of this texture.
+    */
+    virtual BaseTexture* Clone() const;
+
+  private:
+    NTextureData _image; //!< Storage for the texture data
+  };
+
+  class TextureRectangle: public BaseTexture
+  {
+    NUX_DECLARE_OBJECT_TYPE(TextureRectangle, BaseTexture);
+
+  public:
+    TextureRectangle(NUX_FILE_LINE_PROTO);
+    TextureRectangle(const TextureRectangle& texture);
+    TextureRectangle(const NTextureData& Image);
+    TextureRectangle& operator = (const TextureRectangle& texture);
+    ~TextureRectangle();
+
+    virtual bool Update(const NBitmapData* BitmapData, bool UpdateAndCacheResource = true);
+    virtual bool Update(const char* filename, bool UpdateAndCacheResource = true);
+
+    /*!
+      @return True if the texture storage contains valid bitmap data.
+    */
+    virtual bool IsNull() const
+    {
+      return _image.IsNull();
+    }
+
+    void GetData(void* Buffer, int MipIndex, int StrideY, int face = 0);
+
+    /*!
+      @return The number of mip maps in the texture.
+    */
+    int GetNumMipLevel() const
+    {
+      return _image.GetNumMipmap();
+    }
+
+    /*!
+      @return The texture width.
+    */
+    int GetWidth() const
+    {
+      return _image.GetWidth();
+    }
+
+    /*!
+      @return The texture height.
+    */
+    int GetHeight() const
+    {
+      return _image.GetHeight();
+    }
+
+    /*!
+      @return The texture data format.
+    */
+    BitmapFormat GetFormat() const
+    {
+      return _image.GetFormat();
+    }
+
+    /*!
+      @return True if the width and height of the texture are powers of two.
+    */
+    bool IsPowerOfTwo() const
+    {
+      return IsPowerOf2(_image.GetWidth()) && IsPowerOf2(_image.GetHeight());
     }
 
     /*!
@@ -334,72 +338,72 @@ namespace nux
 
   class TextureCube: public BaseTexture
   {
-    NUX_DECLARE_OBJECT_TYPE (TextureCube, BaseTexture);
+    NUX_DECLARE_OBJECT_TYPE(TextureCube, BaseTexture);
 
   public:
-    TextureCube (NUX_FILE_LINE_PROTO);
+    TextureCube(NUX_FILE_LINE_PROTO);
     //Texture2D(const NTextureData& Image);
-    TextureCube (const TextureCube &texture);
-    TextureCube &operator = (const TextureCube &texture);
+    TextureCube(const TextureCube& texture);
+    TextureCube& operator = (const TextureCube& texture);
     ~TextureCube();
 
-    virtual bool Update (const NBitmapData *BitmapData, bool UpdateAndCacheResource = true);
-    virtual bool Update (const TCHAR *filename, bool UpdateAndCacheResource = true);
+    virtual bool Update(const NBitmapData* BitmapData, bool UpdateAndCacheResource = true);
+    virtual bool Update(const char* filename, bool UpdateAndCacheResource = true);
 
     /*!
       @return True if the texture storage contains valid bitmap data.
     */
-    virtual bool IsNull () const
+    virtual bool IsNull() const
     {
-      return _image.IsNull ();
+      return _image.IsNull();
     }
-    void GetData (void *Buffer, int MipIndex, int StrideY, int face = 0);
+    void GetData(void* Buffer, int MipIndex, int StrideY, int face = 0);
 
     /*!
       @return The number of mip maps in the texture.
     */
-    int GetNumMipLevel () const
+    int GetNumMipLevel() const
     {
-      return _image.GetNumMipmap ();
+      return _image.GetNumMipmap();
     }
 
     /*!
       @return The texture width.
     */
-    int GetWidth () const
+    int GetWidth() const
     {
-      return _image.GetWidth ();
+      return _image.GetWidth();
     }
 
     /*!
       @return The texture height.
     */
-    int GetHeight () const
+    int GetHeight() const
     {
-      return _image.GetHeight ();
+      return _image.GetHeight();
     }
 
     /*!
       @return The texture data format.
     */
-    BitmapFormat GetFormat () const
+    BitmapFormat GetFormat() const
     {
-      return _image.GetFormat ();
+      return _image.GetFormat();
     }
 
     /*!
       @return True if the width and height of the texture are powers of two.
     */
-    bool IsPowerOfTwo () const
+    bool IsPowerOfTwo() const
     {
-      return IsPowerOf2 (_image.GetWidth() ) && IsPowerOf2 (_image.GetHeight() );
+      return IsPowerOf2(_image.GetWidth()) && IsPowerOf2(_image.GetHeight());
     }
 
     /*!
       Clone the texture.
       @return A cloned version of this texture.
     */
-    virtual BaseTexture* Clone () const;
+    virtual BaseTexture* Clone() const;
 
   private:
     NCubemapData _image;
@@ -407,81 +411,81 @@ namespace nux
 
   class TextureVolume: public BaseTexture
   {
-    NUX_DECLARE_OBJECT_TYPE (TextureVolume, BaseTexture);
+    NUX_DECLARE_OBJECT_TYPE(TextureVolume, BaseTexture);
 
   public:
-    TextureVolume (NUX_FILE_LINE_PROTO);
+    TextureVolume(NUX_FILE_LINE_PROTO);
     //Texture2D(const NTextureData& Image);
-    TextureVolume (const TextureVolume &texture);
-    TextureVolume &operator = (const TextureVolume &texture);
+    TextureVolume(const TextureVolume& texture);
+    TextureVolume& operator = (const TextureVolume& texture);
     ~TextureVolume();
 
-    virtual bool Update (const NBitmapData *BitmapData, bool UpdateAndCacheResource = true);
-    virtual bool Update (const TCHAR *filename, bool UpdateAndCacheResource = true);
+    virtual bool Update(const NBitmapData* BitmapData, bool UpdateAndCacheResource = true);
+    virtual bool Update(const char* filename, bool UpdateAndCacheResource = true);
 
     /*!
       @return True if the texture storage contains valid bitmap data.
     */
-    virtual bool IsNull () const
+    virtual bool IsNull() const
     {
-      return _image.IsNull ();
+      return _image.IsNull();
     }
-    void GetData (void *Buffer, int MipIndex, int StrideY, int slice = 0);
+    void GetData(void* Buffer, int MipIndex, int StrideY, int slice = 0);
     
     /*!
       @return The number of mip maps in the texture.
     */
-    int GetNumMipLevel () const
+    int GetNumMipLevel() const
     {
-      return _image.GetNumMipmap ();
+      return _image.GetNumMipmap();
     }
 
     /*!
       @return The texture width.
     */
-    int GetWidth () const
+    int GetWidth() const
     {
-      return _image.GetWidth ();
+      return _image.GetWidth();
     }
 
     /*!
       @return The texture height.
     */
-    int GetHeight () const
+    int GetHeight() const
     {
-      return _image.GetHeight ();
+      return _image.GetHeight();
     }
 
     /*!
       @return The texture depth. 
       For TextureFrameAnimation the depth represents the number of frames.
     */
-    int GetDepth () const
+    int GetDepth() const
     {
-      return _image.GetDepth ();
+      return _image.GetDepth();
     }
 
     /*!
       @return The texture data format.
     */
-    BitmapFormat GetFormat () const
+    BitmapFormat GetFormat() const
     {
-      return _image.GetFormat ();
+      return _image.GetFormat();
     }
 
     /*!
       @return True if the width and height of the texture are powers of two.
     */
-    bool IsPowerOfTwo () const
+    bool IsPowerOfTwo() const
     {
-      return IsPowerOf2 (_image.GetWidth () ) && IsPowerOf2 (_image.GetHeight () );
+      return IsPowerOf2(_image.GetWidth()) && IsPowerOf2(_image.GetHeight());
     }
 
     /*!
       Clone the texture.
       @return A cloned version of this texture.
     */
-    virtual BaseTexture* Clone () const;
+    virtual BaseTexture* Clone() const;
 
   private:
     NVolumeData _image;
@@ -489,80 +493,80 @@ namespace nux
 
   class TextureFrameAnimation: public BaseTexture
   {
-    NUX_DECLARE_OBJECT_TYPE (TextureFrameAnimation, BaseTexture);
+    NUX_DECLARE_OBJECT_TYPE(TextureFrameAnimation, BaseTexture);
 
   public:
-    TextureFrameAnimation (NUX_FILE_LINE_PROTO);
-    TextureFrameAnimation (const TextureFrameAnimation &texture);
-    TextureFrameAnimation &operator = (const TextureFrameAnimation &texture);
-    ~TextureFrameAnimation ();
+    TextureFrameAnimation(NUX_FILE_LINE_PROTO);
+    TextureFrameAnimation(const TextureFrameAnimation& texture);
+    TextureFrameAnimation& operator = (const TextureFrameAnimation& texture);
+    ~TextureFrameAnimation();
 
-    virtual bool Update (const NBitmapData *BitmapData, bool UpdateAndCacheResource = true);
-    virtual bool Update (const TCHAR *filename, bool UpdateAndCacheResource = true);
+    virtual bool Update(const NBitmapData* BitmapData, bool UpdateAndCacheResource = true);
+    virtual bool Update(const char* filename, bool UpdateAndCacheResource = true);
 
     /*!
       @return True if the texture storage contains valid bitmap data.
     */
-    virtual bool IsNull () const
+    virtual bool IsNull() const
     {
-      return _image.IsNull ();
+      return _image.IsNull();
     }
-    void GetData (void *Buffer, int MipIndex, int StrideY, int slice = 0);
-    int GetFrameTime (int Frame);
+    void GetData(void* Buffer, int MipIndex, int StrideY, int slice = 0);
+    int GetFrameTime(int Frame);
 
     /*!
       @return The number of mip maps in the texture.
     */
-    int GetNumMipLevel () const
+    int GetNumMipLevel() const
     {
-      return _image.GetNumMipmap ();
+      return _image.GetNumMipmap();
     }
 
     /*!
       @return The texture width.
     */
-    int GetWidth () const
+    int GetWidth() const
     {
-      return _image.GetWidth ();
+      return _image.GetWidth();
     }
 
     /*!
       @return The texture height.
     */
-    int GetHeight () const
+    int GetHeight() const
     {
-      return _image.GetHeight ();
+      return _image.GetHeight();
     }
 
     /*!
       @return The number of animation frames in the texture.
     */
-    int GetDepth () const
+    int GetDepth() const
     {
-      return _image.GetDepth ();
+      return _image.GetDepth();
     }
 
     /*!
       @return The texture data format.
     */
-    BitmapFormat GetFormat () const
+    BitmapFormat GetFormat() const
     {
-      return _image.GetFormat ();
+      return _image.GetFormat();
     }
 
     /*!
       @return true if the width and heigth of the texture are powers of two.
     */
-    bool IsPowerOfTwo () const
+    bool IsPowerOfTwo() const
     {
-      return IsPowerOf2 (_image.GetWidth () ) && IsPowerOf2 (_image.GetHeight () );
+      return IsPowerOf2(_image.GetWidth()) && IsPowerOf2(_image.GetHeight());
     }
 
     /*!
       Clone the texture.
       @return A cloned version of this texture.
     */
-    virtual BaseTexture* Clone () const;
+    virtual BaseTexture* Clone() const;
 
   private:
     NAnimatedTextureData _image;
@@ -570,20 +574,20 @@ namespace nux
 
   class CachedBaseTexture: public CachedResourceData
   {
-    NUX_DECLARE_OBJECT_TYPE (CachedBaseTexture, CachedResourceData);
+    NUX_DECLARE_OBJECT_TYPE(CachedBaseTexture, CachedResourceData);
   public:
     ObjectPtr < IOpenGLBaseTexture > m_Texture;
 
-    CachedBaseTexture (NResourceSet *ResourceManager);
+    CachedBaseTexture(NResourceSet* ResourceManager);
     ~CachedBaseTexture();
 
-    virtual void LoadMipLevel (BaseTexture *SourceTexture, int MipLevel) = 0;
+    virtual void LoadMipLevel(BaseTexture* SourceTexture, int MipLevel) = 0;
 
-    virtual bool UpdateResource (ResourceData *Resource);
+    virtual bool UpdateResource(ResourceData* Resource);
 
-    bool RecreateTexture (BaseTexture *Source);
+    bool RecreateTexture(BaseTexture* Source);
 
-    virtual void UpdateTexture (BaseTexture *Source) = 0;
+    virtual void UpdateTexture(BaseTexture* Source) = 0;
 
     unsigned int SourceWidth;
     unsigned int SourceHeight;
@@ -593,57 +597,57 @@ namespace nux
 
   class CachedTexture2D: public CachedBaseTexture
   {
-    NUX_DECLARE_OBJECT_TYPE (CachedTexture2D, CachedBaseTexture);
+    NUX_DECLARE_OBJECT_TYPE(CachedTexture2D, CachedBaseTexture);
   public:
-    CachedTexture2D (NResourceSet *ResourceManager, Texture2D *SourceTexture);
+    CachedTexture2D(NResourceSet* ResourceManager, Texture2D* SourceTexture);
     ~CachedTexture2D();
 
-    virtual void UpdateTexture (BaseTexture *Source);
-    virtual void LoadMipLevel (BaseTexture *SourceTexture, int MipLevel);
+    virtual void UpdateTexture(BaseTexture* Source);
+    virtual void LoadMipLevel(BaseTexture* SourceTexture, int MipLevel);
   };
 
   class CachedTextureRectangle: public CachedBaseTexture
   {
-    NUX_DECLARE_OBJECT_TYPE (CachedTextureRectangle, CachedBaseTexture);
+    NUX_DECLARE_OBJECT_TYPE(CachedTextureRectangle, CachedBaseTexture);
   public:
-    CachedTextureRectangle (NResourceSet *ResourceManager, TextureRectangle *SourceTexture);
-    ~CachedTextureRectangle ();
+    CachedTextureRectangle(NResourceSet* ResourceManager, TextureRectangle* SourceTexture);
+    ~CachedTextureRectangle();
 
-    virtual void UpdateTexture (BaseTexture *Source);
-    virtual void LoadMipLevel (BaseTexture *SourceTexture, int MipLevel);
+    virtual void UpdateTexture(BaseTexture* Source);
+    virtual void LoadMipLevel(BaseTexture* SourceTexture, int MipLevel);
   };
 
   class CachedTextureCube: public CachedBaseTexture
   {
-    NUX_DECLARE_OBJECT_TYPE (CachedTextureCube, CachedBaseTexture);
+    NUX_DECLARE_OBJECT_TYPE(CachedTextureCube, CachedBaseTexture);
   public:
-    CachedTextureCube (NResourceSet *ResourceManager, TextureCube *SourceTexture);
-    ~CachedTextureCube ();
+    CachedTextureCube(NResourceSet* ResourceManager, TextureCube* SourceTexture);
+    ~CachedTextureCube();
 
-    virtual void UpdateTexture (BaseTexture *Source);
-    virtual void LoadMipLevel (BaseTexture *SourceTexture, int MipLevel);
+    virtual void UpdateTexture(BaseTexture* Source);
+    virtual void LoadMipLevel(BaseTexture* SourceTexture, int MipLevel);
   };
 
   class CachedTextureVolume: public CachedBaseTexture
   {
-    NUX_DECLARE_OBJECT_TYPE (CachedTextureVolume, CachedBaseTexture);
+    NUX_DECLARE_OBJECT_TYPE(CachedTextureVolume, CachedBaseTexture);
   public:
-    CachedTextureVolume (NResourceSet *ResourceManager, TextureVolume *SourceTexture);
-    ~CachedTextureVolume ();
+    CachedTextureVolume(NResourceSet* ResourceManager, TextureVolume* SourceTexture);
+    ~CachedTextureVolume();
 
-    virtual void UpdateTexture (BaseTexture *Source);
-    virtual void LoadMipLevel (BaseTexture *SourceTexture, int MipLevel);
+    virtual void UpdateTexture(BaseTexture* Source);
+    virtual void LoadMipLevel(BaseTexture* SourceTexture, int MipLevel);
   };
 
   class CachedTextureFrameAnimation: public CachedBaseTexture
   {
-    NUX_DECLARE_OBJECT_TYPE (CachedTextureFrameAnimation, CachedBaseTexture);
+    NUX_DECLARE_OBJECT_TYPE(CachedTextureFrameAnimation, CachedBaseTexture);
   public:
-    CachedTextureFrameAnimation (NResourceSet *ResourceManager, TextureFrameAnimation *SourceTexture);
-    ~CachedTextureFrameAnimation ();
+    CachedTextureFrameAnimation(NResourceSet* ResourceManager, TextureFrameAnimation* SourceTexture);
+    ~CachedTextureFrameAnimation();
 
-    virtual void UpdateTexture (BaseTexture *Source);
-    virtual void LoadMipLevel (BaseTexture *SourceTexture, int MipLevel);
+    virtual void UpdateTexture(BaseTexture* Source);
+    virtual void LoadMipLevel(BaseTexture* SourceTexture, int MipLevel);
   };
 
 }
