@@ -33,41 +33,41 @@
 
 namespace nux
 {
-  ObjectPtr<IOpenGLTexture2D> GpuDevice::CreateTexture (
+  ObjectPtr<IOpenGLTexture2D> GpuDevice::CreateTexture(
     int Width
     , int Height
     , int Levels
-    , BitmapFormat PixelFormat)
+    , BitmapFormat PixelFormat
+    , NUX_FILE_LINE_DECL)
   {
     IOpenGLTexture2D *ptr;
-    CreateTexture (Width, Height, Levels, PixelFormat, (IOpenGLTexture2D **) &ptr);
+    CreateTexture(Width, Height, Levels, PixelFormat, (IOpenGLTexture2D **) &ptr, NUX_FILE_LINE_PARAM);
     ObjectPtr<IOpenGLTexture2D> h = ObjectPtr<IOpenGLTexture2D> (ptr);
-    ptr->UnReference ();
+    ptr->UnReference();
     return h;
   }
 
-  int GpuDevice::CreateTexture (
-    t_u32 Width
-    , t_u32 Height
-    , t_u32 Levels
-    //, DWORD Usage    // no use
+  int GpuDevice::CreateTexture(
+    unsigned int Width
+    , unsigned int Height
+    , unsigned int Levels
     , BitmapFormat PixelFormat
     , IOpenGLTexture2D **ppTexture
-    //, HANDLE* pSharedHandle       // no use
+    , NUX_FILE_LINE_DECL
     )
   {
     // From : http://oss.sgi.com/projects/ogl-sample/registry/ARB/texture_non_power_of_two.txt
     //    The "floor" convention has a relatively straightforward way to
-    //        evaluate (with integer math) means to determine how many mipmap
+    //        evaluate(with integer math) means to determine how many mipmap
     //        levels are required for a complete pyramid:
     //    numLevels = 1 + floor(log2(max(w, h, d)))
-    t_u32 NumTotalMipLevel    = 1 + floorf (Log2 (Max (Width, Height) ) );
+    unsigned int NumTotalMipLevel    = 1 + floorf(Log2(Max(Width, Height)));
 
     //    Levels
     //        [in] Number of levels in the texture. If this is zero, generate all texture sublevels
     //        down to 1 by 1 pixels for hardware that supports mip-maps textures. Call GetNumMipLevel to see the
     //        number of levels generated.
-    t_u32 NumMipLevel = 0;
+    unsigned int NumMipLevel = 0;
 
     if (Levels == 0)
     {
@@ -92,61 +92,62 @@ namespace nux
     //        is the dimension of level N+1.  The recursion stops when level
     //        numLevels-1 is reached.
 
-    *ppTexture = new IOpenGLTexture2D (Width, Height, NumMipLevel, PixelFormat, false, NUX_TRACKER_LOCATION);
+    *ppTexture = new IOpenGLTexture2D(Width, Height, NumMipLevel, PixelFormat, false, NUX_FILE_LINE_PARAM);
 
     return 1;
   }
 
-  ObjectPtr<IOpenGLTexture2D> GpuDevice::CreateTexture2DFromID(int id,
-    int width,
-    int height,
-    int levels,
-    BitmapFormat pixel_format)
+  ObjectPtr<IOpenGLTexture2D> GpuDevice::CreateTexture2DFromID(int id
+    , int width
+    , int height
+    , int levels
+    , BitmapFormat pixel_format
+    , NUX_FILE_LINE_DECL)
   {
     IOpenGLTexture2D *ptr;
-    ptr = new IOpenGLTexture2D (width, height, levels, pixel_format, true, NUX_TRACKER_LOCATION); // ref count = 1;
+    ptr = new IOpenGLTexture2D(width, height, levels, pixel_format, true, NUX_FILE_LINE_PARAM); // ref count = 1;
     ptr->_OpenGLID = id;
     ObjectPtr<IOpenGLTexture2D> h = ObjectPtr<IOpenGLTexture2D> (ptr); // ref count = 2
-    ptr->UnReference (); // ref count = 1
+    ptr->UnReference(); // ref count = 1
     return h;
   }
 
-  ObjectPtr<IOpenGLRectangleTexture> GpuDevice::CreateRectangleTexture (
+  ObjectPtr<IOpenGLRectangleTexture> GpuDevice::CreateRectangleTexture(
     int Width
     , int Height
     , int Levels
-    , BitmapFormat PixelFormat)
+    , BitmapFormat PixelFormat
+    , NUX_FILE_LINE_DECL)
   {
     IOpenGLRectangleTexture *ptr;
-    CreateRectangleTexture (Width, Height, Levels, PixelFormat, (IOpenGLRectangleTexture **) &ptr);
+    CreateRectangleTexture(Width, Height, Levels, PixelFormat, (IOpenGLRectangleTexture **) &ptr, NUX_FILE_LINE_PARAM);
     ObjectPtr<IOpenGLRectangleTexture> h = ObjectPtr<IOpenGLRectangleTexture> (ptr);
-    ptr->UnReference ();
+    ptr->UnReference();
     return h;
   }
 
-  int GpuDevice::CreateRectangleTexture (
-    t_u32 Width
-    , t_u32 Height
-    , t_u32 Levels
-    //, DWORD Usage    // no use
+  int GpuDevice::CreateRectangleTexture(
+    unsigned int Width
+    , unsigned int Height
+    , unsigned int Levels
     , BitmapFormat PixelFormat
     , IOpenGLRectangleTexture **ppTexture
-    //, HANDLE* pSharedHandle       // no use
+    , NUX_FILE_LINE_DECL
     )
   {
 
     // From : http://oss.sgi.com/projects/ogl-sample/registry/ARB/texture_non_power_of_two.txt
     //    The "floor" convention has a relatively straightforward way to
-    //        evaluate (with integer math) means to determine how many mipmap
+    //        evaluate(with integer math) means to determine how many mipmap
     //        levels are required for a complete pyramid:
     //    numLevels = 1 + floor(log2(max(w, h, d)))
-    t_u32 NumTotalMipLevel    = 1 + floorf (Log2 (Max (Width, Height) ) );
+    unsigned int NumTotalMipLevel    = 1 + floorf(Log2(Max(Width, Height)));
 
     //    Levels
     //        [in] Number of levels in the texture. If this is zero, generate all texture sublevels
     //        down to 1 by 1 pixels for hardware that supports mip-maps textures. Call GetNumMipLevel to see the
     //        number of levels generated.
-    t_u32 NumMipLevel = 0;
+    unsigned int NumMipLevel = 0;
 
     if (Levels == 0)
     {
@@ -172,39 +173,39 @@ namespace nux
     //        is the dimension of level N+1.  The recursion stops when level
     //        numLevels-1 is reached.
 
-    *ppTexture = new IOpenGLRectangleTexture (Width, Height, NumMipLevel, PixelFormat, false, NUX_TRACKER_LOCATION);
+    *ppTexture = new IOpenGLRectangleTexture(Width, Height, NumMipLevel, PixelFormat, false, NUX_FILE_LINE_PARAM);
 
 
     return 1;
   }
 
-  ObjectPtr<IOpenGLCubeTexture> GpuDevice::CreateCubeTexture (
+  ObjectPtr<IOpenGLCubeTexture> GpuDevice::CreateCubeTexture(
     int EdgeLength
     , int Levels
-    , BitmapFormat PixelFormat)
+    , BitmapFormat PixelFormat
+    , NUX_FILE_LINE_DECL)
   {
     IOpenGLCubeTexture *ptr;
-    CreateCubeTexture (EdgeLength, Levels, PixelFormat, (IOpenGLCubeTexture **) &ptr);
+    CreateCubeTexture(EdgeLength, Levels, PixelFormat, (IOpenGLCubeTexture **) &ptr);
     ObjectPtr<IOpenGLCubeTexture> h = ObjectPtr<IOpenGLCubeTexture> (ptr);
-    ptr->UnReference ();
+    ptr->UnReference();
     return h;
   }
 
-  int GpuDevice::CreateCubeTexture (
-    t_u32 EdgeLength
-    , t_u32 Levels
-    //, DWORD Usage    // no use
+  int GpuDevice::CreateCubeTexture(
+    unsigned int EdgeLength
+    , unsigned int Levels
     , BitmapFormat PixelFormat
     , IOpenGLCubeTexture **ppCubeTexture
-    //, HANDLE* pSharedHandle    // no use
+    , NUX_FILE_LINE_DECL
     )
   {
-    t_u32 NumTotalMipLevel    = 1 + floorf (Log2 (EdgeLength) );
+    unsigned int NumTotalMipLevel    = 1 + floorf(Log2(EdgeLength));
     //    Levels
     //        [in] Number of levels in the texture. If this is zero, Direct3D will generate all texture sublevels
     //        down to 1 by 1 pixels for hardware that supports mipmapped textures. Call GetNumMipLevel to see the
     //        number of levels generated.
-    t_u32 NumMipLevel = 0;
+    unsigned int NumMipLevel = 0;
 
     if (Levels == 0)
     {
@@ -219,42 +220,42 @@ namespace nux
       NumMipLevel = Levels;
     }
 
-    *ppCubeTexture = new IOpenGLCubeTexture (EdgeLength, NumMipLevel, PixelFormat);
+    *ppCubeTexture = new IOpenGLCubeTexture(EdgeLength, NumMipLevel, PixelFormat);
 
     return 1;
   }
 
-  ObjectPtr<IOpenGLVolumeTexture> GpuDevice::CreateVolumeTexture (
+  ObjectPtr<IOpenGLVolumeTexture> GpuDevice::CreateVolumeTexture(
     int Width
     , int Height
     , int Depth
     , int Levels
-    , BitmapFormat PixelFormat)
+    , BitmapFormat PixelFormat
+    , NUX_FILE_LINE_DECL)
   {
     IOpenGLVolumeTexture *ptr;
-    CreateVolumeTexture (Width, Height, Depth, Levels, PixelFormat, (IOpenGLVolumeTexture **) &ptr);
+    CreateVolumeTexture(Width, Height, Depth, Levels, PixelFormat, (IOpenGLVolumeTexture **) &ptr, NUX_FILE_LINE_PARAM);
     ObjectPtr<IOpenGLVolumeTexture> h = ObjectPtr<IOpenGLVolumeTexture> (ptr);
-    ptr->UnReference ();
+    ptr->UnReference();
     return h;
   }
 
-  int GpuDevice::CreateVolumeTexture (
-    t_u32 Width
-    , t_u32 Height
-    , t_u32 Depth
-    , t_u32 Levels
-    //, DWORD Usage        // no use
+  int GpuDevice::CreateVolumeTexture(
+    unsigned int Width
+    , unsigned int Height
+    , unsigned int Depth
+    , unsigned int Levels
     , BitmapFormat PixelFormat
     , IOpenGLVolumeTexture **ppVolumeTexture
-    //, HANDLE* pSharedHandle       // no use
+    , NUX_FILE_LINE_DECL
     )
   {
-    t_u32 NumTotalMipLevel = 1 + floorf (Log2 (Max (Max (Width, Height), Depth) ) );
+    unsigned int NumTotalMipLevel = 1 + floorf(Log2(Max(Max(Width, Height), Depth)));
     //    Levels
     //        [in] Number of levels in the texture. If this is zero, Direct3D will generate all texture sublevels
     //        down to 1 by 1 pixels for hardware that supports mipmapped textures. Call GetNumMipLevel to see the
     //        number of levels generated.
-    t_u32 NumMipLevel = 0;
+    unsigned int NumMipLevel = 0;
 
     if (Levels == 0)
     {
@@ -269,47 +270,47 @@ namespace nux
       NumMipLevel = Levels;
     }
 
-    *ppVolumeTexture = new IOpenGLVolumeTexture (Width, Height, Depth, NumMipLevel, PixelFormat);
+    *ppVolumeTexture = new IOpenGLVolumeTexture(Width, Height, Depth, NumMipLevel, PixelFormat);
 
     return OGL_OK;
   }
 
-  ObjectPtr<IOpenGLAnimatedTexture> GpuDevice::CreateAnimatedTexture (
+  ObjectPtr<IOpenGLAnimatedTexture> GpuDevice::CreateAnimatedTexture(
     int Width
     , int Height
     , int Depth
     , BitmapFormat PixelFormat)
   {
     IOpenGLAnimatedTexture *ptr;
-    CreateAnimatedTexture (Width, Height, Depth, PixelFormat, (IOpenGLAnimatedTexture **) &ptr);
+    CreateAnimatedTexture(Width, Height, Depth, PixelFormat, (IOpenGLAnimatedTexture **) &ptr);
     ObjectPtr<IOpenGLAnimatedTexture> h = ObjectPtr<IOpenGLAnimatedTexture> (ptr);
-    ptr->UnReference ();
+    ptr->UnReference();
     return h;
   }
 
-  int GpuDevice::CreateAnimatedTexture (t_u32 Width,
-    t_u32 Height,
-    t_u32 Depth,
+  int GpuDevice::CreateAnimatedTexture(unsigned int Width,
+    unsigned int Height,
+    unsigned int Depth,
     BitmapFormat PixelFormat,
     IOpenGLAnimatedTexture **ppAnimatedTexture)
   {
-    *ppAnimatedTexture = new IOpenGLAnimatedTexture (Width, Height, Depth, PixelFormat);
+    *ppAnimatedTexture = new IOpenGLAnimatedTexture(Width, Height, Depth, PixelFormat);
 
     return OGL_OK;
   }
 
-  ObjectPtr<IOpenGLQuery> GpuDevice::CreateQuery (QUERY_TYPE Type)
+  ObjectPtr<IOpenGLQuery> GpuDevice::CreateQuery(QUERY_TYPE Type)
   {
     IOpenGLQuery *ptr;
-    CreateQuery (Type, (IOpenGLQuery **) &ptr);
+    CreateQuery(Type, (IOpenGLQuery **) &ptr);
     ObjectPtr<IOpenGLQuery> h = ObjectPtr<IOpenGLQuery> (ptr);
-    ptr->UnReference ();
+    ptr->UnReference();
     return h;
   }
 
-  int GpuDevice::CreateQuery (QUERY_TYPE Type, IOpenGLQuery **ppQuery)
+  int GpuDevice::CreateQuery(QUERY_TYPE Type, IOpenGLQuery **ppQuery)
   {
-    *ppQuery = new IOpenGLQuery (Type);
+    *ppQuery = new IOpenGLQuery(Type);
 
     return OGL_OK;
   }
