@@ -36,90 +36,90 @@ namespace nux
 
   static STREAMSOURCE _StreamSource[MAX_NUM_STREAM];
 
-  ObjectPtr<IOpenGLVertexBuffer> GpuDevice::CreateVertexBuffer (int Length,
+  ObjectPtr<IOpenGLVertexBuffer> GpuDevice::CreateVertexBuffer(int Length,
       VBO_USAGE Usage)
   {
     IOpenGLVertexBuffer *ptr;
-    CreateVertexBuffer (Length, Usage, (IOpenGLVertexBuffer **) &ptr);
+    CreateVertexBuffer(Length, Usage, (IOpenGLVertexBuffer **) &ptr);
     ObjectPtr<IOpenGLVertexBuffer> h = ObjectPtr<IOpenGLVertexBuffer> (ptr);
-    ptr->UnReference ();
+    ptr->UnReference();
     return h;
   }
 
-  int GpuDevice::CreateVertexBuffer (unsigned int Length,
+  int GpuDevice::CreateVertexBuffer(unsigned int Length,
       VBO_USAGE Usage,
       IOpenGLVertexBuffer **ppVertexBuffer)
   {
-    *ppVertexBuffer = new IOpenGLVertexBuffer (Length, Usage, NUX_TRACKER_LOCATION);
+    *ppVertexBuffer = new IOpenGLVertexBuffer(Length, Usage, NUX_TRACKER_LOCATION);
 
     return OGL_OK;
   }
 
-  ObjectPtr<IOpenGLIndexBuffer> GpuDevice::CreateIndexBuffer (
+  ObjectPtr<IOpenGLIndexBuffer> GpuDevice::CreateIndexBuffer(
     int Length
     , VBO_USAGE Usage    // Dynamic or WriteOnly
     , INDEX_FORMAT Format)
   {
     IOpenGLIndexBuffer *ptr;
-    CreateIndexBuffer (Length, Usage, Format, (IOpenGLIndexBuffer **) &ptr);
+    CreateIndexBuffer(Length, Usage, Format, (IOpenGLIndexBuffer **) &ptr);
     ObjectPtr<IOpenGLIndexBuffer> h = ObjectPtr<IOpenGLIndexBuffer> (ptr);
-    ptr->UnReference ();
+    ptr->UnReference();
     return h;
   }
 
-  int GpuDevice::CreateIndexBuffer (unsigned int Length,
+  int GpuDevice::CreateIndexBuffer(unsigned int Length,
                                           VBO_USAGE Usage,
                                           INDEX_FORMAT Format,
                                           IOpenGLIndexBuffer **ppIndexBuffer)
   {
-    *ppIndexBuffer = new IOpenGLIndexBuffer (Length, Usage, Format, NUX_TRACKER_LOCATION);
+    *ppIndexBuffer = new IOpenGLIndexBuffer(Length, Usage, Format, NUX_TRACKER_LOCATION);
 
     return OGL_OK;
   }
 
-  ObjectPtr<IOpenGLPixelBufferObject> GpuDevice::CreatePixelBufferObject (int Size, VBO_USAGE Usage)
+  ObjectPtr<IOpenGLPixelBufferObject> GpuDevice::CreatePixelBufferObject(int Size, VBO_USAGE Usage)
   {
     IOpenGLPixelBufferObject *ptr;
-    CreatePixelBufferObject (Size, Usage, (IOpenGLPixelBufferObject **) &ptr);
+    CreatePixelBufferObject(Size, Usage, (IOpenGLPixelBufferObject **) &ptr);
     ObjectPtr<IOpenGLPixelBufferObject> h = ObjectPtr<IOpenGLPixelBufferObject> (ptr);
-    ptr->UnReference ();
+    ptr->UnReference();
     return h;
   }
 
-  int GpuDevice::CreatePixelBufferObject (int Size, VBO_USAGE Usage,
+  int GpuDevice::CreatePixelBufferObject(int Size, VBO_USAGE Usage,
       IOpenGLPixelBufferObject **ppPixelBufferObject)
   {
-    *ppPixelBufferObject = new IOpenGLPixelBufferObject (Size, Usage, NUX_TRACKER_LOCATION);
+    *ppPixelBufferObject = new IOpenGLPixelBufferObject(Size, Usage, NUX_TRACKER_LOCATION);
 
     return OGL_OK;
   }
 
-  ObjectPtr<IOpenGLVertexDeclaration> GpuDevice::CreateVertexDeclaration (
+  ObjectPtr<IOpenGLVertexDeclaration> GpuDevice::CreateVertexDeclaration(
     const VERTEXELEMENT *pVertexElements)
   {
     IOpenGLVertexDeclaration *ptr;
-    CreateVertexDeclaration (pVertexElements, (IOpenGLVertexDeclaration **) &ptr);
+    CreateVertexDeclaration(pVertexElements, (IOpenGLVertexDeclaration **) &ptr);
     ObjectPtr<IOpenGLVertexDeclaration> h = ObjectPtr<IOpenGLVertexDeclaration> (ptr);
-    ptr->UnReference ();
+    ptr->UnReference();
     return h;
   }
 
-  int GpuDevice::CreateVertexDeclaration (const VERTEXELEMENT *pVertexElements,
+  int GpuDevice::CreateVertexDeclaration(const VERTEXELEMENT *pVertexElements,
       IOpenGLVertexDeclaration **ppDecl)
   {
-    *ppDecl = new IOpenGLVertexDeclaration (pVertexElements);
+    *ppDecl = new IOpenGLVertexDeclaration(pVertexElements);
 
     return OGL_OK;
   }
 
   void GpuDevice::InvalidateVertexBuffer()
   {
-    CHECKGL (glBindBufferARB (GL_ARRAY_BUFFER_ARB, 0) );
+    CHECKGL(glBindBufferARB(GL_ARRAY_BUFFER_ARB, 0));
   }
 
   void GpuDevice::InvalidateIndexBuffer()
   {
-    CHECKGL (glBindBufferARB (GL_ELEMENT_ARRAY_BUFFER_ARB, 0) );
+    CHECKGL(glBindBufferARB(GL_ELEMENT_ARRAY_BUFFER_ARB, 0));
   }
 
   int GpuDevice::DrawIndexedPrimitive(ObjectPtr<IOpenGLIndexBuffer> IndexBuffer,
@@ -127,9 +127,9 @@ namespace nux
       PRIMITIVE_TYPE PrimitiveType,
       int index_count)
   {
-    nuxAssert (VertexDeclaration.IsValid() );
+    nuxAssert(VertexDeclaration.IsValid());
 
-    if (!VertexDeclaration.IsValid() )
+    if (!VertexDeclaration.IsValid())
       return OGL_ERROR;
 
     int decl = 0;
@@ -139,13 +139,13 @@ namespace nux
       VertexDeclaration->_valid_vertex_input[i] = 0;
     }
 
-    while(VertexDeclaration->_declarations_array[decl].Stream != 0xFF)
+    while (VertexDeclaration->_declarations_array[decl].Stream != 0xFF)
     {
       VERTEXELEMENT vtxelement = VertexDeclaration->_declarations_array[decl];
 
       int shader_attribute_location = VertexDeclaration->GetVertexShaderAttributeLocation(decl);
       
-      if(shader_attribute_location == -1)
+      if (shader_attribute_location == -1)
       {
         ++decl;
         continue;
@@ -175,7 +175,7 @@ namespace nux
       if (IndexBuffer->GetStride() == 4)
         index_format = GL_UNSIGNED_INT;
 
-//       switch (PrimitiveType)
+//       switch(PrimitiveType)
 //       {
 //         case PRIMITIVE_TYPE_POINTLIST:
 //           ElementCount = PrimitiveCount;
@@ -199,19 +199,19 @@ namespace nux
 //           break;
 //         default:
 //           // Unknown primitive type. This should not happen.
-//           nuxAssertMsg (0, TEXT ("[GpuDevice::DrawIndexedPrimitive] Unknown Primitive Type.") );
+//           nuxAssertMsg(0, "[GpuDevice::DrawIndexedPrimitive] Unknown Primitive Type.");
 //       }
 
-      CHECKGL(glDrawElements (primitive,
+      CHECKGL(glDrawElements(primitive,
                                 index_count,
                                 index_format,
                                 0));
     }
 
     {
-      for(int index = 0; index < 16; index++)
+      for (int index = 0; index < 16; index++)
       {
-        if(VertexDeclaration->_valid_vertex_input[index])
+        if (VertexDeclaration->_valid_vertex_input[index])
           glDisableVertexAttribArrayARB(index);
       }
 
@@ -219,7 +219,7 @@ namespace nux
       InvalidateIndexBuffer();
     }
 
-    //    for(int i = 0; i < 8; i++)
+    //    for (int i = 0; i < 8; i++)
     //    {
     //        CHECKGL(glClientActiveTexture(GL_TEXTURE0 + i));
     //        CHECKGL(glDisable(GL_TEXTURE_3D));
@@ -233,15 +233,16 @@ namespace nux
   }
 
 
+#ifndef NUX_OPENGLES_20
 // Draw Primitive without index buffer
-  int GpuDevice::DrawPrimitive (ObjectPtr<IOpenGLVertexDeclaration> VertexDeclaration,
+  int GpuDevice::DrawPrimitive(ObjectPtr<IOpenGLVertexDeclaration> VertexDeclaration,
                                       PRIMITIVE_TYPE PrimitiveType,
                                       unsigned vtx_start_,
                                       unsigned PrimitiveCount)
   {
 //     return OGL_OK;
-//     glDisable (GL_CULL_FACE);
-//     glPolygonMode (GL_FRONT_AND_BACK, GL_LINE);
+//     glDisable(GL_CULL_FACE);
+//     glPolygonMode(GL_FRONT_AND_BACK, GL_LINE);
 // 
 //     // Maps a vertex declaration usage to a vertex shader input index.
 //     // I want to make this a static array defined outside of this function but their seems to be a problem
@@ -269,9 +270,9 @@ namespace nux
 //       3,   // ATTRIB_USAGE_DECL_BINORMAL
 //     };
 // 
-//     nuxAssert (VertexDeclaration.IsValid() );
+//     nuxAssert(VertexDeclaration.IsValid());
 // 
-//     if (!VertexDeclaration.IsValid() )
+//     if (!VertexDeclaration.IsValid())
 //       return OGL_ERROR;
 // 
 //     int decl = 0;
@@ -284,18 +285,18 @@ namespace nux
 //       VERTEXELEMENT vtxelement = VertexDeclaration->_declarations_array[decl];
 //       int vtxInput = sVertexInputMap[vtxelement.Usage + vtxelement.UsageIndex];
 // 
-//       nuxAssert (vtxInput < GetGpuInfo().GetMaxFboAttachment());
-//       // Eneble the vertex attribute (0 to 10)
-//       glEnableVertexAttribArrayARB ( vtxInput );
+//       nuxAssert(vtxInput < GetGpuInfo().GetMaxFboAttachment());
+//       // Eneble the vertex attribute(0 to 10)
+//       glEnableVertexAttribArrayARB( vtxInput );
 //       // Bind the vertex buffer
 //       _StreamSource[vtxelement.Stream].VertexBuffer->BindVertexBuffer();
 // 
-//       CHECKGL ( glVertexAttribPointer (vtxInput,
+//       CHECKGL(glVertexAttribPointer(vtxInput,
 //                                        vtxelement.NumComponent,
 //                                        vtxelement.Type,
 //                                        GL_FALSE,
 //                                        _StreamSource[vtxelement.Stream].StreamStride,
-//                                        (GLvoid *) (&_StreamSource[vtxelement.Stream].StreamOffset + vtxelement.Offset) ) );
+//                                        (GLvoid *) (&_StreamSource[vtxelement.Stream].StreamOffset + vtxelement.Offset)));
 // 
 //       VertexDeclaration->_valid_vertex_input[sVertexInputMap[vtxelement.Usage + vtxelement.UsageIndex]] = 1;
 //       decl++;
@@ -307,7 +308,7 @@ namespace nux
 //       GLenum primitive = PrimitiveType;
 //       int ElementCount = 0;
 // 
-//       switch (PrimitiveType)
+//       switch(PrimitiveType)
 //       {
 //         case PRIMITIVE_TYPE_POINTLIST:
 //           ElementCount = PrimitiveCount;
@@ -331,27 +332,27 @@ namespace nux
 //           break;
 //         default:
 //           // Unknown primitive type. This should not happen.
-//           nuxAssertMsg (0, TEXT ("[GpuDevice::DrawPrimitive] Unknown Primitive Type.") );
+//           nuxAssertMsg(0, "[GpuDevice::DrawPrimitive] Unknown Primitive Type.");
 //           return OGL_ERROR;
 //       }
 // 
-//       CHECKGL ( glDrawArrays (primitive,
+//       CHECKGL(glDrawArrays(primitive,
 //                               ElementCount,
-//                               vtx_start_) );
+//                               vtx_start_));
 //     }
 // 
 //     {
 //       for (int index = 0; index < 16; index++)
 //       {
 //         if (VertexDeclaration->_valid_vertex_input[index])
-//           glDisableVertexAttribArrayARB ( index );
+//           glDisableVertexAttribArrayARB( index );
 //       }
 // 
 //       InvalidateVertexBuffer();
 //       InvalidateIndexBuffer();
 //     }
 // 
-//     //    for(int i = 0; i < 8; i++)
+//     //    for (int i = 0; i < 8; i++)
 //     //    {
 //     //        CHECKGL(glClientActiveTexture(GL_TEXTURE0 + i));
 //     //        CHECKGL(glDisable(GL_TEXTURE_3D));
@@ -365,37 +366,37 @@ namespace nux
   }
 
 // Draw Primitive without index buffer, and use a user pointer for the source of the stream.
-  int GpuDevice::DrawPrimitiveUP (ObjectPtr<IOpenGLVertexDeclaration> VertexDeclaration,
+  int GpuDevice::DrawPrimitiveUP(ObjectPtr<IOpenGLVertexDeclaration> VertexDeclaration,
                                         PRIMITIVE_TYPE PrimitiveType,
                                         unsigned int PrimitiveCount,
                                         const void *pVertexStreamZeroData,
                                         unsigned int VertexStreamZeroStride)
   {
-//     nuxAssertMsg (VertexDeclaration->IsUsingMoreThanStreamZero(), TEXT ("[GpuDevice::DrawPrimitiveUP] Declaration is using more than stream 0.") );
-//     VERTEXELEMENT vtxelement = VertexDeclaration->GetUsage (ATTRIB_USAGE_DECL_POSITION);
+//     nuxAssertMsg(VertexDeclaration->IsUsingMoreThanStreamZero(), "[GpuDevice::DrawPrimitiveUP] Declaration is using more than stream 0.");
+//     VERTEXELEMENT vtxelement = VertexDeclaration->GetUsage(ATTRIB_USAGE_DECL_POSITION);
 //     int Stream = vtxelement.Stream;
 // 
 //     if (Stream != 0xFF)
 //     {
-//       glDisable (GL_CULL_FACE);
-//       glPolygonMode (GL_FRONT_AND_BACK, GL_LINE);
+//       glDisable(GL_CULL_FACE);
+//       glPolygonMode(GL_FRONT_AND_BACK, GL_LINE);
 // 
 //       InvalidateVertexBuffer();
 //       InvalidateVertexBuffer();
 // 
-//       t_size ptr = * (t_size *) pVertexStreamZeroData + _StreamSource[vtxelement.Stream].StreamOffset;
-//       CHECKGL ( glEnableClientState (GL_VERTEX_ARRAY) );
-//       CHECKGL ( glVertexPointer ( vtxelement.NumComponent,
+//       size_t ptr = * (size_t *) pVertexStreamZeroData + _StreamSource[vtxelement.Stream].StreamOffset;
+//       CHECKGL(glEnableClientState(GL_VERTEX_ARRAY));
+//       CHECKGL(glVertexPointer( vtxelement.NumComponent,
 //                                   vtxelement.Type,
 //                                   VertexStreamZeroStride,
-//                                   (GLvoid *) &ptr) );
+//                                   (GLvoid *) &ptr));
 // 
 //       InvalidateIndexBuffer();
 // 
 //       GLenum primitive = PrimitiveType;
 //       int ElementCount = 0;
 // 
-//       switch (PrimitiveType)
+//       switch(PrimitiveType)
 //       {
 //         case PRIMITIVE_TYPE_POINTLIST:
 //           ElementCount = PrimitiveCount;
@@ -419,19 +420,19 @@ namespace nux
 //           break;
 //         default:
 //           // Unknown primitive type. This should not happen.
-//           nuxAssertMsg (0, TEXT ("[GpuDevice::DrawPrimitiveUP] Unknown Primitive Type.") );
+//           nuxAssertMsg(0, "[GpuDevice::DrawPrimitiveUP] Unknown Primitive Type.");
 //           return OGL_ERROR;
 //       }
 // 
-//       CHECKGL ( glDrawArrays (primitive,
+//       CHECKGL(glDrawArrays(primitive,
 //                               ElementCount,
-//                               0) );
+//                               0));
 // 
-//       CHECKGL ( glDisableClientState (GL_VERTEX_ARRAY) );
+//       CHECKGL(glDisableClientState(GL_VERTEX_ARRAY));
 // 
 //     }
 // 
-//     //    for(int i = 0; i < 8; i++)
+//     //    for (int i = 0; i < 8; i++)
 //     //    {
 //     //        CHECKGL(glClientActiveTexture(GL_TEXTURE0 + i));
 //     //        CHECKGL(glDisable(GL_TEXTURE_3D));
@@ -443,6 +444,7 @@ namespace nux
 //     //    }
     return OGL_OK;
   }
+#endif
 
 // //    DirectX Matrix
 // //    |   2/W     0       0       -(W+1)/W    |
@@ -459,7 +461,7 @@ namespace nux
 // //        Y: W ---> -1-1/H                  --->                H-0.5
 // //
 // //    The Matrix above is good to do quad on screen in DirectX. DirectX requires that the vertex coordinates be shifted
-// //    by (-0.5,-0.5) in order for the center of texel to be located at the center of pixel.
+// //    by(-0.5,-0.5) in order for the center of texel to be located at the center of pixel.
 // //    Note: OpenGL maps integral texture coordinates to the texel center
 // //          whereas Direct3D maps  integral texture coordinates to the upper, left texel corner.
 // 
@@ -478,13 +480,13 @@ namespace nux
 // //        Y: W ---> -1
 
 
-  int GpuDevice::SetStreamSource (
+  int GpuDevice::SetStreamSource(
     unsigned int StreamNumber,
     ObjectPtr<IOpenGLVertexBuffer> pStreamData,
     unsigned int OffsetInBytes,
     unsigned int Stride)
   {
-    nuxAssert (StreamNumber < MAX_NUM_STREAM);
+    nuxAssert(StreamNumber < MAX_NUM_STREAM);
 
     _StreamSource[StreamNumber].Stream = StreamNumber;
     _StreamSource[StreamNumber].StreamOffset = OffsetInBytes;
