@@ -34,10 +34,12 @@ namespace nux
                              bool        take_focus,
                              int         override_redirect)
     : strutsEnabled_(false)
+    , overlayStrutsEnabled_(false)
     , display_(GetGraphicsDisplay()->GetX11Display())
     , geometry_(0, 0, 1, 1)
     , shown_(false)
     , mapped_(false)
+    , overlay_strut_atom_(0)
   {
     XSetWindowAttributes attrib;
 
@@ -81,17 +83,17 @@ namespace nux
                     (unsigned char *) type, 1);
 
     XStoreName(display_, window_, title);
-    EnsureInputs ();
+    EnsureInputs();
 
     if (take_focus)
-      EnableTakeFocus ();
+      EnableTakeFocus();
 
-    EnableDnd ();
+    EnableDnd();
   }
 
   XInputWindow::~XInputWindow()
   {
-    native_windows_.erase(std::find (native_windows_.begin (), native_windows_.end (), window_));
+    native_windows_.erase(std::find(native_windows_.begin(), native_windows_.end(), window_));
     XDestroyWindow(display_, window_);
   }
 
@@ -101,19 +103,19 @@ namespace nux
     return native_windows_;
   }
 
-  void XInputWindow::SetStruts()
+  std::vector<long int> XInputWindow::GetStrutsData()
   {
     int n_info;
-    XineramaScreenInfo *info = XineramaQueryScreens (display_, &n_info);
+    XineramaScreenInfo *info = XineramaQueryScreens(display_, &n_info);
     Region             screen_region;
-    Region             total_screen_region = XCreateRegion ();
-    Region             input_window_region = XCreateRegion ();
-    Region             intersection = XCreateRegion ();
-    XineramaScreenInfo monitor;
+    Region             total_screen_region = XCreateRegion();
+    Region             input_window_region = XCreateRegion();
+    Region             intersection = XCreateRegion();
+    XRectangle         monitor;
     XRectangle         tmp_rect;
     int largestWidth = 0, largestHeight = 0;
     int screenWidth, screenHeight;
-    long int data[12] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
+    std::vector<long int> data(12, 0);
 
     /* Find the screen that this region intersects */
     tmp_rect.x = geometry_.x;
@@ -121,7 +123,14 @@ namespace nux
     tmp_rect.width = geometry_.width;
     tmp_rect.height = geometry_.height;
 
-    XUnionRectWithRegion (&tmp_rect, input_window_region, input_window_region);
+    XUnionRectWithRegion(&tmp_rect, input_window_region, input_window_region);
+
+    /* If there is no Xinerama data available just use the geometry we have */
+    if (!info)
+    {
+      monitor = tmp_rect;
+      n_info = 0;
+    }
 
     for (int i = 0; i < n_info; i++)
     {
@@ -130,13 +139,13 @@ namespace nux
       tmp_rect.width = info[i].width;
       tmp_rect.height = info[i].height;
 
-      screen_region = XCreateRegion ();
+      screen_region = XCreateRegion();
 
-      XUnionRectWithRegion (&tmp_rect, screen_region, screen_region);
-      XUnionRegion (screen_region, total_screen_region, total_screen_region);
-      XIntersectRegion (screen_region, input_window_region, intersection);
+      XUnionRectWithRegion(&tmp_rect, screen_region, screen_region);
+      XUnionRegion(screen_region, total_screen_region, total_screen_region);
+      XIntersectRegion(screen_region, input_window_region, intersection);
 
-      if (!XEmptyRegion (intersection))
+      if (!XEmptyRegion(intersection))
       {
         int width = intersection->extents.x2 - intersection->extents.x1;
         int height = intersection->extents.y2 - intersection->extents.y1;
@@ -146,26 +155,29 @@ namespace nux
           largestWidth = width;
           largestHeight = height;
 
-          monitor = info[i];
+          monitor.x      = info[i].x_org;
+          monitor.y      = info[i].y_org;
+          monitor.width  = info[i].width;
+          monitor.height = info[i].height;
         }
       }
 
-      XDestroyRegion (screen_region);
+      XDestroyRegion(screen_region);
     }
 
     screenWidth = total_screen_region->extents.x2 - total_screen_region->extents.x1;
     screenHeight = total_screen_region->extents.y2 - total_screen_region->extents.y1;
 
-    XDestroyRegion (input_window_region);
-    XDestroyRegion (intersection);
-    XDestroyRegion (total_screen_region);
+    XDestroyRegion(input_window_region);
+    XDestroyRegion(intersection);
+    XDestroyRegion(total_screen_region);
 
     if (info)
-      XFree (info);
+      XFree(info);
 
     if (geometry_.width > geometry_.height)
     {
-      if (geometry_.y - monitor.y_org < monitor.height / 2)
+      if (geometry_.y - monitor.y < monitor.height / 2)
       {
         /* top */
         data[2] = geometry_.y + geometry_.height;
@@ -182,7 +194,7 @@ namespace nux
     }
     else
     {
-      if (geometry_.x - monitor.x_org < monitor.width / 2)
+      if (geometry_.x - monitor.x < monitor.width / 2)
       {
         /* left */
         data[0] = geometry_.x + geometry_.width;
@@ -198,10 +210,17 @@ namespace nux
       }
     }
 
+    return data;
+  }
+
+  void XInputWindow::SetStruts()
+  {
+    std::vector<long int> data(GetStrutsData());
+
     XChangeProperty(display_, window_,
                     XInternAtom(display_, "_NET_WM_STRUT_PARTIAL", 0),
                     XA_CARDINAL, 32, PropModeReplace,
-                    (unsigned char *) data, 12);
+                    (unsigned char*) &data[0], 12);
   }
 
   void XInputWindow::UnsetStruts()
@@ -210,6 +229,20 @@ namespace nux
                     XInternAtom(display_, "_NET_WM_STRUT_PARTIAL", 0));
   }
 
+  void XInputWindow::SetOverlayStruts()
+  {
+    std::vector<long int> data(GetStrutsData());
+
+    XChangeProperty(display_, window_, overlay_strut_atom_,
+                    XA_CARDINAL, 32, PropModeReplace,
+                    (unsigned char*) &data[0], 12);
+  }
+
+  void XInputWindow::UnsetOverlayStruts()
+  {
+    XDeleteProperty(display_, window_, overlay_strut_atom_);
+  }
+
   void XInputWindow::EnableStruts(bool enable)
   {
     if (strutsEnabled_ == enable)
@@ -227,6 +260,26 @@ namespace nux
     return strutsEnabled_;
   }
 
+  void XInputWindow::EnableOverlayStruts(bool enable)
+  {
+    if (overlayStrutsEnabled_ == enable)
+      return;
+
+    if (!overlay_strut_atom_)
+      overlay_strut_atom_ = XInternAtom(display_, "_COMPIZ_NET_OVERLAY_STRUT", 0);
+
+    overlayStrutsEnabled_ = enable;
+    if (enable)
+      SetOverlayStruts();
+    else
+      UnsetOverlayStruts();
+  }
+
+  bool XInputWindow::OverlayStrutsEnabled()
+  {
+    return overlayStrutsEnabled_;
+  }
+
   void XInputWindow::EnsureInputs()
   {
     XSelectInput(display_, window_,
@@ -245,10 +298,10 @@ namespace nux
 
   void XInputWindow::EnableTakeFocus()
   {
-    Atom wmTakeFocus = XInternAtom (display_, "WM_TAKE_FOCUS", False);
+    Atom wmTakeFocus = XInternAtom(display_, "WM_TAKE_FOCUS", False);
     XWMHints* wmHints = NULL;
 
-    wmHints = (XWMHints*) calloc (1, sizeof (XWMHints));
+    wmHints = (XWMHints*) calloc(1, sizeof(XWMHints));
     wmHints->flags |= InputHint;
     wmHints->input = False;
     XSetWMHints(display_, window_, wmHints);
@@ -283,6 +336,8 @@ namespace nux
 
     if (strutsEnabled_)
       SetStruts();
+    if (overlayStrutsEnabled_)
+      SetOverlayStruts();
   }
 
   //! Set the position and size of the window
@@ -297,17 +352,17 @@ namespace nux
     return geometry_;
   }
 
-  Window XInputWindow::GetWindow ()
+  Window XInputWindow::GetWindow()
   {
     return window_;
   }
 
-  void XInputWindow::SetInputFocus ()
+  void XInputWindow::SetInputFocus()
   {
     XSetInputFocus(display_, window_, RevertToParent, CurrentTime);
   }
 
-  void XInputWindow::Hide ()
+  void XInputWindow::Hide()
   {
     XMoveResizeWindow(display_, window_,
                       -100 - geometry_.width,
@@ -317,18 +372,22 @@ namespace nux
     shown_ = false;
   }
 
-  void XInputWindow::Show ()
+  void XInputWindow::Show()
   {
     shown_ = true;
 
     if (!mapped_)
     {
-      XMapRaised (display_, window_);
+      XMapRaised(display_, window_);
       mapped_ = true;
+
+      XEvent xevent;
+      while (XCheckTypedWindowEvent(display_, window_, MapNotify, &xevent));
+      XSetInputFocus(display_, window_, RevertToParent, CurrentTime);
+
     }
     XMoveResizeWindow(display_, window_,
                       geometry_.x, geometry_.y,
                       geometry_.width, geometry_.height);
   }
 }
-
