@@ -51,6 +51,9 @@ namespace nux
     void EnableStruts(bool enable);
     bool StrutsEnabled();
 
+    void EnableOverlayStruts(bool enable);
+    bool OverlayStrutsEnabled();
+
     void EnsureInputs();
 
     void EnableTakeFocus ();
@@ -74,22 +77,28 @@ namespace nux
 
   private:
 
+    std::vector<long int> GetStrutsData();
+
     void SetStruts ();
     void UnsetStruts ();
 
+    void SetOverlayStruts ();
+    void UnsetOverlayStruts ();
+
     void EnableDnd ();
     void DisableDnd ();
 
     static std::vector<Window> native_windows_;
 
     bool strutsEnabled_;
+    bool overlayStrutsEnabled_;
     Window window_;
     Display *display_;
     Rect geometry_;
     bool shown_;
     bool mapped_;
+    Atom overlay_strut_atom_;
   };
 }
 
 #endif // XINPUTWINDOW_H
-
