@@ -92,8 +92,8 @@ void RenderTexturePowerOfTwo ()
   m_GraphicsContext->SetContext(0, 0, w, h);
   m_GraphicsContext->Push2DWindow(w, h);
 
-  nux::IEvent event;
-  memset(&event, 0, sizeof(nux::IEvent));
+  nux::Event event;
+  memset(&event, 0, sizeof(nux::Event));
 
   do
   {
@@ -101,7 +101,7 @@ void RenderTexturePowerOfTwo ()
     CHECKGL( glClear(GL_COLOR_BUFFER_BIT|GL_DEPTH_BUFFER_BIT|GL_STENCIL_BUFFER_BIT) );
 
     m_GLWindow->GetSystemEvent(&event);
-    if(event.e_event == nux::NUX_SIZE_CONFIGURATION)
+    if(event.type == nux::NUX_SIZE_CONFIGURATION)
     {
       m_GraphicsContext->DisableAllTextureMode(0);
       m_GraphicsContext->DisableAllTextureMode(1);
@@ -119,12 +119,6 @@ void RenderTexturePowerOfTwo ()
     for (int i = 0; i < 9; i++)
     {
       m_GraphicsContext->SetTexture(GL_TEXTURE0, tex [i]);
-      CHECKGL( glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST) );
-      CHECKGL( glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST) );
-
-      glEnable(GL_TEXTURE_2D);
-      glDisable(GL_TEXTURE_3D);
-      glDisable(GL_TEXTURE_CUBE_MAP);
 
       if (i > 0)
         x += tex[i-1]->GetWidth () + 5;
@@ -132,22 +126,12 @@ void RenderTexturePowerOfTwo ()
       int width = tex[i]->GetWidth ();
       int height = tex[i]->GetHeight ();
 
-      glBegin(GL_QUADS);
-      {
-        glMultiTexCoord2fARB(GL_TEXTURE0, 0.0f, 0.0f);
-        glVertex3f(x,  y, 0);
-        glMultiTexCoord2fARB(GL_TEXTURE0, 0.0f, 1.0);
-        glVertex3f(x,  y + height, 0);
-        glMultiTexCoord2fARB(GL_TEXTURE0, 1.0f, 1.0);
-        glVertex3f(x + width,  y + height, 0);
-        glMultiTexCoord2fARB(GL_TEXTURE0, 1.0f, 0.0);
-        glVertex3f(x + width,  y, 0);
-      }
-      glEnd();
+      nux::TexCoordXForm texxform;
+      m_GraphicsContext->QRP_GLSL_1Tex(x, y, width, height, tex[i], texxform, nux::color::White);
     }
 
     m_GLWindow->SwapBuffer();
-  } while(event.e_event != nux::NUX_TERMINATE_APP);
+  } while(event.type != nux::NUX_TERMINATE_APP);
 
   for (int i = 0; i < 9; i++)
   {
